log using sip90jid, text replace
set mem 500m
*This program reads the 1990 SIPP Revised Job ID Data File 
*Note:  This program is distributed under the GNU GPL. See end of
*this file and http://www.gnu.org/licenses/ for details.
*by Jean Roth Thu Mar 11 15:57:24 EST 2004
*Please report errors to jroth@nber.org
*run with do sip90jid
*Change output file name/location as desired in the first line of the .dct file
*If you are using a PC, you may need to change the direction of the slashes, as in C:\
*  or "\\Nber\home\data\sipp\1990\sip90jid.dat"
* The following changes in variable names have been made, if necessary:
*      '$' to 'd';            '-' to '_';              '%' to 'p';
*For compatibility with other software, variable label definitions are the
*variable name unless the variable name ends in a digit. 
*'1' -> 'a', '2' -> 'b', '3' -> 'c', ... , '0' -> 'j'
* Note:  Variable names in Stata are case-sensitive
clear

*local dat_name "C:\Users\amecikovsky\Desktop\SIPP\Raw data\sipp_revised_jobid_file_1990.dat"
local dat_name "F:\Data\SIPP\Data\sipp_revised_jobid_file_1990.dat"

/* The following line should contain the path to your output '.dta' file */

*local dta_name "C:\Users\amecikovsky\Desktop\SIPP\Extracts\sipp90jid.dta"
local dta_name "F:\Data\SIPP\Extracts\sipp90jid.dta"

/* The following line should contain the path to the data dictionary file */

*local dct_name "C:\Users\amecikovsky\Desktop\SIPP\Dictionaries\sip90jid.dct"
local dct_name "F:\Data\SIPP\Data\sip90jid.dct"

/* The line below does NOT need to be changed */

quietly infile using "`dct_name'", using("`dat_name'") clear

*Everything below this point are value labels

#delimit ;

;
label values flag_jobid_chan flag_jobid_chan;
label define flag_jobid_chan
	0           "No revisions made to this jobid in this wave and jobid=jobid_revised"
	1           "Revisions made to this jobid in this wave and jobid ~= jobid_revised"
;

#delimit cr


sort suid entry pnum panel wave
rename jobid jobid_old
egen obs = group(suid entry pnum panel wave)
sort obs
gen index = 1
by obs: egen index2 = sum(index)
gen jobid1_old = 0
gen jobid1_rev = 0
gen jobid2_old = 0
gen jobid2_rev = 0
by obs: replace jobid1_old = jobid_old 
by obs: replace jobid1_rev = jobid_revised 
by obs: replace jobid2_old = jobid_old if index2==2
by obs: replace jobid2_rev = jobid_revised if index2==2
drop index2
by obs: replace jobid2_old = jobid2_old[2]
by obs: replace jobid2_rev = jobid2_rev[2]
replace jobid2_old =0 if jobid2_old==.
replace jobid2_rev =0 if jobid2_rev==.
by obs: gen index2=sum(index)
drop if index2==2
drop index index2 jobid_old jobid_revised obs

rename suid su_id 
rename entry pp_entry 
rename pnum pp_pnum 
rename wave pp_wave
destring su_id, replace
format su_id %11.0f
sort su_id pp_entry pp_pnum pp_wave

save `dta_name' , replace
log close
clear


/*
Copyright 2004 shared by the National Bureau of Economic Research and Jean Roth

National Bureau of Economic Research.
1050 Massachusetts Avenue
Cambridge, MA 02138
jroth@nber.org

This program and all programs referenced in it are free software. You
can redistribute the program or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA.
*/
