function u_loss = comp_u_loss(NLSY_aux,names)

%compute reduced form depretiation coefficient

%drop the disabled and sum all unemployed
NLSY_aux(NLSY_aux(:,1)==4,:) = [];
NLSY_aux(NLSY_aux(:,1)==5,:) = [];
NLSY_aux(NLSY_aux(:,1)==3,1) = 2;

%drop younger than 35
% NLSY_aux=NLSY_aux(NLSY_aux(:,13)>=40,:);

%find starting point of new agent
NLSY_aux = [NLSY_aux zeros(length(NLSY_aux),1)];
NLSY_aux(2:end,12) = NLSY_aux(2:end,9)-NLSY_aux(1:end-1,9);
NLSY_aux(NLSY_aux(:,12)~=0,12) = 1;
NLSY_aux(1,12) =1;
names(1,12) = {'d ID'};

%find EU movement
fcn = @(x){create_diff(x)};
NLSY_aux(:,13) = accumarray_expand(NLSY_aux(:,1),NLSY_aux(:,9),fcn); %find eu transition
NLSY_aux(:,13) = NLSY_aux(:,13)==1;
names(1,13) = {'d EU'};

%find UE movement
fcn = @(x){create_diff(x)};
NLSY_aux(:,14) = accumarray_expand(NLSY_aux(:,1),NLSY_aux(:,9),fcn); %find ue transition
NLSY_aux(:,14) = NLSY_aux(:,14)==-1;
names(1,14) = {'d UE'};

%find unemployment spell
fcn = @(x){cumsum(x)}; 
NLSY_aux(:,15) = accumarray_expand(NLSY_aux(:,13),NLSY_aux(:,9),fcn);
NLSY_aux(NLSY_aux(:,1)==1,15) = 0;

%old log wage for unemployment spell
NLSY_aux = [NLSY_aux zeros(length(NLSY_aux),1)];
NLSY_aux(2:end,16) = log(NLSY_aux(1:end-1,7));
NLSY_aux(NLSY_aux(:,13)==0,16) = 0;

%new log wage after spell
NLSY_aux = [NLSY_aux zeros(length(NLSY_aux),1)];
NLSY_aux(1:end-1,17) = log(NLSY_aux(2:end,7));
NLSY_aux(NLSY_aux(:,1)==1,17) = 0;
NLSY_aux(NLSY_aux(:,17)==-Inf,17) = 0;

% keep only unemployed and drop initial unemployment spell
NLSY_aux(NLSY_aux(:,1)==1,:) = [];
NLSY_aux(NLSY_aux(:,15)==0,:) = [];

%compute duration of unemplozment spell (and drop spells longer than 4 years)
NLSY_aux(:,18) = group([NLSY_aux(:,9) NLSY_aux(:,15)]);
NLSY_aux(:,19) = 1;
fcn = @(x)sum(x); 
NLSY_aux(:,19) = accumarray_expand(NLSY_aux(:,19),NLSY_aux(:,18),fcn);
% NLSY_aux = NLSY_aux(NLSY_aux(:,19)<=16,:);

%reduce to one observation by spell
fcn = @(x)max(x); 
NLSY_aux(:,16) = accumarray_expand(NLSY_aux(:,16),NLSY_aux(:,18),fcn);
NLSY_aux(:,17) = accumarray_expand(NLSY_aux(:,17),NLSY_aux(:,18),fcn);
fcn = @(x)mean(x); 
aux = accumarray_expand_s(NLSY_aux(:,16),NLSY_aux(:,18),fcn);
aux(:,2) = accumarray_expand_s(NLSY_aux(:,17),NLSY_aux(:,18),fcn);
aux(aux(:,2)==0,:) = []; %drop spells where worker did not get employed again.
aux(:,3) = aux(:,2)-aux(:,1);
u_loss.mean = mean(aux(:,3));
u_loss.median = median(aux(:,3));

end
