﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}


__global__ void e_inter(double *E_e_inter, double *E_u_inter, double *E_f_inter, double *E_r_inter, const double *E_e, const double *E_u, const double *E_f, const double *E_r, const double* wage, const double *b, const double* agrid, const double* grid_nc, const double* aprime, const int* abound, const int *index, const int t1)
{
    //interpolate nc grid for the employed 
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;


    //read out parameter vector
    //double work = par[0];
    //double retire = par[1];

    int na = index[0];
    int np = index[1];
    int fnodes = index[2];
    int nc = index[3];
    //int fnodes_nc = index[4];
    //int ns = index[5];
    int nap = index[6];
    int nap_nc = index[7];


    //initialization
    double lt_inc;
    double num;
    double a00;
    double a01;
    double a10;
    double a11;



    if (ROW < nap_nc && COL < np && PAGE < fnodes) {
        
        //E_e_d, E_u_d, E_f_d, E_r_d have size na*np*fnodes*nc
        //E_e_inter have size nap*nc*np*fnodes
        double aux = ROW / nap;
        int SHEET = floor(aux); //implied nc
        int PAGE2 = ROW - (SHEET * nap); // the nap entry

        lt_inc = (wage[PAGE * np + COL] + t1 * grid_nc[SHEET]) / (t1 + 1); //life time income to be interpolated
        int pos_lt = find_pos(lt_inc, grid_nc, nc); //index
        if (pos_lt == nc - 1) {
            pos_lt = nc - 2;
        }

        int pos_a = abound[PAGE2]; //position of aprime
        double save_plus_lump = aprime[PAGE2] + b[PAGE * np + COL];
        int pos_a2 = find_pos(save_plus_lump, agrid, na);  //position of aprime+b
        if (pos_a2 == na - 1) {
            pos_a2 = na - 2;
        }

        //weights of 2-D interpolation of lt_inc -- aprime
        num = (grid_nc[pos_lt + 1] - grid_nc[pos_lt]) * (agrid[pos_a + 1] - agrid[pos_a]);  // x_g = grid_nc
        a00 = ((grid_nc[pos_lt + 1] - lt_inc) * (agrid[pos_a + 1] - aprime[PAGE2])) / num;
        a01 = ((grid_nc[pos_lt + 1] - lt_inc) * (aprime[PAGE2] - agrid[pos_a])) / num;
        a10 = ((lt_inc - grid_nc[pos_lt]) * (agrid[pos_a + 1] - aprime[PAGE2])) / num;
        a11 = ((lt_inc - grid_nc[pos_lt]) * (aprime[PAGE2] - agrid[pos_a])) / num;

        //value of staying employed
        E_e_inter[PAGE * np * nap_nc + COL * nap_nc + ROW] = a00 * E_e[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a01 * E_e[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1] + a10 * E_e[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a11 * E_e[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1];

        //E_e_inter[PAGE * np * nap_nc + COL * nap_nc + ROW] = pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a;

        //value of forced offer
        E_f_inter[PAGE * np * nap_nc + COL * nap_nc + ROW] = a00 * E_f[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a01 * E_f[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1] + a10 * E_f[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a11 * E_f[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1];

        //value of regular offer
        E_r_inter[PAGE * np * nap_nc + COL * nap_nc + ROW] = a00 * E_r[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a01 * E_r[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1] + a10 * E_r[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a] + a11 * E_r[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a + 1];

        //weights of 2-D interpolation of lt_inc -- aprime+b
        num = (grid_nc[pos_lt + 1] - grid_nc[pos_lt]) * (agrid[pos_a2 + 1] - agrid[pos_a2]);  // x_g = grid_nc
        a00 = ((grid_nc[pos_lt + 1] - lt_inc) * (agrid[pos_a2 + 1] - save_plus_lump)) / num;
        a01 = ((grid_nc[pos_lt + 1] - lt_inc) * (save_plus_lump - agrid[pos_a2])) / num;
        a10 = ((lt_inc - grid_nc[pos_lt]) * (agrid[pos_a2 + 1] - save_plus_lump)) / num;
        a11 = ((lt_inc - grid_nc[pos_lt]) * (save_plus_lump - agrid[pos_a2])) / num;

        //value of exogenous job destruction
        E_u_inter[PAGE * np * nap_nc + COL * nap_nc + ROW] = a00 * E_u[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a2] + a01 * E_u[pos_lt * na * np * fnodes + PAGE * np * na + COL * na + pos_a2 + 1] + a10 * E_u[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a2] + a11 * E_u[(pos_lt + 1) * na * np * fnodes + PAGE * np * na + COL * na + pos_a2 + 1];

    }

}
