clear all
close all
clc


opengl('save', 'software')
%% 
for iii = 1:1:3 %loop over education types
   
opti.period = 1;
opti.type = iii;  
opti.cali = 0; %calibrate parameters
opti.truncate = 0;
opti.error = 1; %simulate with error

%options to compute Table 6. For the baseline, set all to 0
opti.decomp =0; %options for risk decomposition 
opti.prod_shock = 0; %1: productivity dispersion from period 3
opti.job_disp = 0; %1: job dispersion from period 3
opti.job_risk = 0; %1: reallocation shocks and job destruction from period 3
opti.ini_ineq = 0; %1: initial productivity dispersion from period 3
opti.health = 0; %1: health risk from period 3
opti.wage = 0; %1: wage process from period 3
opti.welfare = 0; %1: welfare state from period 3



%% load parameters

load('p1_s1_t1.mat','p1_s1_t1');
load('p1_s1_t2.mat','p1_s1_t2');
load('p1_s1_t3.mat','p1_s1_t3');
load('p3_s1_t1_recal.mat','p3_s1_t1_recal');
load('p3_s1_t2_recal.mat','p3_s1_t2_recal');
load('p3_s1_t3_recal.mat','p3_s1_t3_recal');


%data
load('disab_data.mat','disab_data')
load('di.mat','di')
load('ini_disab.mat','ini_disab')



%% parameters
r = (1+0.04)^(1/4)-1; %interest rate
R=1+r;
theta = 1.5;
if opti.type == 1  
    beta = 0.9948;        %discount factor   
    eta0 = 0.65; %scale of search costs      
    eta1 = 1.00; %curvature for search costs  
    eta_f = 0.0; %fixed costs of search 
    phi = -0.48;                 %target   emp_prime: 78.24// emp_55: 0.6409  emp_61:0.499   Higher phi may help with var over lc
    fc = 1040; %fixed-costs of working 
    if opti.wage==0
        mu = p1_s1_t1.para(6);       %experience gains 25-49 
        mu2 = p1_s1_t1.para(7);      %experience gains 50-61
    else
        mu = p3_s1_t1_recal.para(6);       %experience gains 25-49 
        mu2 = p3_s1_t1_recal.para(7);      %experience gains 50-61
    end
    delta1 = min(0.0,mu);   %skill loss young
    delta2 = min(0.0,mu2);   %skill loss old
    if opti.health == 0
        xi = p1_s1_t1.para(15);
        pi_gb = disab_data.gb_age_g1_p1;
        pi_bg = disab_data.bg_age_g1;
    else
        xi = p3_s1_t1_recal.para(15);
        pi_gb = disab_data.gb_age_g1_p3;
        pi_bg = disab_data.bg_age_g1;
    end
elseif opti.type == 2 
    beta = 0.9956;       
    eta0 = 0.45;   
    eta1 = 0.94; 
    eta_f = 0.0; 
    phi = -0.48;             
    fc = 1280; 
    if opti.wage==0
        mu = p1_s1_t2.para(6);       
        mu2 = p1_s1_t2.para(7);     
    else
        mu = p3_s1_t2_recal.para(6);    
        mu2 = p3_s1_t2_recal.para(7);     
    end
    delta1 = min(0,mu); 
    delta2 = min(0,mu2);   
    if opti.health == 0
        xi = p1_s1_t2.para(15); %p1_s1_t1.para(13);
        pi_gb = disab_data.gb_age_g2_p1;
        pi_bg = disab_data.bg_age_g2;
    else
        xi = p3_s1_t2_recal.para(15);
        pi_gb = disab_data.gb_age_g2_p3;
        pi_bg = disab_data.bg_age_g2;
    end    
else 
    beta = 0.9959;      
    eta0 = 0.50;
    eta1 = 0.92; 
    eta_f = 0.0;
    phi = -0.48;         
    fc = 1210; 
    if opti.wage==0
        mu = p1_s1_t3.para(6); 
        mu2 = p1_s1_t3.para(7); 
    else
        mu = p3_s1_t3_recal.para(6);      
        mu2 = p3_s1_t3_recal.para(7);    
    end
    delta1 = min(0,mu);   
    delta2 = min(0,mu2);  
    if opti.health == 0
        xi = p1_s1_t3.para(15); 
        pi_gb = disab_data.gb_age_g3_p1;
        pi_bg = disab_data.bg_age_g3;
    else
        xi = p3_s1_t3_recal.para(15);
        pi_gb = disab_data.gb_age_g3_p3;
        pi_bg = disab_data.bg_age_g3;
    end   
end
disab_c = 0; %cutoff for disability shocks

if opti.type == 1
    if opti.job_risk == 0
        destruct_age = [p1_s1_t1.para(1); p1_s1_t1.para(2); p1_s1_t1.para(3)];    %exogenous destruction
        lambda_d = p1_s1_t1.para(10);    %probability of reallocation offer
    else
        destruct_age = [p3_s1_t1_recal.para(1); p3_s1_t1_recal.para(2); p3_s1_t1_recal.para(3)];    
        lambda_d = p3_s1_t1_recal.para(10);  
    end
    data_targets = [19.41/100; 2.58/100; 3.53/100; 0.426; 8.330; 0.3814; 0.3000; -0.0307; 0.0305; 0.0196; 0.0296; 0.0394; 0.1146; -0.16]; 
elseif opti.type ==2
    if opti.job_risk == 0
        destruct_age = [p1_s1_t2.para(1); p1_s1_t2.para(2); p1_s1_t2.para(3)];   
        lambda_d = p1_s1_t2.para(10);    
    else
        destruct_age = [p3_s1_t2_recal.para(1); p3_s1_t2_recal.para(2); p3_s1_t2_recal.para(3)];  
        lambda_d = p3_s1_t2_recal.para(10);   
    end
    data_targets = [23.14/100; 3.46/100; 3.46/100; 0.43; 8.436; 0.3756; 0.4464; -0.0424; 0.0185; 0.0146; 0.024; 0.0153; 0.0578; -0.129];
else
    if opti.job_risk == 0
        destruct_age = [p1_s1_t3.para(1); p1_s1_t3.para(2); p1_s1_t3.para(3)];  
        lambda_d = p1_s1_t3.para(10);   
    else
        destruct_age = [p3_s1_t3_recal.para(1); p3_s1_t3_recal.para(2); p3_s1_t3_recal.para(3)];   
        lambda_d = p3_s1_t3_recal.para(10);   
    end
    data_targets = [24.5/100; 2.81/100; 2.81/100; 0.424; 8.63; 0.4079; 0.5553; -0.0346; 0.0117; 0.0084; 0.0192; 0.0058; 0.0332; -0.217];
end




%duration of life
work = 37*4;          
retire = 10*4;
disable = 37*4;  %can apply to DI
life = work+retire;

%asset grid
na = 608;
if opti.type==1
    amax =155000;
elseif opti.type==2
    amax =200000;
else 
    amax =350000;
end
amin = 0;
na_aux = round(na/2);
agrid = linspace(amin,amax/4,round(na/2))'; 
agrid = [agrid; linspace(agrid(end)+max(diff(agrid)),amax,na-na_aux)'];
adiff = diff(agrid);

%asset choices
nap=4*na;
na_aux = round(nap/2);
aprime = linspace(amin,amax/4,round(nap/2))'; 
aprime = [aprime; linspace(aprime(end)+max(diff(aprime)),amax,nap-na_aux)'];

%get interpolation points for asset choices
[~,abound] = histc(aprime,agrid);
abound(aprime>=agrid(end)) = na-1;
abound(aprime<=agrid(1)) = 1;
s_aprime = (aprime - agrid(abound))./adiff(abound);

%initial asset
load('asset_ini.mat','asset_ini') %load distribution from the data
if opti.type == 1
    asset_ini = asset_ini(:,1,1);
elseif opti.type == 2
    asset_ini = asset_ini(:,2,1);  
else
    asset_ini = asset_ini(:,3,1);
end

[~,asset_ini] = histc(min(max(agrid),asset_ini),agrid); %CDF
asset_ini = [asset_ini (0.1:0.1:1)'];


%initial employment and disability
if opti.type == 1
    ini_emp = 0;
    ini_disab_u = disab_data.age_g1_p1(1,1);
    ini_disab_e = ini_disab(1,2,1)-0.018*ini_disab(1,1,1);
elseif opti.type == 2
    ini_emp = 0;
    ini_disab_u = disab_data.age_g2_p1(1,1);
    ini_disab_e = ini_disab(2,2,1)+0.100*ini_disab(2,2,1);
else
    ini_emp = 0;
    ini_disab_u = disab_data.age_g3_p1(1,1);
    ini_disab_e = ini_disab(3,2,1)-0.05*ini_disab(3,2,1);
end


%search grid
ns = 8;
sgrid = [0; 0.1; 0.13; 0.17; 0.21; 0.25; 0.30; 0.35];

search_costs_e = (eta0*(sgrid.^(1+eta1)./(1+eta1))); %search costs employed 
search_costs_u = [0; (eta0*(sgrid(2:end).^(1+eta1)./(1+eta1)))+eta_f]; %search costs non-employed 

%uncertainty
if opti.prod_shock == 0 && opti.job_disp==0
    if  opti.type==1
        gamma.std = 0.2598; %job offer dist.
        epsilon.stde = 0.0303; %productivity shocks
    elseif  opti.type==2
        gamma.std = 0.2169; 
        epsilon.stde = 0.0424; 
    else
        gamma.std = 0.2669;
        epsilon.stde = 0.0496; 
    end
else %period 3
    if opti.prod_shock == 1 && opti.job_disp==1 
        if  opti.type==1
            gamma.std = 0.2249; 
            epsilon.stde = 0.0396; 
        elseif  opti.type==2
            gamma.std = 0.2306;
            epsilon.stde = 0.0465; 
        else
            gamma.std = 0.2999;
            epsilon.stde = 0.0583; 
        end
    elseif  opti.prod_shock == 0 && opti.job_disp==1 
        if  opti.type==1
            gamma.std = 0.2249;
            epsilon.stde = 0.0303;
        elseif  opti.type==2
            gamma.std = 0.2351; 
            epsilon.stde = 0.0424; 
        else
            gamma.std = 0.2999; 
            epsilon.stde = 0.0496; 
        end
    elseif  opti.prod_shock == 1 && opti.job_disp==0 
        if  opti.type==1
            gamma.std = 0.2598; 
            epsilon.stde = 0.0396; 
        elseif  opti.type==2
            gamma.std = 0.2169; 
            epsilon.stde = 0.0465; 
        else
            gamma.std = 0.2669;
            epsilon.stde = 0.0583; 
        end    
    end
end


%transitory shocks
if opti.period == 1
    ma.coef = [-0.4549 -0.4333 -0.4351; -0.0487 -0.04 -0.0465];
    ma.std = [0.0710; 0.0787; 0.1066];
else
    ma.coef = [-0.440 -0.4 -0.474; -0.000 -0.061 -0.09];
    ma.std = [0.043; 0.05; 0.073];
end

%log productivity grid
np = 30; %number of grid points for worker productivity
if opti.type==1
    nmax = 9.35-log(549);  %maximum individual prod
    nmin = 7.45-log(549);  %minimum individual prod
elseif opti.type==2
    nmax = 9.7-log(549);  %maximum individual prod
    nmin = 7.47-log(549);  %minimum individual prod
else 
    nmax = 10.20-log(549);  %maximum individual prod
    nmin = 7.55-log(549);  %minimum individual prod
end
pgrid = linspace(nmin,nmax,np)';   %grid for worker productivity
step = pgrid(2,1)-pgrid(1,1);

%job component
mean_f = 0;
fnodes = 15; %number of grid points
[gamma.n, gamma.w] = Norm(fnodes,mean_f,gamma.std); 
gamma.n = gamma.n-(1/2*(gamma.std^2)); %assure that mean is at 0

%total earnings grid
nc = 6; %number of points
grid_nc = [100; 267*3; 1500; 1611*3; 7500; 11000];
step_nc = diff(grid_nc);
max_nc = grid_nc(end);

%probability to go to a specific job conditional on current job and
%conditional on moving
prob_loss = 1-cumsum(gamma.w); %probability that employee is hired from outside job
aux = (tril(ones(fnodes))')-eye(fnodes,fnodes);
Prob.firm = (repmat(gamma.w',fnodes,1).*aux); 
for tt = 1:fnodes-1 
    Prob.firm(tt,:) = Prob.firm(tt,:)/sum(Prob.firm(tt,:));
end

%probability to go to a specific job conditional on current job and
%a random outside offer (use fact that all movements are up)
aux = (repmat(gamma.w',fnodes,1)); 
Prob.move = zeros(fnodes,fnodes);
for tt = 1:fnodes 
    Prob.move(tt,1:tt-1) = 0;
    Prob.move(tt,tt) = sum(aux(tt,1:tt));
    Prob.move(tt,tt+1:end) = aux(tt,tt+1:end);
end


% Generate transition matrix for random walk
% nnodes = 100;
epsilon.stdu = epsilon.stde;
stepp=diff(pgrid);
bounds=[-Inf; pgrid(1:end-1)+stepp/2; Inf];
bounds(1)=bounds(2)-99999999999;
bounds(end)=bounds(end-1)+99999999999;

%stay in same disability state
trans.emp_stay_y = zeros(np,np); %employed, young
trans.emp_stay_o = zeros(np,np); %employed, old
trans.unemp_stay_y = zeros(np,np); %non-employed, young
trans.unemp_stay_o = zeros(np,np); %non-employed, old
for i = 1:np %state
    for j = 1:np %transition to
        trans.emp_stay_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu,epsilon.stde);
        trans.emp_stay_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2,epsilon.stde);
        trans.unemp_stay_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1,epsilon.stde);
        trans.unemp_stay_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2,epsilon.stde);
    end
end

%move from g to b
trans.emp_gb_y = zeros(np,np); %employed, young
trans.emp_gb_o = zeros(np,np); %employed, old
trans.unemp_gb_y = zeros(np,np); %non-employed, young
trans.unemp_gb_o = zeros(np,np); %non-employed, old
for i = 1:np %state
    for j = 1:np %transition to
        trans.emp_gb_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu-xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu-xi,epsilon.stde);
        trans.emp_gb_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2-xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2-xi,epsilon.stde);
        trans.unemp_gb_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1-xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1-xi,epsilon.stde);
        trans.unemp_gb_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2-xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2-xi,epsilon.stde);
    end
end

%move from b to g
trans.emp_bg_y = zeros(np,np); %employed, young
trans.emp_bg_o = zeros(np,np); %employed, old
trans.unemp_bg_y = zeros(np,np); %non-employed, young
trans.unemp_bg_o = zeros(np,np); %non-employed, old
for i = 1:np %state
    for j = 1:np %transition to
        trans.emp_bg_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu+xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu+xi,epsilon.stde);
        trans.emp_bg_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2+xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+mu2+xi,epsilon.stde);
        trans.unemp_bg_y(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1+xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta1+xi,epsilon.stde);
        trans.unemp_bg_o(j,i) = normcdf(bounds(j+1),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2+xi,epsilon.stde)-normcdf(bounds(j),pgrid(i)-(1/2*(epsilon.stdu^2))+delta2+xi,epsilon.stde);
    end
end



%Newborn productivity
if opti.type ==1
    if opti.ini_ineq==0
        epsilon.stdnewborn = p1_s1_t1.para(5); %innitial dispersion
    else
        epsilon.stdnewborn = p3_s1_t1_recal.para(5);
    end
    if opti.wage==0
        newmean = p1_s1_t1.para(4); %mean log wage
    else
        newmean = p3_s1_t1_recal.para(4); 
    end
elseif opti.type==2
    if opti.ini_ineq==0
        epsilon.stdnewborn = p1_s1_t2.para(5);
    else
        epsilon.stdnewborn = p3_s1_t2_recal.para(5);
    end
    if opti.wage==0
        newmean = p1_s1_t2.para(4);
    else
        newmean = p3_s1_t2_recal.para(4); 
    end
else
    if opti.ini_ineq==0
        epsilon.stdnewborn = p1_s1_t3.para(5); 
    else
        epsilon.stdnewborn = p3_s1_t3_recal.para(5);
    end
    if opti.wage==0
        newmean = p1_s1_t3.para(4); 
    else
        newmean = p3_s1_t3_recal.para(4); 
    end
end

%from wages to earnings
pgrid = pgrid+log(549);
nmin = nmin+log(549);
nmax = nmax+log(549);

% Create productivity distribution for newborns on grid
Prob.Newborn = zeros(np,1);
Prob.Newborn(1,1) = normcdf(pgrid(1),newmean(1,1),epsilon.stdnewborn(1,1));
Prob.Newborn(2:end,1) = diff(normcdf(pgrid,newmean(1,1),epsilon.stdnewborn(1,1)));
Prob.Newborn(end,1) = Prob.Newborn(end,1)+1-normcdf(pgrid(end),newmean(1,1),epsilon.stdnewborn(1,1));
Prob.Newborn(Prob.Newborn(:,1)<10^(-24),1) = 0;
Prob.Newborn(:,1) = Prob.Newborn(:,1)/sum(Prob.Newborn(:,1));
Prob.Newborn_disab = zeros(np,1);
Prob.Newborn_disab(1,1) = normcdf(pgrid(1),newmean(1,1)-xi,epsilon.stdnewborn(1,1));
Prob.Newborn_disab(2:end,1) = diff(normcdf(pgrid,newmean(1,1)-xi,epsilon.stdnewborn(1,1)));
Prob.Newborn_disab(end,1) = Prob.Newborn_disab(end,1)+1-normcdf(pgrid(end),newmean(1,1)-xi,epsilon.stdnewborn(1,1));
Prob.Newborn_disab(Prob.Newborn_disab(:,1)<10^(-24),1) = 0;
Prob.Newborn_disab(:,1) = Prob.Newborn_disab(:,1)/sum(Prob.Newborn_disab(:,1));

%gross earnings
w = exp((repmat(pgrid,1,fnodes))+(repmat(gamma.n',np,1)));


%welfare state
if opti.welfare==0 %baseline welfare state
    fbar_young = 808*3*1.3/1.058; %top income for ff, young
    fbar_old = 645*3*1.3/1.058; %top income for ff, old
    abar = 2000;
    tau_c = exp(0.6132);
    tau_p = 0.8916;
    ff=236*3/1.0508;  %maximum food stamps
    ff_old=165*3/1.058; %maximum food stamps old
    if opti.type==1
        psi_y = [0; p1_s1_t1.para(12)]; %probability to get disability insurance depending on D
        psi_o = [0; p1_s1_t1.para(14)]; %probability to get disability insurance depending on D
    elseif opti.type ==2
        psi_y = [0; p1_s1_t2.para(12)]; 
        psi_o = [0; p1_s1_t2.para(14)]; 
    else
        psi_y = [0; p1_s1_t3.para(12)]; 
        psi_o = [0; p1_s1_t3.para(14)]; 
    end
    rr_b = 0.7;  %replacement rate for benefits 
    bmax = 169*4.3*3*1.1028; %maximum benefits 
    b = min(bmax,rr_b*w);  
    b2 = 1;  
    %social security transfers
    ssinc = zeros(nc,1);
    aux = grid_nc;
    index = aux<=267*3;
    ssinc(index,1) = 0.9*aux(index);
    index = logical((aux>267*3).*(aux<1612*3));
    ssinc(index,1) = 0.9*267*3+0.32*(aux(index)-(267*3));
    index = (aux>1612*3);
    ssinc(index,1) = 0.9*267*3+0.32*((1612*3)-(267*3))+0.15*(aux(index)-(1612*3)); %nc,1
    dinc = ssinc;
    sub_ssinc = max(0,3*340-(ssinc-(3*20)));
elseif opti.welfare==1 %decomposition with change in welafre state
    fbar_young = 18310*1.3/4/1.8305; 
    fbar_old = 14570*1.3/4/1.8305; 
    abar = 2000/1.8305;
    tau_c = exp(0.8713616);
    tau_p = 0.866738;
    ff=463*3/(1.8305);  
    ff_old=367*3/(1.8305);
    if opti.type==1
        psi_y = [0; p3_s1_t1_recal.para(12)]; 
        psi_o = [0; p3_s1_t1_recal.para(14)]; 
    elseif opti.type ==2
        psi_y = [0; p3_s1_t2_recal.para(12)]; 
        psi_o = [0; p3_s1_t2_recal.para(14)]; 
    else
        psi_y = [0; p3_s1_t3_recal.para(12)]; 
        psi_o = [0; p3_s1_t3_recal.para(14)]; 
    end

    rr_b = 0.7;
    bmax = 445*4.3*3/1.8475; 
    b = min(bmax,rr_b*w);  
    b2 = 1;

    %social security transfers
    ssinc = zeros(nc,1);
    aux = grid_nc;
    index = aux<=612*3/1.8293;
    ssinc(index,1) = 0.9*aux(index);
    index = logical((aux>(612*3/1.8293)).*(aux<(3689*3/1.8293)));
    ssinc(index,1) = 0.9*(612*3/1.8293)+0.32*(aux(index)-((612*3/1.8293)));
    index = (aux>(3689*3/1.8293));
    ssinc(index,1) = 0.9*(612*3/1.8293)+0.32*((3689*3/1.8293)-(612*3/1.8293))+0.15*(aux(index)-(3689*3/1.8293)); %nc,1
    dinc = ssinc;
    sub_ssinc = max(0,3*(674/1.9031)-(ssinc-(3*20/1.9031)));
end


    
%% Income variables

%gross variables
subsidy_ssinc = sub_ssinc;
w_gross = w;
b_gross = b; 
b2_gross = b2;
ssinc_gross = ssinc;
dinc_gross = dinc;
sub_ssinc_gross = ssinc+sub_ssinc; %total ss inc if sub_ssinc is received
sub_dinc_gross = dinc+sub_ssinc;

%food stamp transfers
net_w = max(0,0.8*w_gross-(3*122));
net_b = max(0,(b_gross)-(3*122));
net_b2 = max(0,b2_gross-(3*122));
net_d = max(dinc_gross-(3*122),0);
net_sub_d = max(sub_dinc_gross-(3*122),0);
net_ss = max(ssinc_gross-(3*122),0);
net_sub_ss = max(sub_ssinc_gross-(3*122),0);
transfer.w = max(0,ff-(0.3*net_w));
transfer.w(w_gross>fbar_young) = 0; 
transfer.b = max(0,ff-(0.3*net_b));
transfer.b(b_gross>fbar_young) = 0; 
transfer.b2 = max(0,ff-(0.3*net_b2));
transfer.b2(b2>fbar_young) = 0; 
transfer.wel = ff;
transfer.d = max(0,(ff)-(0.3*net_sub_d));
transfer.d(sub_dinc_gross>fbar_young) = 0; 

transfer.w_old = max(0,ff_old-(0.3*net_w));
transfer.w_old(w_gross>fbar_old) = 0; 
transfer.b_old = max(0,ff_old-(0.3*net_b));
transfer.b_old(b_gross>fbar_old) = 0; 
transfer.b2_old = max(0,ff_old-(0.3*net_b2));
transfer.b2_old(b2>fbar_old) = 0; 
transfer.wel_old = ff_old;
transfer.d_old = max(0,(ff_old)-(0.3*net_sub_d));
transfer.d_old(sub_dinc_gross>fbar_old) = 0; 
transfer.ss = max(0,(ff_old)-(0.3*net_sub_ss));
transfer.ss(sub_ssinc_gross>fbar_old) = 0;

%taxes
w = tau_c*((w_gross).^(tau_p));

%taxes on unemployment benefits, social security, and disability insurance
if opti.welfare==0
    for i1 = 1:np
        for i2 = 1:fnodes
            if b_gross(i1,i2)<=(2480/4)
                b(i1,i2) = b_gross(i1,i2);
            elseif b_gross(i1,i2)>(2480/4) && b_gross(i1,i2)<=(3670/4)
                b(i1,i2) = 2480/4 + 0.89*(b_gross(i1,i2)-(2480/4));
            elseif b_gross(i1,i2)>(3670/4) && b_gross(i1,i2)<=(4750/4)
                b(i1,i2) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*(b_gross(i1,i2)-(3670/4));
            elseif b_gross(i1,i2)>(4750/4) && b_gross(i1,i2)<=(7010/4)
                b(i1,i2) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*(b_gross(i1,i2)-(4750/4));
            elseif b_gross(i1,i2)>(7010/4) && b_gross(i1,i2)<=(9170/4)
                b(i1,i2) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*(b_gross(i1,i2)-(7010/4));
            end
        end
    end
    for i1 = 1:nc
        if ssinc_gross(i1)<=(2480/4)
            ssinc(i1) = ssinc_gross(i1);
        elseif ssinc_gross(i1)>(2480/4) && ssinc_gross(i1)<=(3670/4)
            ssinc(i1) = 2480/4 + 0.89*(ssinc_gross(i1)-(2480/4));
        elseif ssinc_gross(i1)>(3670/4) && ssinc_gross(i1)<=(4750/4)
            ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*(ssinc_gross(i1)-(3670/4));
        elseif ssinc_gross(i1)>(4750/4) && ssinc_gross(i1)<=(7010/4)
            ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*(ssinc_gross(i1)-(4750/4));
        elseif ssinc_gross(i1)>(7010/4) && ssinc_gross(i1)<=(9170/4)
            ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*(ssinc_gross(i1)-(7010/4));
        elseif ssinc_gross(i1)>(9170/4) && ssinc_gross(i1)<=(11650/4)
            ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*((9170/4)-(7010/4)) + 0.82*(ssinc_gross(i1)-(9170/4));
        elseif ssinc_gross(i1)>(11650/4) && ssinc_gross(i1)<=(13920/4)
            ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*((9170/4)-(7010/4)) + 0.82*((11650/4)-(9170/4)) + 0.8*(ssinc_gross(i1)-(11650/4));
        end


        if sub_ssinc_gross(i1)<=(2480/4)
            sub_ssinc(i1) = sub_ssinc_gross(i1);
        elseif sub_ssinc_gross(i1)>(2480/4) && sub_ssinc_gross(i1)<=(3670/4)
            sub_ssinc(i1) = 2480/4 + 0.89*(sub_ssinc_gross(i1)-(2480/4));
        elseif sub_ssinc_gross(i1)>(3670/4) && sub_ssinc_gross(i1)<=(4750/4)
            sub_ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*(sub_ssinc_gross(i1)-(3670/4));
        elseif sub_ssinc_gross(i1)>(4750/4) && sub_ssinc_gross(i1)<=(7010/4)
            sub_ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*(sub_ssinc_gross(i1)-(4750/4));
        elseif sub_ssinc_gross(i1)>(7010/4) && sub_ssinc_gross(i1)<=(9170/4)
            sub_ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*(sub_ssinc_gross(i1)-(7010/4));
        elseif sub_ssinc_gross(i1)>(9170/4) && sub_ssinc_gross(i1)<=(11650/4)
            sub_ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*((9170/4)-(7010/4)) + 0.82*(sub_ssinc_gross(i1)-(9170/4));
        elseif sub_ssinc_gross(i1)>(11650/4) && sub_ssinc_gross(i1)<=(13920/4)
            sub_ssinc(i1) = 2480/4 + 0.89*((3670/4)-(2480/4)) + 0.88*((4750/4)-(3670/4)) + 0.85*((7010/4)-(4750/4)) + 0.84*((9170/4)-(7010/4)) + 0.82*((11650/4)-(9170/4)) + 0.8*(sub_ssinc_gross(i1)-(11650/4));
        end
    end
    dinc = ssinc;
    sub_dinc = sub_ssinc;
else %taxes from period 3
    for i1 = 1:np
        for i2 = 1:fnodes
            if b_gross(i1,i2)<=(7550/4/1.8530)
                b(i1,i2) = b_gross(i1,i2);
            elseif b_gross(i1,i2)>(7550/4/1.8530) && b_gross(i1,i2)<=(30650/4/1.8530)
                b(i1,i2) = 7550/4/1.8530 + 0.85*(b_gross(i1,i2)-(7550/4/1.8530));
            elseif b_gross(i1,i2)>(30650/4/1.8530) && b_gross(i1,i2)<=(74200/4/1.8530)
                b(i1,i2) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*(b_gross(i1,i2)-(30650/4/1.8530));
            elseif b_gross(i1,i2)>(74200/4/1.8530) && b_gross(i1,i2)<=(154800/4/1.8530)
                b(i1,i2) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*(b_gross(i1,i2)-(74200/4/1.8530));
            elseif b_gross(i1,i2)>(154800/4/1.8530) && b_gross(i1,i2)<=(336550/4/1.8530)
                b(i1,i2) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*((154800/4/1.8530)-(74200/4/1.8530)) + 0.67*(b_gross(i1,i2)-(154800/4/1.8530));
            end
        end
    end
    for i1 = 1:nc
        if ssinc_gross(i1)<=(7550/4/1.8530)
            ssinc(i1) = ssinc_gross(i1);
        elseif ssinc_gross(i1)>(7550/4/1.8530) && ssinc_gross(i1)<=(30650/4/1.8530)
            ssinc(i1) = 7550/4/1.8530 + 0.85*(ssinc_gross(i1)-(7550/4/1.8530));
        elseif ssinc_gross(i1)>(30650/4/1.8530) && ssinc_gross(i1)<=(74200/4/1.8530)
            ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*(ssinc_gross(i1)-(30650/4/1.8530));
        elseif ssinc_gross(i1)>(74200/4/1.8530) && ssinc_gross(i1)<=(154800/4/1.8530)
            ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*(ssinc_gross(i1)-(74200/4/1.8530));
        elseif ssinc_gross(i1)>(154800/4/1.8530) && ssinc_gross(i1)<=(336550/4/1.8530)
            ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*((154800/4/1.8530)-(74200/4/1.8530)) + 0.67*(ssinc_gross(i1)-(154800/4/1.8530));
        elseif ssinc_gross(i1)>(336550/4/1.8530)
            ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*((154800/4/1.8530)-(74200/4/1.8530)) + 0.67*((336550/4/1.8530)-(154800/4/1.8530)) + 0.65*(ssinc_gross(i1)-(336550/4/1.8530));
        end


        if sub_ssinc_gross(i1)<=(7550/4/1.8530)
            sub_ssinc(i1) = sub_ssinc_gross(i1);
        elseif sub_ssinc_gross(i1)>(7550/4/1.8530) && sub_ssinc_gross(i1)<=(30650/4/1.8530)
            sub_ssinc(i1) = 7550/4/1.8530 + 0.85*(sub_ssinc_gross(i1)-(7550/4/1.8530));
        elseif sub_ssinc_gross(i1)>(30650/4/1.8530) && sub_ssinc_gross(i1)<=(74200/4/1.8530)
            sub_ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*(sub_ssinc_gross(i1)-(30650/4/1.8530));
        elseif sub_ssinc_gross(i1)>(74200/4/1.8530) && sub_ssinc_gross(i1)<=(154800/4/1.8530)
            sub_ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*(sub_ssinc_gross(i1)-(74200/4/1.8530));
        elseif sub_ssinc_gross(i1)>(154800/4/1.8530) && sub_ssinc_gross(i1)<=(336550/4/1.8530)
            sub_ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*((154800/4/1.8530)-(74200/4/1.8530)) + 0.67*(sub_ssinc_gross(i1)-(154800/4/1.8530));
        elseif sub_ssinc_gross(i1)>(336550/4/1.8530)
            sub_ssinc(i1) = 7550/4/1.8530 + 0.85*((30650/4/1.8530)-(7550/4/1.8530)) + 0.75*((74200/4/1.8530)-(30650/4/1.8530)) + 0.72*((154800/4/1.8530)-(74200/4/1.8530)) + 0.67*((336550/4/1.8530)-(154800/4/1.8530)) + 0.65*(sub_ssinc_gross(i1)-(336550/4/1.8530));
        end
    end
    dinc = ssinc;
    sub_dinc = sub_ssinc;
end
% end


%lump-sum transfer received: Unemployed should only receive
%max(b+transfer.b,b2+transfer.b2). Code is
%written, such that he receives b at the end of previous period and b2 + transfer.b2 next period
b = max(0,(b+transfer.b-(b2+transfer.b2)))./R;
b_old = max(0,(b+transfer.b_old-(b2+transfer.b2_old)))./R;



%total income
inc.emp =max(w-fc,0.001);
inc.emp_trans =max(w+transfer.w-fc,0.001);
inc.emp_trans_old =max(w+transfer.w_old-fc,0.001);
inc.dinc = dinc;
inc.dinc_trans = sub_dinc+transfer.d;
inc.dinc_trans_old = sub_dinc+transfer.d_old;
inc.ssinc = ssinc;
inc.ssinc_trans = sub_ssinc+transfer.ss;
inc.wel = 0; %obsolete    
    

%% preallocate memory on the GPU
dims = [na np fnodes nc];

VR_d = gpuArray(zeros(1,dims(1)*dims(4)*retire));
VD_d = gpuArray(zeros(1,dims(1)*dims(4)*disable));
VE_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work));
VE_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work));
VU_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*work));
VU_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*work));
VUJ_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*disable));
VUJ_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*disable));
pol_R_a_d = gpuArray(zeros(1,dims(1)*dims(4)*retire));
pol_UJ_g_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*disable));
pol_UJ_b_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*disable));
pol_U_g_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*work));
pol_U_b_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)*work));
pol_D_a_d = gpuArray(zeros(1,dims(1)*dims(4)*disable));
pol_U_g_s_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(4)*work)));
pol_U_b_s_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(4)*work)));
pol_d_g_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(4)*disable)));
pol_d_b_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(4)*disable)));
pol_E_g_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work));
pol_E_b_a_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work));
pol_E_g_s_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work)));
pol_E_b_s_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work)));
emp_pol_u_g_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work)));
emp_pol_u_b_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*work)));
emp_pol_e_g_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*disable)));
emp_pol_e_b_d = gpuArray(int32(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)*disable)));


agrid_d = gpuArray(agrid');
sgrid_d = gpuArray(sgrid');
pgrid_d = gpuArray(pgrid');
grid_nc_d = gpuArray(grid_nc');
search_costs_u_d = gpuArray(search_costs_u');
search_costs_e_d = gpuArray(search_costs_e');
aprime_d = gpuArray(aprime');
abound_d = gpuArray(int32(abound)'-1);
gamma_w_d = gpuArray(gamma.w');
w_gross_d = gpuArray(w_gross(:)');
b_d = gpuArray(b(:)');
aux = Prob.move';
prob_move_d = gpuArray(aux(:)');
inc_emp_d = gpuArray((inc.emp(:))');
inc_emp_trans_d = gpuArray((inc.emp_trans(:))');
inc_emp_trans_old_d = gpuArray((inc.emp_trans_old(:))');
dinc_d = gpuArray(dinc');
dinc_trans_d = gpuArray(inc.dinc_trans');
dinc_trans_old_d = gpuArray(inc.dinc_trans_old');
ssinc_d = gpuArray(inc.ssinc');
ssinc_trans_d = gpuArray(inc.ssinc_trans');



upper1_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
upper1_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
upper2_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
upper2_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
EV_ue_o_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));
EV_ue_o_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));
E_ee_f2_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_f2_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_r2_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_r2_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_f1_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_f1_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_r1_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_ee_r1_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_e_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_e_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_u_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_u_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_f_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_f_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_r_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_r_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(3)*dims(4)));
E_e_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_u_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_f_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_r_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_e_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_u_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_f_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
E_r_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(3)*dims(4)));
U_n_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(4)));
U_n_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(4)));
U_f_g_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(4)));
U_f_b_inter_d = gpuArray(zeros(1,nap*dims(2)*dims(4)));
U_n_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));
U_n_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));
U_f_g_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));
U_f_b_d = gpuArray(zeros(1,dims(1)*dims(2)*dims(4)));

index_R = gpuArray(int32([dims(1) dims(4) nap]));
index_U = gpuArray(int32([dims(1) dims(2) dims(4) ns nap]));
index_E = gpuArray(int32([dims(1) dims(2) dims(3) dims(4) dims(3)*dims(4) ns nap nap*nc]));
index_life_d = gpuArray(int32([work disable retire]));


%% GPU



%value function retired

%last period
t=0;
k = parallel.gpu.CUDAKernel('val_fun_ret_last.ptx','val_fun_ret_last.cu');
k.GridSize = [dims(4) 1 1]; %number of blocks
k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
par_d = gpuArray([R beta theta abar]);
[VR_d] = feval(k,VR_d,agrid_d,ssinc_trans_d,index_R,par_d,gpuArray(int32(retire - 1)));


%loop over remaining periods
t=1;
k = parallel.gpu.CUDAKernel('val_fun_ret.ptx','val_fun_ret.cu');
k.GridSize = [dims(2) 1 1]; %number of blocks
k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
while t<retire
    par_d = gpuArray([R beta theta abar]);
    [VR_d, pol_R_a_d] = feval(k,VR_d,pol_R_a_d,agrid_d,aprime_d,abound_d,ssinc_d,ssinc_trans_d,index_R,par_d,int32(retire - t - 1));
    t=t+1;
end




%working life with option of disability
while t < retire+(disable)

    %productivity transition matrix
    if t < retire+48
        trans.emp_stay = trans.emp_stay_o;
        trans.unemp_stay = trans.unemp_stay_o;
        trans.emp_gb = trans.emp_gb_o;
        trans.unemp_gb = trans.unemp_gb_o;
        trans.emp_bg = trans.emp_bg_o;
        trans.unemp_bg = trans.unemp_bg_o;
        destruct = destruct_age(end);
    else
        trans.emp_stay = trans.emp_stay_y;
        trans.unemp_stay = trans.unemp_stay_y;
        trans.emp_gb = trans.emp_gb_y;
        trans.unemp_gb = trans.unemp_gb_y;
        trans.emp_bg = trans.emp_bg_y;
        trans.unemp_bg = trans.unemp_bg_y;
        if t< retire+108
            destruct = destruct_age(2);
        else
            destruct = destruct_age(1);
        end
    end


    trans_u_stay_d = gpuArray(trans.unemp_stay(:));
    trans_emp_stay_d = gpuArray(trans.emp_stay(:));
    trans_u_bg_d = gpuArray(trans.unemp_bg(:));
    trans_emp_bg_d = gpuArray(trans.emp_bg(:));
    trans_u_gb_d = gpuArray(trans.unemp_gb(:));
    trans_emp_gb_d = gpuArray(trans.emp_gb(:));
    
    %probability to get DI
    if t < retire+(12*4)
        psi = psi_o;
    else
        psi = psi_y;
    end

    %income including food stamps
    if t < retire+48
        dinc_trans_d_aux = dinc_trans_old_d;
        transfer_b2 = transfer.b2_old;
        inc_emp_trans_d_aux = inc_emp_trans_old_d;
    else
        dinc_trans_d_aux = dinc_trans_d;
        transfer_b2 = transfer.b2;
        inc_emp_trans_d_aux = inc_emp_trans_d;
    end

    if t==retire   

        %value function disabled
        k = parallel.gpu.CUDAKernel('val_fun_d_last.ptx','val_fun_d_last.cu');
        k.GridSize = [dims(4) 1 1]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta theta abar]);
        [VD_d,pol_D_a_d] = feval(k,VD_d,pol_D_a_d,VR_d(1:na*nc),agrid_d,aprime_d,abound_d,dinc_d,dinc_trans_d_aux,index_R,par_d,int32(retire + disable - t - 1));

        %value function unemployed (good health)
        k = parallel.gpu.CUDAKernel('val_fun_u_last.ptx','val_fun_u_last.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta b2 transfer_b2 theta abar]);
        [VU_g_d,pol_U_g_a_d,pol_U_g_s_d] = feval(k,VU_g_d,pol_U_g_a_d,pol_U_g_s_d,VR_d(1:na*nc),agrid_d,aprime_d,abound_d,grid_nc_d,index_U,index_life_d,par_d,int32(retire + work - t - 1));


        %value function unemployed (bad health)
        k = parallel.gpu.CUDAKernel('val_fun_u_copy.ptx','val_fun_u_copy.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [VU_b_d,pol_U_b_a_d,pol_U_b_s_d] = feval(k,VU_b_d,pol_U_b_a_d,pol_U_b_s_d,VU_g_d,pol_U_g_a_d,pol_U_g_s_d,index_U,int32(retire + work - t - 1));


        %value function just unemployed (good health)
        k = parallel.gpu.CUDAKernel('val_fun_uj_last.ptx','val_fun_uj_last.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [VUJ_g_d,pol_UJ_g_a_d] = feval(k,VUJ_g_d,pol_UJ_g_a_d,VU_g_d,pol_U_g_a_d,index_U,index_life_d,int32(retire + work - t - 1));


        %value function just unemployed (bad health)
        k = parallel.gpu.CUDAKernel('val_fun_uj_last.ptx','val_fun_uj_last.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [VUJ_b_d,pol_UJ_b_a_d] = feval(k,VUJ_b_d,pol_UJ_b_a_d,VU_b_d,pol_U_b_a_d,index_U,index_life_d,int32(retire + work - t - 1));


        %value function employed (good health)
        k = parallel.gpu.CUDAKernel('val_fun_e_last.ptx','val_fun_e_last.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta theta phi destruct lambda_d disab_c abar]);
        [VE_g_d,pol_E_g_a_d,pol_E_g_s_d] = feval(k,VE_g_d,pol_E_g_a_d,pol_E_g_s_d,VR_d(1:na*nc),agrid_d,aprime_d,grid_nc_d,w_gross_d,inc_emp_d,inc_emp_trans_d_aux,index_E,index_life_d,par_d,int32(retire + work - t - 1));


        %value function employed (bad health)
        k = parallel.gpu.CUDAKernel('val_fun_e_copy.ptx','val_fun_e_copy.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [VE_b_d,pol_E_b_a_d,pol_E_b_s_d] = feval(k,VE_b_d,pol_E_b_a_d,pol_E_b_s_d,VE_g_d,pol_E_g_a_d,pol_E_g_s_d,index_E,int32(retire + work - t - 1));


    else    

        %value function disabled
        k = parallel.gpu.CUDAKernel('val_fun_ret.ptx','val_fun_ret.cu');
        k.GridSize = [dims(4) 1 1]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta theta abar]);
        [VD_d, pol_D_a_d] = feval(k,VD_d,pol_D_a_d,agrid_d,aprime_d,abound_d,dinc_d,dinc_trans_d_aux,index_R,par_d,int32(retire + disable - t - 1));


        %employment policy unemployed in good health (defined on states tomorrow)
        k = parallel.gpu.CUDAKernel('U_emp_pol.ptx','U_emp_pol.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [emp_pol_u_g_d,upper1_g_d] = feval(k,emp_pol_u_g_d,upper1_g_d,VU_g_d,VE_g_d,index_E,int32(retire + work - t - 1));


        %employment policy unemployed in bad health (defined on states tomorrow)
        k = parallel.gpu.CUDAKernel('U_emp_pol.ptx','U_emp_pol.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [emp_pol_u_b_d,upper1_b_d] = feval(k,emp_pol_u_b_d,upper1_b_d,VU_b_d,VE_b_d,index_E,int32(retire + work - t - 1));


        %expected value of a job offer in good health
        k = parallel.gpu.CUDAKernel('upper1_gamma.ptx','upper1_gamma.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [EV_ue_o_g_d] = feval(k,EV_ue_o_g_d,upper1_g_d,gamma_w_d,index_E);


        %expected value of a job offer in bad health
        k = parallel.gpu.CUDAKernel('upper1_gamma.ptx','upper1_gamma.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [EV_ue_o_b_d] = feval(k,EV_ue_o_b_d,upper1_b_d,gamma_w_d,index_E);


        %productivity transition unemployed
        k = parallel.gpu.CUDAKernel('prod_trans_u.ptx','prod_trans_u.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([pi_gb(end-(t-retire)) pi_bg(end-(t-retire))]);
        [U_n_g_d,U_f_g_d,U_n_b_d,U_f_b_d] = feval(k,U_n_g_d,U_f_g_d,U_n_b_d,U_f_b_d,EV_ue_o_g_d,VU_g_d,EV_ue_o_b_d,VU_b_d,trans_u_stay_d,trans_u_gb_d,trans_u_bg_d,par_d,index_E,int32(retire + work - t - 1));


        %2D interpolation good health (for achoice (nap), gird_nc (nc)). the
        %interpolated values are nap*np*nc
        k = parallel.gpu.CUDAKernel('u_inter.ptx','u_inter.cu');
        k.GridSize = [1 nap dims(4)]; %number of blocks
        k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
        [U_n_g_inter_d,U_f_g_inter_d] = feval(k,U_n_g_inter_d,U_f_g_inter_d,U_n_g_d,U_f_g_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


        %2D interpolation bad health (for achoice (nap), gird_nc (nc)). the
        %interpolated values are nap*np*nc
        k = parallel.gpu.CUDAKernel('u_inter.ptx','u_inter.cu');
        k.GridSize = [1 nap dims(4)]; %number of blocks
        k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
        [U_n_b_inter_d,U_f_b_inter_d] = feval(k,U_n_b_inter_d,U_f_b_inter_d,U_n_b_d,U_f_b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


        %value function unemployed good health
        k = parallel.gpu.CUDAKernel('val_fun_u.ptx','val_fun_u.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta b2 transfer_b2 theta abar]);
        [VU_g_d,pol_U_g_a_d,pol_U_g_s_d] = feval(k,VU_g_d,pol_U_g_a_d,pol_U_g_s_d,U_n_g_inter_d,U_f_g_inter_d,agrid_d,aprime_d,grid_nc_d,sgrid_d,search_costs_u_d,index_E,index_life_d,par_d,int32(retire + work - t - 1));


        %value function unemployed bad health
        k = parallel.gpu.CUDAKernel('val_fun_u.ptx','val_fun_u.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta b2 transfer_b2 theta abar]);
        [VU_b_d,pol_U_b_a_d,pol_U_b_s_d] = feval(k,VU_b_d,pol_U_b_a_d,pol_U_b_s_d,U_n_b_inter_d,U_f_b_inter_d,agrid_d,aprime_d,grid_nc_d,sgrid_d,search_costs_u_d,index_E,index_life_d,par_d,int32(retire + work - t - 1));



        %value function just unemployed good health
        k = parallel.gpu.CUDAKernel('val_fun_UJ.ptx','val_fun_UJ.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta b2 transfer_b2 theta psi(1) abar]);
        [VUJ_g_d,pol_UJ_g_a_d,pol_d_g_d] = feval(k,VUJ_g_d,pol_UJ_g_a_d,pol_d_g_d,pol_U_g_s_d,VD_d,U_n_g_inter_d,U_f_g_inter_d,grid_nc_d,agrid_d,sgrid_d,aprime_d,abound_d,search_costs_u_d,index_U,index_life_d,par_d,int32(retire + work - t - 1));


        %value function just unemployed bad health
        k = parallel.gpu.CUDAKernel('val_fun_UJ.ptx','val_fun_UJ.cu');
        k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta b2 transfer_b2 theta psi(2) abar]);
        [VUJ_b_d,pol_UJ_b_a_d,pol_d_b_d] = feval(k,VUJ_b_d,pol_UJ_b_a_d,pol_d_b_d,pol_U_b_s_d,VD_d,U_n_b_inter_d,U_f_b_inter_d,grid_nc_d,agrid_d,sgrid_d,aprime_d,abound_d,search_costs_u_d,index_U,index_life_d,par_d,int32(retire + work - t - 1));



        
        %employment policy for employed eligible to apply for DI good health (defined on states
        %tomorrow), otherwise use emp_pol_u and upper1
        k = parallel.gpu.CUDAKernel('E_emp_pol.ptx','E_emp_pol.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [emp_pol_e_g_d,upper2_g_d] = feval(k,emp_pol_e_g_d,upper2_g_d,VUJ_g_d,VE_g_d,index_E,index_life_d,int32(retire + work - t - 1));


        %employment policy for employed eligible to apply for DI bad health (defined on states
        %tomorrow), otherwise use emp_pol_u and upper1
        k = parallel.gpu.CUDAKernel('E_emp_pol.ptx','E_emp_pol.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [emp_pol_e_b_d,upper2_b_d] = feval(k,emp_pol_e_b_d,upper2_b_d,VUJ_b_d,VE_b_d,index_E,index_life_d,int32(retire + work - t - 1));


        %values of on-the job and reallocation offers in good health (for each state, value of particular offer times its probability)
        k = parallel.gpu.CUDAKernel('upper2_gamma.ptx','upper2_gamma.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [E_ee_f2_g_d,E_ee_r2_g_d,E_ee_f1_g_d,E_ee_r1_g_d] = feval(k,E_ee_f2_g_d,E_ee_r2_g_d,E_ee_f1_g_d,E_ee_r1_g_d,upper1_g_d,upper2_g_d,gamma_w_d,prob_move_d,index_E);


        %values of on-the job and reallocation offers in bad health (for each state, value of particular offer times its probability)
        k = parallel.gpu.CUDAKernel('upper2_gamma.ptx','upper2_gamma.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        [E_ee_f2_b_d,E_ee_r2_b_d,E_ee_f1_b_d,E_ee_r1_b_d] = feval(k,E_ee_f2_b_d,E_ee_r2_b_d,E_ee_f1_b_d,E_ee_r1_b_d,upper1_b_d,upper2_b_d,gamma_w_d,prob_move_d,index_E);


        %productivity transitions
        k = parallel.gpu.CUDAKernel('prod_trans_e.ptx','prod_trans_e.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([disab_c pi_gb(end-(t-retire)) pi_bg(end-(t-retire))]);
        [E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d] = feval(k,E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d...
            ,VUJ_g_d,VUJ_b_d,upper2_g_d,upper2_b_d,E_ee_f2_g_d,E_ee_f2_b_d,E_ee_r2_g_d,E_ee_r2_b_d,VU_g_d,VU_b_d,upper1_g_d,upper1_b_d...
            ,E_ee_f1_g_d,E_ee_f1_b_d,E_ee_r1_g_d,E_ee_r1_b_d,pgrid_d,trans_emp_stay_d,trans_emp_gb_d,trans_emp_bg_d,par_d,index_E,index_life_d,int32(retire + work - t - 1));



        %2D interpolation for good health (for achoice (nap), gird_nc (nc),
        %wage(np*nodes)). the interpolated values are nap*nc*np*fnodes.
        %(Wage is time-invariant, could be optimized)
        k = parallel.gpu.CUDAKernel('e_inter.ptx','e_inter.cu');
        k.GridSize = [1 nap*nc dims(3)]; %number of blocks
        k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
        [E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d] = feval(k,E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d,E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,w_gross_d,b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


        %2D interpolation for bad health (for achoice (nap), gird_nc (nc),
        %wage(np*nodes)). the interpolated values are nap*nc*np*fnodes.
        %(Wage is time-invariant, could be optimized)
        k = parallel.gpu.CUDAKernel('e_inter.ptx','e_inter.cu');
        k.GridSize = [1 nap*nc dims(3)]; %number of blocks
        k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
        [E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d] = feval(k,E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d,w_gross_d,b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


        %value function employed good health
        k = parallel.gpu.CUDAKernel('val_fun_E.ptx','val_fun_E.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta theta phi destruct lambda_d abar]);
        [VE_g_d,pol_E_g_a_d,pol_E_g_s_d] = feval(k,VE_g_d,pol_E_g_a_d,pol_E_g_s_d,E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d,agrid_d,grid_nc_d,abound_d,sgrid_d,search_costs_e_d,aprime_d,inc_emp_d,inc_emp_trans_d_aux,index_E,par_d,int32(retire + work - t - 1));


        %value function employed bad health
        k = parallel.gpu.CUDAKernel('val_fun_E.ptx','val_fun_E.cu');
        k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
        k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
        par_d = gpuArray([R beta theta phi destruct lambda_d abar]);
        [VE_b_d,pol_E_b_a_d,pol_E_b_s_d] = feval(k,VE_b_d,pol_E_b_a_d,pol_E_b_s_d,E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d,agrid_d,grid_nc_d,abound_d,sgrid_d,search_costs_e_d,aprime_d,inc_emp_d,inc_emp_trans_d_aux,index_E,par_d,int32(retire + work - t - 1));



    end


    t=t+1;

end



%working without disability
while t < life

    %productivity transition matrix
    if t < retire+48
        trans.emp_stay = trans.emp_stay_o;
        trans.unemp_stay = trans.unemp_stay_o;
        trans.emp_gb = trans.emp_gb_o;
        trans.unemp_gb = trans.unemp_gb_o;
        trans.emp_bg = trans.emp_bg_o;
        trans.unemp_bg = trans.unemp_bg_o;
        destruct = destruct_age(end);
    else
        trans.emp_stay = trans.emp_stay_y;
        trans.unemp_stay = trans.unemp_stay_y;
        trans.emp_gb = trans.emp_gb_y;
        trans.unemp_gb = trans.unemp_gb_y;
        trans.emp_bg = trans.emp_bg_y;
        trans.unemp_bg = trans.unemp_bg_y;
        if t< retire+108
            destruct = destruct_age(2);
        else
            destruct = destruct_age(1);
        end
    end

    trans_u_stay_d = gpuArray(trans.unemp_stay(:));
    trans_emp_stay_d = gpuArray(trans.emp_stay(:));
    trans_u_bg_d = gpuArray(trans.unemp_bg(:));
    trans_emp_bg_d = gpuArray(trans.emp_bg(:));
    trans_u_gb_d = gpuArray(trans.unemp_gb(:));
    trans_emp_gb_d = gpuArray(trans.emp_gb(:));


    %employment policy unemployed in good health (defined on states tomorrow)
    k = parallel.gpu.CUDAKernel('U_emp_pol.ptx','U_emp_pol.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [emp_pol_u_g_d,upper1_g_d] = feval(k,emp_pol_u_g_d,upper1_g_d,VU_g_d,VE_g_d,index_E,int32(retire + work - t - 1));


    %employment policy unemployed in bad health (defined on states tomorrow)
    k = parallel.gpu.CUDAKernel('U_emp_pol.ptx','U_emp_pol.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [emp_pol_u_b_d,upper1_b_d] = feval(k,emp_pol_u_b_d,upper1_b_d,VU_b_d,VE_b_d,index_E,int32(retire + work - t - 1));



    %expected value of a job offer in good health
    k = parallel.gpu.CUDAKernel('upper1_gamma.ptx','upper1_gamma.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [EV_ue_o_g_d] = feval(k,EV_ue_o_g_d,upper1_g_d,gamma_w_d,index_E);


    %expected value of a job offer in bad health
    k = parallel.gpu.CUDAKernel('upper1_gamma.ptx','upper1_gamma.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [EV_ue_o_b_d] = feval(k,EV_ue_o_b_d,upper1_b_d,gamma_w_d,index_E);


    %productivity transition unemployed
    k = parallel.gpu.CUDAKernel('prod_trans_u.ptx','prod_trans_u.cu');
    k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([pi_gb(end-(t-retire)) pi_bg(end-(t-retire))]);
    [U_n_g_d,U_f_g_d,U_n_b_d,U_f_b_d] = feval(k,U_n_g_d,U_f_g_d,U_n_b_d,U_f_b_d,EV_ue_o_g_d,VU_g_d,EV_ue_o_b_d,VU_b_d,trans_u_stay_d,trans_u_gb_d,trans_u_bg_d,par_d,index_E,int32(retire + work - t - 1));



    %2D interpolation good health (for achoice (nap), gird_nc (nc)). the
    %interpolated values are nap*np*nc
    k = parallel.gpu.CUDAKernel('u_inter.ptx','u_inter.cu');
    k.GridSize = [1 nap dims(4)]; %number of blocks
    k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
    [U_n_g_inter_d,U_f_g_inter_d] = feval(k,U_n_g_inter_d,U_f_g_inter_d,U_n_g_d,U_f_g_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


    %2D interpolation bad health (for achoice (nap), gird_nc (nc)). the
    %interpolated values are nap*np*nc
    k = parallel.gpu.CUDAKernel('u_inter.ptx','u_inter.cu');
    k.GridSize = [1 nap dims(4)]; %number of blocks
    k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
    [U_n_b_inter_d,U_f_b_inter_d] = feval(k,U_n_b_inter_d,U_f_b_inter_d,U_n_b_d,U_f_b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));



    %value function unemployed good health
    k = parallel.gpu.CUDAKernel('val_fun_u.ptx','val_fun_u.cu');
    k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([R beta b2 transfer.b2 theta abar]);
    [VU_g_d,pol_U_g_a_d,pol_U_g_s_d] = feval(k,VU_g_d,pol_U_g_a_d,pol_U_g_s_d,U_n_g_inter_d,U_f_g_inter_d,agrid_d,aprime_d,grid_nc_d,sgrid_d,search_costs_u_d,index_E,index_life_d,par_d,int32(retire + work - t - 1));


    %value function unemployed bad health
    k = parallel.gpu.CUDAKernel('val_fun_u.ptx','val_fun_u.cu');
    k.GridSize = [dims(2) 1 dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([R beta b2 transfer.b2 theta abar]);
    [VU_b_d,pol_U_b_a_d,pol_U_b_s_d] = feval(k,VU_b_d,pol_U_b_a_d,pol_U_b_s_d,U_n_b_inter_d,U_f_b_inter_d,agrid_d,aprime_d,grid_nc_d,sgrid_d,search_costs_u_d,index_E,index_life_d,par_d,int32(retire + work - t - 1));



    %values of on-the job and reallocation offers in good health (for each state, value of particular offer times its probability)
    k = parallel.gpu.CUDAKernel('upper3_gamma.ptx','upper3_gamma.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [E_ee_f1_g_d,E_ee_r1_g_d] = feval(k,E_ee_f1_g_d,E_ee_r1_g_d,upper1_g_d,gamma_w_d,prob_move_d,index_E);


    %values of on-the job and reallocation offers in bad health (for each state, value of particular offer times its probability)
    k = parallel.gpu.CUDAKernel('upper3_gamma.ptx','upper3_gamma.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    [E_ee_f1_b_d,E_ee_r1_b_d] = feval(k,E_ee_f1_b_d,E_ee_r1_b_d,upper1_b_d,gamma_w_d,prob_move_d,index_E);


    %productivity transitions
    k = parallel.gpu.CUDAKernel('prod_trans_e2.ptx','prod_trans_e2.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([disab_c pi_gb(end-(t-retire)) pi_bg(end-(t-retire))]);
    [E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d] = feval(k,E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d...
        ,VU_g_d,VU_b_d,upper1_g_d,upper1_b_d,E_ee_f1_g_d,E_ee_f1_b_d,E_ee_r1_g_d,E_ee_r1_b_d,pgrid_d...
        ,trans_emp_stay_d,trans_emp_gb_d,trans_emp_bg_d,par_d,index_E,index_life_d,int32(retire + work - t - 1));


    %2D interpolation for good health (for achoice (nap), gird_nc (nc),
    %wage(np*nodes)). the interpolated values are nap*nc*np*fnodes.
    %(Wage is time-invariant, could be optimized)
    k = parallel.gpu.CUDAKernel('e_inter.ptx','e_inter.cu');
    k.GridSize = [1 nap*nc dims(3)]; %number of blocks
    k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
    [E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d] = feval(k,E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d,E_e_g_d,E_u_g_d,E_f_g_d,E_r_g_d,w_gross_d,b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));

    
    %2D interpolation for bad health (for achoice (nap), gird_nc (nc),
    %wage(np*nodes)). the interpolated values are nap*nc*np*fnodes.
    %(Wage is time-invariant, could be optimized)
    k = parallel.gpu.CUDAKernel('e_inter.ptx','e_inter.cu');
    k.GridSize = [1 nap*nc dims(3)]; %number of blocks
    k.ThreadBlockSize = [dims(2) 1 1]; %number of threads
    [E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d] = feval(k,E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d,E_e_b_d,E_u_b_d,E_f_b_d,E_r_b_d,w_gross_d,b_d,agrid_d,grid_nc_d,aprime_d,abound_d,index_E,int32(retire + work - t - 1));


    %value function employed good health
    k = parallel.gpu.CUDAKernel('val_fun_E.ptx','val_fun_E.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([R beta theta phi destruct lambda_d abar]);
    [VE_g_d,pol_E_g_a_d,pol_E_g_s_d] = feval(k,VE_g_d,pol_E_g_a_d,pol_E_g_s_d,E_e_g_inter_d,E_u_g_inter_d,E_f_g_inter_d,E_r_g_inter_d,agrid_d,grid_nc_d,abound_d,sgrid_d,search_costs_e_d,aprime_d,inc_emp_d,inc_emp_trans_d,index_E,par_d,int32(retire + work - t - 1));


    %value function employed bad health
    k = parallel.gpu.CUDAKernel('val_fun_E.ptx','val_fun_E.cu');
    k.GridSize = [dims(2) 1 dims(3)*dims(4)]; %number of blocks
    k.ThreadBlockSize = [1 dims(1) 1]; %number of threads
    par_d = gpuArray([R beta theta phi destruct lambda_d abar]);
    [VE_b_d,pol_E_b_a_d,pol_E_b_s_d] = feval(k,VE_b_d,pol_E_b_a_d,pol_E_b_s_d,E_e_b_inter_d,E_u_b_inter_d,E_f_b_inter_d,E_r_b_inter_d,agrid_d,grid_nc_d,abound_d,sgrid_d,search_costs_e_d,aprime_d,inc_emp_d,inc_emp_trans_d,index_E,par_d,int32(retire + work - t - 1));



    t = t+1;
end
done=1;



%keep only period 1 value functions
VU_g = gather(VU_g_d);
VU_g = reshape(VU_g,[dims(1),dims(2),dims(4),work]);
VU_b = gather(VU_b_d);
VU_b = reshape(VU_b,[dims(1),dims(2),dims(4),work]);
VE_g = gather(VE_g_d);
VE_g = reshape(VE_g,[dims(1),dims(2),dims(3),dims(4),work]);
VE_b = gather(VE_b_d);
VE_b = reshape(VE_b,[dims(1),dims(2),dims(3),dims(4),work]);
VE_g = VE_g(:,:,:,1,1);
VU_g = VU_g(:,:,1,1);
VE_b = VE_b(:,:,:,1,1);
VU_b = VU_b(:,:,1,1);

clear VU_g_d VU_b_d VE_g_d VE_b_d
clear abound_d agrid_d aprime_d E_e_d E_e_inter_d E_ee_f1_d E_ee_f2_d E_ee_r1_d E_ee_r2_d
clear E_f_d E_f_inter_d E_r_d E_r_inter_d E_u_d E_u_inter_d EV_ue_o_d gamma_w_d grid_nc_d
clear inc_dinc_d inc_emp_d inc_ssinc_d index_E index_life_d index_R index_U par_d pgrid_d
clear prob_move_d search_costs_e_d search_costs_u_d sgrid_d trans_emp_d trans_u_d U_f_d
clear U_f_inter_d U_n_d U_n_inter_d upper1_d upper2_d w_d



%%
%read out policy functions and copy back to CPU memory
pol_U_g_s = gather(pol_U_g_s_d);
pol_U_g_s = reshape(pol_U_g_s,[dims(1),dims(2),dims(4),work])+1;
pol_U_b_s = gather(pol_U_b_s_d);
pol_U_b_s = reshape(pol_U_b_s,[dims(1),dims(2),dims(4),work])+1;
pol_E_g_s = gather(pol_E_g_s_d);
pol_E_g_s = reshape(pol_E_g_s,[dims(1),dims(2),dims(3),dims(4),work])+1;
pol_E_b_s = gather(pol_E_b_s_d);
pol_E_b_s = reshape(pol_E_b_s,[dims(1),dims(2),dims(3),dims(4),work])+1;
emp_pol.u_g = gather(emp_pol_u_g_d);
emp_pol.u_g = reshape(emp_pol.u_g,[dims(1),dims(2),dims(3),dims(4),work]);
emp_pol.u_b = gather(emp_pol_u_b_d);
emp_pol.u_b = reshape(emp_pol.u_b,[dims(1),dims(2),dims(3),dims(4),work]);
emp_pol.e_g = gather(emp_pol_e_g_d);
emp_pol.e_g = reshape(emp_pol.e_g,[dims(1),dims(2),dims(3),dims(4),disable]);
emp_pol.e_b = gather(emp_pol_e_b_d);
emp_pol.e_b = reshape(emp_pol.e_b,[dims(1),dims(2),dims(3),dims(4),disable]);
d_pol_g = gather(pol_d_g_d);
d_pol_g = reshape(d_pol_g,[dims(1),dims(2),dims(4),disable]);
d_pol_b = gather(pol_d_b_d);
d_pol_b = reshape(d_pol_b,[dims(1),dims(2),dims(4),disable]);
policyU_g = gather(pol_U_g_a_d);
policyU_g = reshape(policyU_g,[dims(1),dims(2),dims(4),work]);
policyU_b = gather(pol_U_b_a_d);
policyU_b = reshape(policyU_b,[dims(1),dims(2),dims(4),work]);
policyE_g = gather(pol_E_g_a_d);
policyE_g = reshape(policyE_g,[dims(1),dims(2),dims(3),dims(4),work]);
policyE_b = gather(pol_E_b_a_d);
policyE_b = reshape(policyE_b,[dims(1),dims(2),dims(3),dims(4),work]);
policyUJ_g = gather(pol_UJ_g_a_d);
policyUJ_g = reshape(policyUJ_g,[dims(1),dims(2),dims(4),disable]);
policyUJ_b = gather(pol_UJ_b_a_d);
policyUJ_b = reshape(policyUJ_b,[dims(1),dims(2),dims(4),disable]);
policyD = gather(pol_D_a_d);
policyD = reshape(policyD,[dims(1),dims(4),disable]);
policyR = gather(pol_R_a_d);
policyR = reshape(policyR,[dims(1),dims(4),retire]);


%translate policy function into search grid
policyE_g_s_aux = zeros(size(pol_E_g_s));
policyE_b_s_aux = zeros(size(pol_E_b_s));
policyU_g_s_aux = zeros(size(pol_U_g_s));
policyU_b_s_aux = zeros(size(pol_U_b_s));
for t1 = 1:work
    for j = 1:nc
        policyE_g_s_aux(:,:,:,j,t1) = sgrid(pol_E_g_s(:,:,:,j,t1));
        policyE_b_s_aux(:,:,:,j,t1) = sgrid(pol_E_b_s(:,:,:,j,t1));
        policyU_g_s_aux(:,:,j,t1) = sgrid(pol_U_g_s(:,:,j,t1));
        policyU_b_s_aux(:,:,j,t1) = sgrid(pol_U_b_s(:,:,j,t1));
    end
end

policyE_g_s = policyE_g_s_aux;
policyE_b_s = policyE_b_s_aux;
policyU_g_s = policyU_g_s_aux;
policyU_b_s = policyU_b_s_aux;
clear policyE_g_s_aux policyE_b_s_aux policyU_g_s_aux policyU_b_s_aux
%% Calibration of subset of parameters keeping model solution fixed

T = work;
H=ceil(7000);


%change dimensions of policies to speed up simulation
policyE_g = permute(policyE_g,[1 2 4 3 5]);
policyE_b = permute(policyE_b,[1 2 4 3 5]);
policyE_g_s = permute(policyE_g_s,[1 2 4 3 5]);
policyE_b_s = permute(policyE_b_s,[1 2 4 3 5]);
emp_pol.e_g = permute(emp_pol.e_g,[1 2 4 3 5]);
emp_pol.e_b = permute(emp_pol.e_b,[1 2 4 3 5]);
emp_pol.u_g = permute(emp_pol.u_g,[1 2 4 3 5]);
emp_pol.u_b = permute(emp_pol.u_b,[1 2 4 3 5]);

if opti.cali%shall targets be calibrated 
    
    crit.cali = 1
    tol.cali = 0.04;
    count=0;
    while crit.cali > tol.cali && count<=20
        count = count+1;
        
        rand('seed',21424);  
        randn('seed',85796);
        
        %find the lowest firm type a worker is willing to accept
        % aux = newmean+2*epsilon.stdnewborn; %a high initial productivbity draw
        % aux = find(pgrid>aux,1,'first')-1;
        % min_firm = find(emp_pol.u_g(1,aux,1,:,1)==1,1,'first');

        min_prod_e = pgrid(find(emp_pol.u_g(1,:,1,12,1)==1,1,'first')); %minimum productivity to accept employment at 75th percentile firm

        prod_initial = min(max(nmin,epsilon.stdnewborn*randn(H,1)+newmean),nmax); %random numbers for initial asset distribution
        prod_initial_e = prod_initial; %truncated log normal for the employed
        for i1=1:H
            if prod_initial_e(i1)<min_prod_e
                control = 0;
                while control == 0
                    aux = min(max(nmin,epsilon.stdnewborn*randn(1,1)+newmean),nmax);
                    if aux >= min_prod_e
                        prod_initial_e(i1) = aux;
                        control = 1;
                    end
                end
            end
        end
        prod_shock = epsilon.stde*randn(H,T)-(1/2*(epsilon.stdu^2)); %productivity shocks
        
        %simulate
        panel = simulation_mex(int32(H),int32(T),int32(na),int32(np),int32(nc),int32(fnodes)...
            ,destruct_age,prod_initial,prod_shock...
            ,gamma.w,agrid,pgrid,grid_nc,mu,mu2,delta1,amin,amax,nmin,nmax...
            ,w_gross,transfer.w,inc.wel,b,inc.dinc,inc.dinc_trans,inc.ssinc,inc.ssinc_trans,R,int32(work),int32(disable),psi_y,psi_o...
            ,policyU_g,double(policyU_g_s),policyE_g,double(policyE_g_s),policyUJ_g,policyU_b,double(policyU_b_s),policyE_b,double(policyE_b_s),policyUJ_b...
            ,policyD,policyR(:,:,1),double(emp_pol.e_g),double(emp_pol.u_g),double(emp_pol.e_b),double(emp_pol.u_b)...
            ,double(d_pol_g),double(d_pol_b),asset_ini,tau_p,tau_c,disab_c,b2,transfer.b2,delta2,lambda_d,ini_emp,flip(prob_loss)...
            ,pi_gb,pi_bg,abar,ini_disab_u,xi,fc,prod_initial_e,transfer.w_old,transfer.b2_old,inc.dinc_trans_old,ini_disab_e);
        
        
        
        %collapse to 2d matrix
        NLSY_panel = zeros(H*(T+1),11);
        for h = 1:H
            transform = squeeze(panel(h,:,1:end));
            transform = transform';
            NLSY_panel(1+(h-1)*(T+1):h*(T+1),:) = transform;
        end
        
        NLSY_panel(:,12) = opti.type;
        clear panel
        
        %age
        fcn = @(x){cumsum(x)};
        NLSY_panel(:,13) = 1;
        NLSY_panel(:,13) = accumarray_expand(NLSY_panel(:,13),NLSY_panel(:,9),fcn);
        
        %recompute just unemployed
        fcn = @(x){create_diff(x)};
        aux = accumarray_expand(NLSY_panel(:,1),NLSY_panel(:,9),fcn);
        NLSY_panel(logical((aux(:,1)==3).*(aux==1)),1) = 2;
        
        if opti.error %add measurement error
            spell = 0; %how shall employment spell be computed
            NLSY_panel = meas_error(NLSY_panel,ma,opti.type,spell);
        end
        
        names = {'Emp' 'JTJ' 'Prod' 'Gamma' 'asset' 'Acc' 'Gross w' 'c' 'i' 'search' 'disab' 'type' 'age'}; 
                 
        NLSY_aux = NLSY_panel;
             
        
        %employment transition rates
        [ue,en,ee,ee_p,share_loss,ee_gain,Neu_age,trans.young,eu,eolf] = comp_trans(NLSY_panel,work,names);


        %experience gains
        [life_wage,life_wage_y,life_wage_o] = comp_lifewage(NLSY_panel,work);
        
        
        %compute number of diabled, share of people in DI, and wage
        %difference to non-disabled
        disab_info = comp_disab(NLSY_panel,work,disable,names);

      

        %drop the DI and retired and sum all unemployed
        NLSY_aux(NLSY_aux(:,1)==4,:) = [];
        NLSY_aux(NLSY_aux(:,1)==5,:) = [];
        NLSY_aux(NLSY_aux(:,1)==3,1) = 2;
        
        %compute initial log wage and dispersion
        aux = NLSY_aux(NLSY_aux(:,1)==1,:); %keep the employed
        ini_wage = mean(log(aux(aux(:,13)<=12,7)));
        reg = ols(log(aux(:,7)),[ones(length(aux),1) aux(:,13) aux(:,13).^2]);
        aux = [reg.resid aux(:,13)];
        aux2 = aux(aux(:,2)<=12,1);
        ini_disp = std(aux2);
        
        
        
        if abs((en.a1-data_targets(9))./abs(data_targets(9)))>tol.cali
            if en.a1-data_targets(9)>0
                destruct_age(1)=destruct_age(1)-0.02*destruct_age(1);
            else
                if destruct_age(1)<0.0003
                    destruct_age(1)=0.0003;
                else
                    destruct_age(1)=destruct_age(1)+0.02*destruct_age(1);
                end
            end
        end
        
        if abs((en.a2-data_targets(10))./abs(data_targets(10)))>tol.cali
            if en.a2-data_targets(10)>0
                destruct_age(2)=destruct_age(2)-0.02*destruct_age(2);
            else
                if destruct_age(2)<0.0003
                    destruct_age(2)=0.0003;
                else
                    destruct_age(2)=destruct_age(2)+0.02*destruct_age(2);
                end
            end
        end
        
        if abs((en.a3-data_targets(11))./abs(data_targets(11)))>tol.cali
            if en.a3-data_targets(11)>0
                destruct_age(3)=destruct_age(3)-0.02*destruct_age(3);
            else
                if destruct_age(3)<0.0003
                    destruct_age(3)=0.0003;
                else
                    destruct_age(3)=destruct_age(3)+0.02*destruct_age(3);
                end
            end
        end
        
        if abs((share_loss.all-data_targets(4))./abs(data_targets(4)))>tol.cali
            if share_loss.all-data_targets(4)>0 
                lambda_d=lambda_d-0.02*lambda_d;
            else
                lambda_d=lambda_d+0.02*lambda_d;
            end
        end
        
        if abs((life_wage_y-data_targets(7))./abs(data_targets(7)))>tol.cali
            if life_wage_y-data_targets(7)>0
                mu=mu-0.02*mu;
            else
                mu=mu+0.02*mu;
            end
        end
        delta1 = min(0.0,mu);  
    
        
        if abs((life_wage_o-data_targets(8))./abs(data_targets(8)))>tol.cali
            if life_wage_o-data_targets(8)>0 && mu2<0
                mu2=mu2+0.02*mu2;
            elseif life_wage_o-data_targets(8)<0 && mu2<0
                mu2=mu2-0.02*mu2;
            elseif life_wage_o-data_targets(8)>0 && mu2>0
                mu2=mu2-0.02*mu2;
            elseif life_wage_o-data_targets(8)<0 && mu2>0
                mu2=mu2+0.02*mu2;
            end
        end
        delta2 = min(0.0,mu2);   
        
        
        
        if abs((exp(ini_wage)-exp(data_targets(5)))./abs(exp(data_targets(5))))>tol.cali
            if ini_wage-data_targets(5)>0
                newmean=newmean-0.002*newmean;
            else
                newmean=newmean+0.002*newmean;
            end
        end
        if abs((ini_disp-data_targets(6))./abs(data_targets(6)))>tol.cali
            if ini_disp-data_targets(6)>0
                epsilon.stdnewborn=epsilon.stdnewborn-0.005*epsilon.stdnewborn;
            else
                epsilon.stdnewborn=epsilon.stdnewborn+0.005*epsilon.stdnewborn;
            end
        end
        
      
        if abs((disab_info.DI_rate_young-data_targets(12))./abs(data_targets(12)))>tol.cali %number of DI bad health
            if disab_info.DI_rate_young-data_targets(12)>0 %too many disabled
                psi_y(2)=psi_y(2)-0.002*psi_y(2);
            else
                psi_y(2)=psi_y(2)+0.002*psi_y(2);
            end
        end

        if abs((disab_info.DI_rate_old-data_targets(13))./abs(data_targets(13)))>tol.cali %number of DI bad health
            if disab_info.DI_rate_old-data_targets(13)>0 %too many disabled
                psi_o(2)=psi_o(2)-0.002*psi_o(2);
            else
                psi_o(2)=psi_o(2)+0.002*psi_o(2);
            end
        end

        if abs((disab_info.dummy-data_targets(14))./abs(data_targets(14)))>tol.cali %disability dummy
            if disab_info.dummy-data_targets(14)<0 %too large penalty
                xi=xi-0.05*xi;
            else
                xi=xi+0.05*xi;
            end
        end

        if destruct_age(1)<=0.0003 
            crit_d1 = 0;
        else
            crit_d1 = abs((en.a1-data_targets(9))./abs(data_targets(9)));
        end
        if destruct_age(2)<=0.0003 
            crit_d2 = 0;
        else
            crit_d2 = abs((en.a2-data_targets(10))./abs(data_targets(10)));
        end
        if destruct_age(3)<=0.0003
            crit_d3 = 0;
        else
            crit_d3 = abs((en.a3-data_targets(11))./abs(data_targets(11)));
        end
            
        
        crit.cali = max([crit_d1 crit_d2 crit_d3...
                abs((exp(ini_wage)-exp(data_targets(5)))./abs(exp(data_targets(5)))) abs((ini_disp-data_targets(6))./abs(data_targets(6)))...
                abs((life_wage_y-data_targets(7))./abs(data_targets(7))) abs((life_wage_o-data_targets(8))./abs(data_targets(8)))...
                abs((share_loss.all-data_targets(4))./abs(data_targets(4))) ...
                abs(disab_info.DI_rate_young-data_targets(12))/abs(data_targets(12)) abs(disab_info.DI_rate_old-data_targets(13))/abs(data_targets(13))...
                abs(disab_info.dummy-data_targets(14))./abs(data_targets(14))]);

        [abs((en.a1-data_targets(9))./abs(data_targets(9))) en.a1 destruct_age(1);...
            abs((en.a2-data_targets(10))./abs(data_targets(10))) en.a2 destruct_age(2);...
            abs((en.a3-data_targets(11))./abs(data_targets(11))) en.a3 destruct_age(3);...
            abs((share_loss.all-data_targets(4))./abs(data_targets(4))) lambda_d share_loss.all;...
            abs((exp(ini_wage)-exp(data_targets(5)))./abs(exp(data_targets(5)))) ini_wage newmean;...
            abs((ini_disp-data_targets(6))./abs(data_targets(6))) ini_disp epsilon.stdnewborn;...
            abs((life_wage_y-data_targets(7))./abs(data_targets(7))) life_wage_y*100 mu*100;...
            abs((life_wage_o-data_targets(8))./abs(data_targets(8))) life_wage_o*100 mu2*100;...
            abs(disab_info.DI_rate_young-data_targets(12))/abs(data_targets(12)) disab_info.DI_rate_young psi_y(2);...
            abs(disab_info.DI_rate_old-data_targets(13))/abs(data_targets(13)) disab_info.DI_rate_old psi_o(2);...
            abs(disab_info.dummy-data_targets(14))./abs(data_targets(14)) disab_info.dummy xi]

        
    end
    
    
end
parameter = [destruct_age; newmean; epsilon.stdnewborn; mu; mu2; delta1; delta2; lambda_d; psi_y; psi_o; xi]; %save parameter values


%% simulation


rand('seed',21424);
randn('seed',85796);
H=7000;
T=work;

min_prod_e = pgrid(find(emp_pol.u_g(1,:,1,12,1)==1,1,'first')); %minimum productivity to accept employment at 75th percentile firm

prod_initial = min(max(nmin,epsilon.stdnewborn*randn(H,1)+newmean),nmax); %random numbers for initial asset distribution
prod_initial_e = prod_initial; %truncated log normal for the employed
for i1=1:H
    if prod_initial_e(i1)<min_prod_e
        control = 0;
        while control == 0
            aux = min(max(nmin,epsilon.stdnewborn*randn(1,1)+newmean),nmax);
            if aux >= min_prod_e
                prod_initial_e(i1) = aux;
                control = 1;
            end
        end
    end
end
prod_shock_aux = randn(H,T);
prod_shock = epsilon.stde*prod_shock_aux-(1/2*(epsilon.stdu^2)); %productivity shocks



panel = simulation_mex(int32(H),int32(T),int32(na),int32(np),int32(nc),int32(fnodes)...
    ,destruct_age,prod_initial,prod_shock...
    ,gamma.w,agrid,pgrid,grid_nc,mu,mu2,delta1,amin,amax,nmin,nmax...
    ,w_gross,transfer.w,inc.wel,b,inc.dinc,inc.dinc_trans,inc.ssinc,inc.ssinc_trans,R,int32(work),int32(disable),psi_y,psi_o...
    ,policyU_g,double(policyU_g_s),policyE_g,double(policyE_g_s),policyUJ_g,policyU_b,double(policyU_b_s),policyE_b,double(policyE_b_s),policyUJ_b...
    ,policyD,policyR(:,:,1),double(emp_pol.e_g),double(emp_pol.u_g),double(emp_pol.e_b),double(emp_pol.u_b)...
    ,double(d_pol_g),double(d_pol_b),asset_ini,tau_p,tau_c,disab_c,b2,transfer.b2,delta2,lambda_d,ini_emp,flip(prob_loss)...
    ,pi_gb,pi_bg,abar,ini_disab_u,xi,fc,prod_initial_e,transfer.w_old,transfer.b2_old,inc.dinc_trans_old,ini_disab_e);



%collapse to 2d matrix
NLSY_panel = zeros(H*(T+1),11);
for h = 1:H
    transform = squeeze(panel(h,:,1:end));
    transform = transform';
    NLSY_panel(1+(h-1)*(T+1):h*(T+1),:) = transform;
end
NLSY_panel(:,12) = opti.type;
clear panel

%age
fcn = @(x){cumsum(x)};
NLSY_panel(:,13) = 1;
NLSY_panel(:,13) = accumarray_expand(NLSY_panel(:,13),NLSY_panel(:,9),fcn);

%recompute just unemployed
fcn = @(x){create_diff(x)};
aux = accumarray_expand(NLSY_panel(:,1),NLSY_panel(:,9),fcn);
NLSY_panel(logical((aux(:,1)==3).*(aux==1)),1) = 2;


%labor supply elasticity
NLSY_in = NLSY_panel; %used for labor supply elasticities
NLSY_in = NLSY_in(NLSY_in(:,13)<=work,:); %only working population
fcn = @(x){create_LEAD(x,1)};
NLSY_in(:,14) = accumarray_expand(NLSY_in(:,3),NLSY_in(:,9),fcn)-0.1; %next period productivity -0.1
NLSY_in(:,15) = accumarray_expand(NLSY_in(:,5),NLSY_in(:,9),fcn); %next period assets (predetermined given today's states)
NLSY_in(:,16) = accumarray_expand(NLSY_in(:,6),NLSY_in(:,9),fcn); %next period ebar
NLSY_in(:,17) = accumarray_expand(NLSY_in(:,11),NLSY_in(:,9),fcn); %next period health
fcn = @(x){create_lag1(x)};
NLSY_in(:,18) = accumarray_expand(NLSY_in(:,3),NLSY_in(:,9),fcn); %last year productivity

panel_elas = simulation_elas_mex(int32(H),int32(T),int32(na),int32(np),int32(nc),int32(fnodes)...
    ,destruct_age,prod_initial,prod_shock...
    ,gamma.w,agrid,pgrid,grid_nc,mu,mu2,delta1,amin,amax,nmin,nmax...
    ,w_gross,transfer.w,inc.wel,b,inc.dinc,inc.dinc_trans,inc.ssinc,inc.ssinc_trans,R,int32(work),int32(disable),psi_y,psi_o...
    ,policyU_g,double(policyU_g_s),policyE_g,double(policyE_g_s),policyUJ_g,policyU_b,double(policyU_b_s),policyE_b,double(policyE_b_s),policyUJ_b...
    ,policyD,policyR(:,:,1),double(emp_pol.e_g),double(emp_pol.u_g),double(emp_pol.e_b),double(emp_pol.u_b)...
    ,double(d_pol_g),double(d_pol_b),asset_ini,tau_p,tau_c,disab_c,b2,transfer.b2,delta2,lambda_d,ini_emp,flip(prob_loss)...
    ,pi_gb,pi_bg,abar,ini_disab_u,xi,fc,prod_initial_e,transfer.w_old,transfer.b2_old,inc.dinc_trans_old,ini_disab_e,NLSY_in);
panel_elas(panel_elas(:,13)==work,:) = []; %drop last decision from counterfactual simulation
NLSY_in(NLSY_in(:,13)==1,:) = []; %drop age 1 from baseline simulation
labor_elas.all = (mean(NLSY_in(:,1)==1)-mean(panel_elas(:,1)==1))./0.1;
labor_elas.young = (mean(NLSY_in(NLSY_in(:,13)<100,1)==1)-mean(panel_elas(panel_elas(:,13)<100,1)==1))./0.1;
labor_elas.old = (mean(NLSY_in(NLSY_in(:,13)>=100,1)==1)-mean(panel_elas(panel_elas(:,13)>=100,1)==1))./0.1;

clear NLSY_in panel_elas

if opti.error %add measurement error
    spell = 0; %how shall employment spell be computed
    NLSY_panel = meas_error(NLSY_panel,ma,opti.type,spell);
end

names = {'Emp' 'JTJ' 'Prod' 'Gamma' 'asset' 'Acc' 'Gross w' 'c' 'i' 'search' 'disab' 'type' 'age'};



NLSY_aux = NLSY_panel;


%employment rate
fcn = @(x)create_rate(x);
aux = sortrows(NLSY_aux(:,[1 13]),2);
emp_age = accumarray_expand_s(aux(:,1),aux(:,2),fcn);
emp_drop = mean(emp_age(33*4+1:37*4))/mean(emp_age(17*4+1:21*4));
emp_prime = mean(emp_age(17*4+1:21*4));
emp_55 = mean(emp_age(129:132));
emp_61 = mean(emp_age(145:148));
emp_old = mean(emp_age(129:148));
index = (NLSY_aux(:,1)~=1).*(NLSY_aux(:,10)==0); %out of labor force
aux = sortrows([index NLSY_aux(:,13)],2);
olf_age = accumarray_expand_s(aux(:,1),aux(:,2),fcn);
olf_prime = mean(olf_age(17*4+1:21*4));
olf_55 = mean(olf_age(129:132));
olf_61 = mean(olf_age(145:148));
olf_old = mean(olf_age(129:148));

wealth_stats = comp_wwr(NLSY_panel,work);

con_drop = comp_condrop(NLSY_panel,work);

%sum of gross wages
aux = NLSY_panel(NLSY_panel(:,1)==1,:);
total_output = sum(aux(:,7))-length(aux)*fc;


[life_wage,life_wage_y,life_wage_o] = comp_lifewage(NLSY_panel,work);

%Topel Ward statistics
tw = tw_stats(NLSY_panel);

%compute depreciation losses
u_loss = comp_u_loss(NLSY_panel,names);

%compute number of diabled, share of people in DI, and wage
%difference to non-disabled
disab_info = comp_disab(NLSY_panel,work,disable,names);

% average wage over age
aux = NLSY_aux(NLSY_aux(:,1)==1,:);
aux = sortrows(aux(:,[7 13]),2);
aux(:,1) = log(aux(:,1));
fcn = @(x)mean(x);
age_wage = accumarray_expand_s(aux(:,1),aux(:,2),fcn);

% average productivity over age
aux = sortrows(NLSY_aux(:,[3 13]),2);
fcn = @(x)mean(x);
age_prod = accumarray_expand_s(aux(:,1),aux(:,2),fcn);
aux = NLSY_aux(NLSY_aux(:,1)==1,:);
aux = sortrows(aux(:,[3 13]),2);
age_e_prod = accumarray_expand_s(aux(:,1),aux(:,2),fcn);
aux = NLSY_aux(NLSY_aux(:,1)>1,:);
aux = sortrows(aux(:,[3 13]),2);
age_u_prod = accumarray_expand_s(aux(:,1),aux(:,2),fcn);

%drop the DI and sum all unemployed
NLSY_aux(NLSY_aux(:,1)==4,:) = [];
NLSY_aux(NLSY_aux(:,1)==5,:) = [];
NLSY_aux(NLSY_aux(:,1)==3,1) = 2;

%mean and standard deviation firm state
firm_mean = mean(gamma.n(NLSY_aux(NLSY_aux(:,1)==1,4)));
firm_std = std(gamma.n(NLSY_aux(NLSY_aux(:,1)==1,4)));

%transition rates
[ue,en,ee,ee_p,share_loss,ee_gain,Neu_age,trans.young,eu,eolf] = comp_trans(NLSY_panel,work,names);

%excess variance of wage growth
[excess_var,movers_var,stayers_var] = comp_excess_wg(NLSY_panel,names);


%mean and median wages and initial wages
aux = NLSY_panel(NLSY_panel(:,1)==1,:); %keep the employed
wage.median = median(aux(:,7)); %median wage
wage.mean = median(aux(:,7)); %median wage
ini.mean = mean(log(aux(aux(:,13)<=12,7)));



%initial and total wage dispersion and age profile
aux = aux(:,[7 13 11]);
aux(:,1) = log(aux(:,1)); %create residuals
aux(aux(:,2)<=4,4) = 1;
for t1 = 2:36
    index = (aux(:,2)>(t1-1)*4).*(aux(:,2)<=((t1-1)*4+4));
    aux(logical(index),4) = t1;
end
aux(aux(:,2)>144,4) = 37;
agedummy = dummyvar(aux(:,4));
disabdummy = dummyvar(aux(:,3)+1);
reg = ols(aux(:,1),[ones(length(aux),1) disabdummy(:,2:end) agedummy(:,2:end)]);
aux(:,5) = aux(:,2); %age
aux(:,2) = reg.resid+mean(aux(:,1)); %residuals corrected by mean
aux(:,1) = reg.resid;


%cross sectional inequality
ineq.mm.l1 = prctile(exp(aux(:,2)),50)./prctile(exp(aux(:,2)),1);
ineq.mm.l5 = prctile(exp(aux(:,2)),50)./prctile(exp(aux(:,2)),5);
ineq.mm.l10 = prctile(exp(aux(:,2)),50)./prctile(exp(aux(:,2)),10);

ineq.R90_50 = prctile(exp(aux(:,2)),90)./prctile(exp(aux(:,2)),50);
ineq.R90_10 = prctile(exp(aux(:,2)),90)./prctile(exp(aux(:,2)),10);
ineq.R50_10 = prctile(exp(aux(:,2)),50)./prctile(exp(aux(:,2)),10);
ineq.var = var(aux(:,2));
[ineq.gini,~] = gini(1/length(aux(:,2))*ones(length(aux(:,2)),1),exp(aux(:,2)));
ineq.p1 = prctile(exp(aux(:,2)),1);
ineq.p5 = prctile(exp(aux(:,2)),5);
ineq.p10 = prctile(exp(aux(:,2)),10);
ineq.p25 = prctile(exp(aux(:,2)),25);
ineq.p50 = prctile(exp(aux(:,2)),50);
ineq.p75 = prctile(exp(aux(:,2)),75);
ineq.p90 = prctile(exp(aux(:,2)),90);
ineq.p95 = prctile(exp(aux(:,2)),95);
ineq.p99 = prctile(exp(aux(:,2)),99);
% aux = NLSY_panel(NLSY_panel(:,11)<=work,:); %keep the employed


%over age
aux = sortrows(aux,4);
fcn = @(x)var(x);
age_var = accumarray_expand_s(aux(:,2),aux(:,4),fcn);

age_var = age_var-age_var(1);
fcn = @(x)mean(x);
mm1 = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
fcn = @(x)prctile(x,5);
mm2 = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_mm = mm1./mm2;
age_mm = age_mm-age_mm(1);
fcn = @(x){gini(1/length(x)*ones(length(x),1),x)};
age_gini = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_gini = age_gini-age_gini(1);
fcn = @(x)prctile(x,90);
percentile_90th = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
fcn = @(x)prctile(x,10);
percentile_10th = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_p9010 = percentile_90th./percentile_10th;
age_p9010 = age_p9010-age_p9010(1);

%over age bin
aux(:,5) = aux(:,4); %age categories 5 years
aux(aux(:,5)<=5,4) = 1;
for t1 = 2:6
    index = (aux(:,5)>(t1-1)*5).*(aux(:,5)<=t1*5);
    aux(logical(index),4) = t1;
end
aux(aux(:,5)>30,4) = 7;
aux2 = aux(aux(:,4)==1,1);
ini.std = std(aux2);

aux = sortrows(aux,4);
fcn = @(x)var(x);
age_var_bin = accumarray_expand_s(aux(:,2),aux(:,4),fcn);
age_var_bin = age_var_bin-age_var_bin(1);
fcn = @(x)mean(x);
mm1 = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
fcn = @(x)prctile(x,5);
mm2 = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_mm_bin = mm1./mm2;
age_mm_bin = age_mm_bin-age_mm_bin(1);
fcn = @(x){gini(1/length(x)*ones(length(x),1),x)};
age_gini_bin = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_gini_bin = age_gini_bin-age_gini_bin(1);
fcn = @(x)prctile(x,90);
percentile_90th = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
fcn = @(x)prctile(x,10);
percentile_10th = accumarray_expand_s(exp(aux(:,2)),aux(:,4),fcn);
age_p9010_bin = percentile_90th./percentile_10th;
age_p9010_bin = age_p9010_bin-age_p9010_bin(1);

%wealth inequality
ineq.wealth.var = var(log(NLSY_panel(:,5)+1));
ineq.wealth.gini = gini(1/length(NLSY_panel(:,5))*ones(length(NLSY_panel(:,5)),1),NLSY_panel(:,5));
ineq.wealth.p9010 = prctile(NLSY_panel(:,5),90)./prctile(NLSY_panel(:,5),10);
ineq.wealth.p9050 = prctile(NLSY_panel(:,5),90)./prctile(NLSY_panel(:,5),50);


%% simulation with government budget


T = life;
H=7000;
rand('seed',21424);
randn('seed',85796);


min_prod_e = pgrid(find(emp_pol.u_g(1,:,1,12,1)==1,1,'first')); %minimum productivity to accept employment at 75th percentile firm

prod_initial = min(max(nmin,epsilon.stdnewborn*randn(H,1)+newmean),nmax); %random numbers for initial asset distribution
prod_initial_e = prod_initial; %truncated log normal for the employed
for i1=1:H
    if prod_initial_e(i1)<min_prod_e
        control = 0;
        while control == 0
            aux = min(max(nmin,epsilon.stdnewborn*randn(1,1)+newmean),nmax);
            if aux >= min_prod_e
                prod_initial_e(i1) = aux;
                control = 1;
            end
        end
    end
end
prod_shock = epsilon.stde*prod_shock_aux-(1/2*(epsilon.stdu^2)); %productivity shocks
 
[panel,revenues,p_costs1,p_costs2,p_costs3,p_costs4,p_costs5] = simulation_gov_mex(int32(H),int32(T),int32(na),int32(np),int32(nc),int32(fnodes)...
            ,destruct_age,prod_initial,prod_shock...
            ,gamma.w,agrid,pgrid,grid_nc,mu,mu2,delta1,amin,amax,nmin,nmax...
            ,w_gross,transfer.w,inc.wel,b,inc.dinc,sub_dinc,inc.ssinc,sub_ssinc,R,int32(work),int32(disable),psi_y,psi_o...
            ,policyU_g,double(policyU_g_s),policyE_g,double(policyE_g_s),policyUJ_g,policyU_b,double(policyU_b_s),policyE_b,double(policyE_b_s),policyUJ_b...
            ,policyD,policyR,double(emp_pol.e_g),double(emp_pol.u_g),double(emp_pol.e_b),double(emp_pol.u_b)...
            ,double(d_pol_g),double(d_pol_b),asset_ini,tau_p,tau_c,disab_c,b2,transfer.b2,delta2,lambda_d,ini_emp,flip(prob_loss)...
            ,pi_gb,pi_bg,abar,ini_disab_u,xi,int32(retire),fc,prod_initial_e,transfer.w_old,transfer.b2_old,transfer.d,transfer.d_old...
            ,transfer.ss,ini_disab_e);


panel_tax = panel;
budget = sum(sum(panel(:,10,:)));
 
p_costs(1) = p_costs1;
p_costs(2) = p_costs2;
p_costs(3) = p_costs3;
p_costs(4) = p_costs4;
p_costs(5) = p_costs5;



%% saving results
asset_ini(2:end,2) = diff(asset_ini(:,2));
ini_dist = zeros(na,np); %mke it a PDF
for i = 1:length(asset_ini)
    ini_dist(asset_ini(i,1),:) = ini_dist(asset_ini(i,1),:)+asset_ini(i,2);
end
ini_dist_g = ini_dist.*repmat(Prob.Newborn',na,1);
ini_dist_b = ini_dist.*repmat(Prob.Newborn_disab',na,1);

% VE_aux= sum(VE_g.*repmat(reshape(gamma.w,[1 1 fnodes]),[na np]),3)*(1-ini_disab_e)+sum(VE_b.*repmat(reshape(gamma.w,[1 1 fnodes]),[na np]),3)*ini_disab_e;
VU_aux= VU_g.*ini_dist_g*(1-ini_disab_u)+VU_b.*ini_dist_b*ini_disab_u;
value_f = sum(sum(VU_aux));

if opti.period == 1 && opti.decomp==0 
            if opti.type == 1
                clear p1_s1_t1
                p1_s1_t1.para = parameter;
                p1_s1_t1.ee = ee;
                p1_s1_t1.ee_p = ee_p;
                p1_s1_t1.ue = ue;
                p1_s1_t1.en = en;
                p1_s1_t1.eu = eu;
                p1_s1_t1.eolf = eolf;
                p1_s1_t1.share_loss = share_loss;
                p1_s1_t1.ee_gain = ee_gain;
                p1_s1_t1.excess_var = excess_var;
                p1_s1_t1.stayers_var = stayers_var;
                p1_s1_t1.wealth_stats = wealth_stats;
                p1_s1_t1.wage=wage;
                p1_s1_t1.emp_age = emp_age;
                p1_s1_t1.olf_age = olf_age;
                p1_s1_t1.u_loss=u_loss;
                p1_s1_t1.disab_info = disab_info;
                p1_s1_t1.born = ini_dist;
                p1_s1_t1.value = value_f;
                p1_s1_t1.prod_shock = prod_shock_aux;
                p1_s1_t1.prod_initial = prod_initial;
                p1_s1_t1.prod_initial_e = prod_initial_e;
                p1_s1_t1.ini.mean = ini.mean;
                p1_s1_t1.ini.std = ini.std;
                p1_s1_t1.ineq= ineq;
                p1_s1_t1.age_var = age_var;
                p1_s1_t1.age_gini = age_gini;
                p1_s1_t1.age_mm = age_mm;
                p1_s1_t1.age_p9010 = age_p9010;
                p1_s1_t1.age_var_bin = age_var_bin;
                p1_s1_t1.age_gini_bin = age_gini_bin;
                p1_s1_t1.age_mm_bin = age_mm_bin;
                p1_s1_t1.age_p9010_bin = age_p9010_bin;
                p1_s1_t1.con_drop = con_drop;
                p1_s1_t1.tw = tw;
                p1_s1_t1.budget = budget;
                p1_s1_t1.p_costs = p_costs;
                p1_s1_t1.revenues = revenues;
                p1_s1_t1.firm_mean = firm_mean;
                p1_s1_t1.firm_std = firm_std;
                p1_s1_t1.life_wage = life_wage;
                p1_s1_t1.labor_elas = labor_elas;
                save('p1_s1_t1.mat','p1_s1_t1');
            elseif opti.type ==2
                clear p1_s1_t2
                p1_s1_t2.para = parameter;
                p1_s1_t2.ee = ee;
                p1_s1_t2.ee_p = ee_p;
                p1_s1_t2.ue = ue;
                p1_s1_t2.en = en;
                p1_s1_t2.eu = eu;
                p1_s1_t2.eolf = eolf;
                p1_s1_t2.share_loss = share_loss;
                p1_s1_t2.ee_gain = ee_gain;
                p1_s1_t2.excess_var = excess_var;
                p1_s1_t2.stayers_var = stayers_var;
                p1_s1_t2.wealth_stats = wealth_stats;
                p1_s1_t2.wage=wage;
                p1_s1_t2.emp_age = emp_age;
                p1_s1_t2.olf_age = olf_age;
                p1_s1_t2.u_loss=u_loss;
                p1_s1_t2.disab_info = disab_info;
                p1_s1_t2.born = ini_dist;
                p1_s1_t2.value = value_f;
                p1_s1_t2.prod_shock = prod_shock_aux;
                p1_s1_t2.prod_initial = prod_initial;
                p1_s1_t2.prod_initial_e = prod_initial_e;
                p1_s1_t2.ini.mean = ini.mean;
                p1_s1_t2.ini.std = ini.std;
                p1_s1_t2.ineq= ineq;
                p1_s1_t2.age_var = age_var;
                p1_s1_t2.age_gini = age_gini;
                p1_s1_t2.age_mm = age_mm;
                p1_s1_t2.age_p9010 = age_p9010;
                p1_s1_t2.age_var_bin = age_var_bin;
                p1_s1_t2.age_gini_bin = age_gini_bin;
                p1_s1_t2.age_mm_bin = age_mm_bin;
                p1_s1_t2.age_p9010_bin = age_p9010_bin;
                p1_s1_t2.con_drop = con_drop;
                p1_s1_t2.tw = tw;
                p1_s1_t2.budget = budget;
                p1_s1_t2.p_costs = p_costs;
                p1_s1_t2.revenues = revenues;
                p1_s1_t2.firm_mean = firm_mean;
                p1_s1_t2.firm_std = firm_std;
                p1_s1_t2.life_wage = life_wage;
                p1_s1_t2.labor_elas = labor_elas;
                save('p1_s1_t2.mat','p1_s1_t2');
            else
                clear p1_s1_t3
                p1_s1_t3.para = parameter;
                p1_s1_t3.ee = ee;
                p1_s1_t3.ee_p = ee_p;
                p1_s1_t3.ue = ue;
                p1_s1_t3.en = en;
                p1_s1_t3.eu = eu;
                p1_s1_t3.eolf = eolf;
                p1_s1_t3.share_loss = share_loss;
                p1_s1_t3.ee_gain = ee_gain;
                p1_s1_t3.excess_var = excess_var;
                p1_s1_t3.stayers_var = stayers_var;
                p1_s1_t3.wealth_stats = wealth_stats;
                p1_s1_t3.wage=wage;
                p1_s1_t3.emp_age = emp_age;
                p1_s1_t3.olf_age = olf_age;
                p1_s1_t3.u_loss=u_loss;
                p1_s1_t3.disab_info = disab_info;
                p1_s1_t3.born = ini_dist;
                p1_s1_t3.value = value_f;
                p1_s1_t3.prod_shock = prod_shock_aux;
                p1_s1_t3.prod_initial = prod_initial;
                p1_s1_t3.prod_initial_e = prod_initial_e;
                p1_s1_t3.ini.mean = ini.mean;
                p1_s1_t3.ini.std = ini.std;
                p1_s1_t3.ineq= ineq;
                p1_s1_t3.age_var = age_var;
                p1_s1_t3.age_gini = age_gini;
                p1_s1_t3.age_mm = age_mm;
                p1_s1_t3.age_p9010 = age_p9010;
                p1_s1_t3.age_var_bin = age_var_bin;
                p1_s1_t3.age_gini_bin = age_gini_bin;
                p1_s1_t3.age_mm_bin = age_mm_bin;
                p1_s1_t3.age_p9010_bin = age_p9010_bin;
                p1_s1_t3.con_drop = con_drop;
                p1_s1_t3.tw = tw;
                p1_s1_t3.budget = budget;
                p1_s1_t3.p_costs = p_costs;
                p1_s1_t3.revenues = revenues;
                p1_s1_t3.firm_mean = firm_mean;
                p1_s1_t3.firm_std = firm_std;
                p1_s1_t3.life_wage = life_wage;
                p1_s1_t3.labor_elas = labor_elas;
                save('p1_s1_t3.mat','p1_s1_t3');
            end

elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==0 && opti.job_risk == 0 && opti.ini_ineq==0 && opti.health==0 && opti.wage==0 && opti.welfare==0
    if opti.type == 1
        decomp_t1_risk_shock.emp_age = emp_age;
        decomp_t1_risk_shock.olf_age = olf_age;
        decomp_t1_risk_shock.ineq= ineq;
        decomp_t1_risk_shock.age_var= age_var;
        decomp_t1_risk_shock.ee= ee;
        decomp_t1_risk_shock.ue= ue;
        decomp_t1_risk_shock.en= en;
        decomp_t1_risk_shock.eu= eu;
        decomp_t1_risk_shock.firm_std = firm_std;
        decomp_t1_risk_shock.disab_info =disab_info;
        decomp_t1_risk_shock.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t1_risk_shock.labor_elas = labor_elas;
        save('decomp_t1_risk_shock.mat','decomp_t1_risk_shock');
    elseif opti.type == 2
        decomp_t2_risk_shock.emp_age = emp_age;
        decomp_t2_risk_shock.olf_age = olf_age;
        decomp_t2_risk_shock.ineq= ineq;
        decomp_t2_risk_shock.age_var= age_var;
        decomp_t2_risk_shock.ee= ee;
        decomp_t2_risk_shock.ue= ue;
        decomp_t2_risk_shock.en= en;
        decomp_t2_risk_shock.eu= eu;
        decomp_t2_risk_shock.firm_std = firm_std;
        decomp_t2_risk_shock.disab_info =disab_info;
        decomp_t2_risk_shock.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t2_risk_shock.labor_elas = labor_elas;
        save('decomp_t2_risk_shock.mat','decomp_t2_risk_shock');
    else
        decomp_t3_risk_shock.emp_age = emp_age;
        decomp_t3_risk_shock.olf_age = olf_age;
        decomp_t3_risk_shock.ineq= ineq;
        decomp_t3_risk_shock.age_var= age_var;
        decomp_t3_risk_shock.ee= ee;
        decomp_t3_risk_shock.ue= ue;
        decomp_t3_risk_shock.en= en;
        decomp_t3_risk_shock.eu= eu;
        decomp_t3_risk_shock.firm_std = firm_std;
        decomp_t3_risk_shock.disab_info =disab_info;
        decomp_t3_risk_shock.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t3_risk_shock.labor_elas = labor_elas;
        save('decomp_t3_risk_shock.mat','decomp_t3_risk_shock');
    end
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 0 && opti.ini_ineq==0 && opti.health==0 && opti.wage==0 && opti.welfare==0
    if opti.type == 1
        decomp_t1_risk_jdisp.emp_age = emp_age;
        decomp_t1_risk_jdisp.olf_age = olf_age;
        decomp_t1_risk_jdisp.ineq= ineq;
        decomp_t1_risk_jdisp.age_var= age_var;
        decomp_t1_risk_jdisp.ee= ee;
        decomp_t1_risk_jdisp.ue= ue;
        decomp_t1_risk_jdisp.en= en;
        decomp_t1_risk_jdisp.eu= eu;
        decomp_t1_risk_jdisp.firm_std = firm_std;
        decomp_t1_risk_jdisp.disab_info =disab_info;
        decomp_t1_risk_jdisp.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t1_risk_jdisp.labor_elas = labor_elas;
        save('decomp_t1_risk_jdisp.mat','decomp_t1_risk_jdisp');    
   elseif opti.type == 2
        decomp_t2_risk_jdisp.emp_age = emp_age;
        decomp_t2_risk_jdisp.olf_age = olf_age;
        decomp_t2_risk_jdisp.ineq= ineq;
        decomp_t2_risk_jdisp.age_var= age_var;
        decomp_t2_risk_jdisp.ee= ee;
        decomp_t2_risk_jdisp.ue= ue;
        decomp_t2_risk_jdisp.en= en;
        decomp_t2_risk_jdisp.eu= eu;
        decomp_t2_risk_jdisp.firm_std = firm_std;
        decomp_t2_risk_jdisp.disab_info =disab_info;
        decomp_t2_risk_jdisp.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t2_risk_jdisp.labor_elas = labor_elas;
        save('decomp_t2_risk_jdisp.mat','decomp_t2_risk_jdisp');
    else
        decomp_t3_risk_jdisp.emp_age = emp_age;
        decomp_t3_risk_jdisp.olf_age = olf_age;
        decomp_t3_risk_jdisp.ineq= ineq;
        decomp_t3_risk_jdisp.age_var= age_var;
        decomp_t3_risk_jdisp.ee= ee;
        decomp_t3_risk_jdisp.ue= ue;
        decomp_t3_risk_jdisp.en= en;
        decomp_t3_risk_jdisp.eu= eu;
        decomp_t3_risk_jdisp.firm_std = firm_std;
        decomp_t3_risk_jdisp.disab_info =disab_info;
        decomp_t3_risk_jdisp.unemp_prod_perc_emp = unemp_prod_perc_emp;
        decomp_t3_risk_jdisp.labor_elas = labor_elas;
        save('decomp_t3_risk_jdisp.mat','decomp_t3_risk_jdisp');
    end         
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 1 && opti.ini_ineq==0 && opti.health==0 && opti.wage==0 && opti.welfare==0
    if opti.type == 1
        decomp_t1_risk_job.emp_age = emp_age;
        decomp_t1_risk_job.olf_age = olf_age;
        decomp_t1_risk_job.ineq= ineq;
        decomp_t1_risk_job.age_var= age_var;
        decomp_t1_risk_job.ee= ee;
        decomp_t1_risk_job.ue= ue;
        decomp_t1_risk_job.en= en;
        decomp_t1_risk_job.eu= eu;
        decomp_t1_risk_job.disab_info =disab_info;
        decomp_t1_risk_job.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t1_risk_job.mat','decomp_t1_risk_job');
    elseif opti.type == 2
        decomp_t2_risk_job.emp_age = emp_age;
        decomp_t2_risk_job.olf_age = olf_age;
        decomp_t2_risk_job.ineq= ineq;
        decomp_t2_risk_job.age_var= age_var;
        decomp_t2_risk_job.ee= ee;
        decomp_t2_risk_job.ue= ue;
        decomp_t2_risk_job.en= en;
        decomp_t2_risk_job.eu= eu;
        decomp_t2_risk_job.disab_info =disab_info;
        decomp_t2_risk_job.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t2_risk_job.mat','decomp_t2_risk_job');
    else
        decomp_t3_risk_job.emp_age = emp_age;
        decomp_t3_risk_job.olf_age = olf_age;
        decomp_t3_risk_job.ineq= ineq;
        decomp_t3_risk_job.age_var= age_var;
        decomp_t3_risk_job.ee= ee;
        decomp_t3_risk_job.ue= ue;
        decomp_t3_risk_job.en= en;
        decomp_t3_risk_job.eu= eu;
        decomp_t3_risk_job.disab_info =disab_info;
        decomp_t3_risk_job.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t3_risk_job.mat','decomp_t3_risk_job');
    end       
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 1 && opti.ini_ineq==1 && opti.health==0 && opti.wage==0 && opti.welfare==0
    if opti.type == 1
        decomp_t1_risk_ini.emp_age = emp_age;
        decomp_t1_risk_ini.olf_age = olf_age;
        decomp_t1_risk_ini.ineq= ineq;
        decomp_t1_risk_ini.age_var= age_var;
        decomp_t1_risk_ini.ee= ee;
        decomp_t1_risk_ini.ue= ue;
        decomp_t1_risk_ini.en= en;
        decomp_t1_risk_ini.eu= eu;
        decomp_t1_risk_ini.disab_info =disab_info;
        decomp_t1_risk_ini.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t1_risk_ini.mat','decomp_t1_risk_ini');
    elseif opti.type == 2
        decomp_t2_risk_ini.emp_age = emp_age;
        decomp_t2_risk_ini.olf_age = olf_age;
        decomp_t2_risk_ini.ineq= ineq;
        decomp_t2_risk_ini.age_var= age_var;
        decomp_t2_risk_ini.ee= ee;
        decomp_t2_risk_ini.ue= ue;
        decomp_t2_risk_ini.en= en;
        decomp_t2_risk_ini.eu= eu;
        decomp_t2_risk_ini.disab_info =disab_info;
        decomp_t2_risk_ini.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t2_risk_ini.mat','decomp_t2_risk_ini');
    else
        decomp_t3_risk_ini.emp_age = emp_age;
        decomp_t3_risk_ini.olf_age = olf_age;
        decomp_t3_risk_ini.ineq= ineq;
        decomp_t3_risk_ini.age_var= age_var;
        decomp_t3_risk_ini.ee= ee;
        decomp_t3_risk_ini.ue= ue;
        decomp_t3_risk_ini.en= en;
        decomp_t3_risk_ini.eu= eu;
        decomp_t3_risk_ini.disab_info =disab_info;
        decomp_t3_risk_ini.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t3_risk_ini.mat','decomp_t3_risk_ini');
    end  
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 1 && opti.ini_ineq==1 && opti.health==1  && opti.wage==0 && opti.welfare==0
    if opti.type == 1
        decomp_t1_risk_health.emp_age = emp_age;
        decomp_t1_risk_health.olf_age = olf_age;
        decomp_t1_risk_health.ineq= ineq;
        decomp_t1_risk_health.age_var= age_var;
        decomp_t1_risk_health.ee= ee;
        decomp_t1_risk_health.ue= ue;
        decomp_t1_risk_health.en= en;
        decomp_t1_risk_health.eu= eu;
        decomp_t1_risk_health.disab_info =disab_info;
        decomp_t1_risk_health.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t1_risk_health.mat','decomp_t1_risk_health');
    elseif opti.type == 2
        decomp_t2_risk_health.emp_age = emp_age;
        decomp_t2_risk_health.olf_age = olf_age;
        decomp_t2_risk_health.ineq= ineq;
        decomp_t2_risk_health.age_var= age_var;
        decomp_t2_risk_health.ee= ee;
        decomp_t2_risk_health.ue= ue;
        decomp_t2_risk_health.en= en;
        decomp_t2_risk_health.eu= eu;
        decomp_t2_risk_health.disab_info =disab_info;
        decomp_t2_risk_health.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t2_risk_health.mat','decomp_t2_risk_health');
    else
        decomp_t3_risk_health.emp_age = emp_age;
        decomp_t3_risk_health.olf_age = olf_age;
        decomp_t3_risk_health.ineq= ineq;
        decomp_t3_risk_health.age_var= age_var;
        decomp_t3_risk_health.ee= ee;
        decomp_t3_risk_health.ue= ue;
        decomp_t3_risk_health.en= en;
        decomp_t3_risk_health.eu= eu;
        decomp_t3_risk_health.disab_info =disab_info;
        decomp_t3_risk_health.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t3_risk_health.mat','decomp_t3_risk_health');
    end      
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 1 && opti.ini_ineq==1 && opti.health==1 && opti.wage==1 && opti.welfare==0
    if opti.type == 1
        decomp_t1_wage.emp_age = emp_age;
        decomp_t1_wage.olf_age = olf_age;
        decomp_t1_wage.ineq= ineq;
        decomp_t1_wage.age_var= age_var;
        decomp_t1_wage.ee= ee;
        decomp_t1_wage.ue= ue;
        decomp_t1_wage.en= en;
        decomp_t1_wage.eu= eu;
        decomp_t1_wage.disab_info =disab_info;
        decomp_t1_wage.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t1_wage.mat','decomp_t1_wage');
    elseif opti.type == 2
        decomp_t2_wage.emp_age = emp_age;
        decomp_t2_wage.olf_age = olf_age;
        decomp_t2_wage.ineq= ineq;
        decomp_t2_wage.age_var= age_var;
        decomp_t2_wage.ee= ee;
        decomp_t2_wage.ue= ue;
        decomp_t2_wage.en= en;
        decomp_t2_wage.eu= eu;
        decomp_t2_wage.disab_info =disab_info;
        decomp_t2_wage.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t2_wage.mat','decomp_t2_wage');
    else
        decomp_t3_wage.emp_age = emp_age;
        decomp_t3_wage.olf_age = olf_age;
        decomp_t3_wage.ineq= ineq;
        decomp_t3_wage.age_var= age_var;
        decomp_t3_wage.ee= ee;
        decomp_t3_wage.ue= ue;
        decomp_t3_wage.en= en;
        decomp_t3_wage.eu= eu;
        decomp_t3_wage.disab_info =disab_info;
        decomp_t3_wage.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t3_wage.mat','decomp_t3_wage');
    end    
elseif opti.decomp==1 && opti.prod_shock == 1 && opti.job_disp==1 && opti.job_risk == 1 && opti.health==1 && opti.ini_ineq==1 && opti.wage==1 && opti.welfare==1
    if opti.type == 1
        decomp_t1_welfare.emp_age = emp_age;
        decomp_t1_welfare.olf_age = olf_age;
        decomp_t1_welfare.ineq= ineq;
        decomp_t1_welfare.age_var= age_var;
        decomp_t1_welfare.ee= ee;
        decomp_t1_welfare.ue= ue;
        decomp_t1_welfare.en= en;
        decomp_t1_welfare.eu= eu;
        decomp_t1_welfare.disab_info =disab_info;
        decomp_t1_welfare.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t1_welfare.mat','decomp_t1_welfare');
    elseif opti.type == 2
        decomp_t2_welfare.emp_age = emp_age;
        decomp_t2_welfare.olf_age = olf_age;
        decomp_t2_welfare.ineq= ineq;
        decomp_t2_welfare.age_var= age_var;
        decomp_t2_welfare.ee= ee;
        decomp_t2_welfare.ue= ue;
        decomp_t2_welfare.en= en;
        decomp_t2_welfare.eu= eu;
        decomp_t2_welfare.disab_info =disab_info;
        decomp_t2_welfare.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t2_welfare.mat','decomp_t2_welfare');
    else
        decomp_t3_welfare.emp_age = emp_age;
        decomp_t3_welfare.olf_age = olf_age;
        decomp_t3_welfare.ineq= ineq;
        decomp_t3_welfare.age_var= age_var;
        decomp_t3_welfare.ee= ee;
        decomp_t3_welfare.ue= ue;
        decomp_t3_welfare.en= en;
        decomp_t3_welfare.eu= eu;
        decomp_t3_welfare.disab_info =disab_info;
        decomp_t3_welfare.unemp_prod_perc_emp = unemp_prod_perc_emp;
        save('decomp_t3_welfare.mat','decomp_t3_welfare');
    end       
end


    
end


%% statistics based on total population


load('p1_s1_t1.mat','p1_s1_t1');
load('p1_s1_t2.mat','p1_s1_t2');
load('p1_s1_t3.mat','p1_s1_t3');
load('educ_share_age.mat','educ_share_age')

%consumption drop upon unemployment
p1_s1_t1.con_drop.eu_long*(p1_s1_t1.con_drop.eu_long_N/(p1_s1_t1.con_drop.eu_long_N+p1_s1_t2.con_drop.eu_long_N+p1_s1_t3.con_drop.eu_long_N))...
    +p1_s1_t2.con_drop.eu_long*(p1_s1_t2.con_drop.eu_long_N/(p1_s1_t1.con_drop.eu_long_N+p1_s1_t2.con_drop.eu_long_N+p1_s1_t3.con_drop.eu_long_N))...
    +p1_s1_t3.con_drop.eu_long*(p1_s1_t3.con_drop.eu_long_N/(p1_s1_t1.con_drop.eu_long_N+p1_s1_t2.con_drop.eu_long_N+p1_s1_t3.con_drop.eu_long_N))


%employment/OLF rate
pop_emp_age = p1_s1_t1.emp_age(1:work).*educ_share_age.g1.p1+p1_s1_t2.emp_age(1:work).*educ_share_age.g2.p1+p1_s1_t3.emp_age(1:work).*educ_share_age.g3.p1;
pop_olf_age = p1_s1_t1.olf_age(1:work).*educ_share_age.g1.p1+p1_s1_t2.olf_age(1:work).*educ_share_age.g2.p1+p1_s1_t3.olf_age(1:work).*educ_share_age.g3.p1;



%wage loss from ENE
pop_u_loss = p1_s1_t1.u_loss.median*0.55+p1_s1_t2.u_loss.median*0.17+p1_s1_t3.u_loss.median*0.28;

%Topel ward statistics
TW.jobs12 = 0.55*p1_s1_t1.tw.jobs12+0.17*p1_s1_t2.tw.jobs12+0.28*p1_s1_t3.tw.jobs12;
TW.jobs24 = 0.55*p1_s1_t1.tw.jobs24+0.17*p1_s1_t2.tw.jobs24+0.28*p1_s1_t3.tw.jobs24;
TW.jobs36 = 0.55*p1_s1_t1.tw.jobs36+0.17*p1_s1_t2.tw.jobs36+0.28*p1_s1_t3.tw.jobs36;
TW.jobs48 = 0.55*p1_s1_t1.tw.jobs48+0.17*p1_s1_t2.tw.jobs48+0.28*p1_s1_t3.tw.jobs48;
TW.jobs60 = 0.55*p1_s1_t1.tw.jobs60+0.17*p1_s1_t2.tw.jobs60+0.28*p1_s1_t3.tw.jobs60;
TW.jobs72 = 0.55*p1_s1_t1.tw.jobs72+0.17*p1_s1_t2.tw.jobs72+0.28*p1_s1_t3.tw.jobs72;
TW.jobs84 = 0.55*p1_s1_t1.tw.jobs84+0.17*p1_s1_t2.tw.jobs84+0.28*p1_s1_t3.tw.jobs84;
TW.jobs96 = 0.55*p1_s1_t1.tw.jobs96+0.17*p1_s1_t2.tw.jobs96+0.28*p1_s1_t3.tw.jobs96;
TW.jobs108 = 0.55*p1_s1_t1.tw.jobs108+0.17*p1_s1_t2.tw.jobs108+0.28*p1_s1_t3.tw.jobs108;
TW.jobs120 = 0.55*p1_s1_t1.tw.jobs120+0.17*p1_s1_t2.tw.jobs120+0.28*p1_s1_t3.tw.jobs120;

TW.exp12 = 0.55*p1_s1_t1.tw.exp12+0.17*p1_s1_t2.tw.exp12+0.28*p1_s1_t3.tw.exp12;
TW.exp24 = 0.55*p1_s1_t1.tw.exp24+0.17*p1_s1_t2.tw.exp24+0.28*p1_s1_t3.tw.exp24;
TW.exp36 = 0.55*p1_s1_t1.tw.exp36+0.17*p1_s1_t2.tw.exp36+0.28*p1_s1_t3.tw.exp36;
TW.exp48 = 0.55*p1_s1_t1.tw.exp48+0.17*p1_s1_t2.tw.exp48+0.28*p1_s1_t3.tw.exp48;
TW.exp60 = 0.55*p1_s1_t1.tw.exp60+0.17*p1_s1_t2.tw.exp60+0.28*p1_s1_t3.tw.exp60;
TW.exp72 = 0.55*p1_s1_t1.tw.exp72+0.17*p1_s1_t2.tw.exp72+0.28*p1_s1_t3.tw.exp72;
TW.exp84 = 0.55*p1_s1_t1.tw.exp84+0.17*p1_s1_t2.tw.exp84+0.28*p1_s1_t3.tw.exp84;
TW.exp96 = 0.55*p1_s1_t1.tw.exp96+0.17*p1_s1_t2.tw.exp96+0.28*p1_s1_t3.tw.exp96;
TW.exp108 = 0.55*p1_s1_t1.tw.exp108+0.17*p1_s1_t2.tw.exp108+0.28*p1_s1_t3.tw.exp108;
TW.exp120 = 0.55*p1_s1_t1.tw.exp120+0.17*p1_s1_t2.tw.exp120+0.28*p1_s1_t3.tw.exp120;

wei(1) = p1_s1_t1.tw.jtj_N/(p1_s1_t1.tw.jtj_N+p1_s1_t2.tw.jtj_N+p1_s1_t3.tw.jtj_N)*0.55;
wei(2) = p1_s1_t2.tw.jtj_N/(p1_s1_t1.tw.jtj_N+p1_s1_t2.tw.jtj_N+p1_s1_t3.tw.jtj_N)*0.17;
wei(3) = p1_s1_t3.tw.jtj_N/(p1_s1_t1.tw.jtj_N+p1_s1_t2.tw.jtj_N+p1_s1_t3.tw.jtj_N)*0.28;
wei = wei./sum(wei);
TW.wgr_1_10_jtj = p1_s1_t1.tw.wgr_1_10_jtj*wei(1)+p1_s1_t2.tw.wgr_1_10_jtj*wei(2)+p1_s1_t3.tw.wgr_1_10_jtj*wei(3);
TW.wgr_11_20_jtj = p1_s1_t1.tw.wgr_11_20_jtj*wei(1)+p1_s1_t2.tw.wgr_11_20_jtj*wei(2)+p1_s1_t3.tw.wgr_11_20_jtj*wei(3);
TW.wgr_21_30_jtj = p1_s1_t1.tw.wgr_21_30_jtj*wei(1)+p1_s1_t2.tw.wgr_21_30_jtj*wei(2)+p1_s1_t3.tw.wgr_21_30_jtj*wei(3);
TW.wgr_31_40_jtj = p1_s1_t1.tw.wgr_31_40_jtj*wei(1)+p1_s1_t2.tw.wgr_31_40_jtj*wei(2)+p1_s1_t3.tw.wgr_31_40_jtj*wei(3);

TW.wgr_40_share_jtj = p1_s1_t1.tw.wgr_40_share_jtj*0.55+p1_s1_t2.tw.wgr_40_share_jtj*0.17+p1_s1_t3.tw.wgr_40_share_jtj*0.28;


%labor supply elasticity
pop_labor_elas.all = p1_s1_t1.labor_elas.all*0.55+p1_s1_t2.labor_elas.all*0.17+p1_s1_t3.labor_elas.all*0.28; %cite chetty range. Low skill issue
pop_labor_elas.young = p1_s1_t1.labor_elas.young*0.55+p1_s1_t2.labor_elas.young*0.17+p1_s1_t3.labor_elas.young*0.28;
pop_labor_elas.old = p1_s1_t1.labor_elas.old*0.55+p1_s1_t2.labor_elas.old*0.17+p1_s1_t3.labor_elas.old*0.28;



%% Results decomposition
 
load('p1_s1_t1.mat','p1_s1_t1');
load('p1_s1_t2.mat','p1_s1_t2');
load('p1_s1_t3.mat','p1_s1_t3');

load('decomp_t1_risk_jdisp.mat')
load('decomp_t2_risk_jdisp.mat')
load('decomp_t3_risk_jdisp.mat')
load('decomp_t1_risk_shock.mat')
load('decomp_t2_risk_shock.mat')
load('decomp_t3_risk_shock.mat')
load('decomp_t1_risk_job.mat')
load('decomp_t2_risk_job.mat')
load('decomp_t3_risk_job.mat')
load('decomp_t1_risk_ini.mat')
load('decomp_t2_risk_ini.mat')
load('decomp_t3_risk_ini.mat')
load('decomp_t1_risk_health.mat')
load('decomp_t2_risk_health.mat')
load('decomp_t3_risk_health.mat')
load('decomp_t1_wage.mat')
load('decomp_t2_wage.mat')
load('decomp_t3_wage.mat')
load('decomp_t1_welfare.mat')
load('decomp_t2_welfare.mat')
load('decomp_t3_welfare.mat')

%change in wage inequality

(decomp_t1_risk_shock.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_risk_shock.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_risk_shock.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_risk_shock.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_risk_shock.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_risk_shock.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_risk_shock.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_risk_shock.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_risk_shock.ineq.gini-p1_s1_t3.ineq.gini)*100

(decomp_t1_risk_jdisp.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_risk_jdisp.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_risk_jdisp.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_risk_jdisp.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_risk_jdisp.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_risk_jdisp.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_risk_jdisp.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_risk_jdisp.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_risk_jdisp.ineq.gini-p1_s1_t3.ineq.gini)*100

(decomp_t1_risk_job.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_risk_job.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_risk_job.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_risk_job.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_risk_job.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_risk_job.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_risk_job.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_risk_job.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_risk_job.ineq.gini-p1_s1_t3.ineq.gini)*100

(decomp_t1_risk_ini.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_risk_ini.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_risk_ini.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_risk_ini.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_risk_ini.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_risk_ini.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_risk_ini.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_risk_ini.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_risk_ini.ineq.gini-p1_s1_t3.ineq.gini)*100

(decomp_t1_risk_health.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_risk_health.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_risk_health.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_risk_health.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_risk_health.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_risk_health.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_risk_health.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_risk_health.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_risk_health.ineq.gini-p1_s1_t3.ineq.gini)*100

(decomp_t1_wage.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_wage.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_wage.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_wage.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_wage.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_wage.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_wage.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_wage.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_wage.ineq.gini-p1_s1_t3.ineq.gini)*100


(decomp_t1_welfare.ineq.var-p1_s1_t1.ineq.var)*100
(decomp_t2_welfare.ineq.var-p1_s1_t2.ineq.var)*100
(decomp_t3_welfare.ineq.var-p1_s1_t3.ineq.var)*100
(decomp_t1_welfare.ineq.R90_10-p1_s1_t1.ineq.R90_10)
(decomp_t2_welfare.ineq.R90_10-p1_s1_t2.ineq.R90_10)
(decomp_t3_welfare.ineq.R90_10-p1_s1_t3.ineq.R90_10)
(decomp_t1_welfare.ineq.gini-p1_s1_t1.ineq.gini)*100
(decomp_t2_welfare.ineq.gini-p1_s1_t2.ineq.gini)*100
(decomp_t3_welfare.ineq.gini-p1_s1_t3.ineq.gini)*100


%change in employment
(mean(decomp_t1_risk_shock.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_risk_shock.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_risk_shock.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_risk_jdisp.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_risk_jdisp.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_risk_jdisp.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_risk_shock.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_risk_shock.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_risk_shock.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100

(mean(decomp_t1_risk_job.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_risk_job.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_risk_job.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_risk_job.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_risk_job.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_risk_job.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100

(mean(decomp_t1_risk_ini.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_risk_ini.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_risk_ini.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_risk_ini.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_risk_ini.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_risk_ini.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100

(mean(decomp_t1_risk_health.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_risk_health.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_risk_health.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_risk_health.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_risk_health.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_risk_health.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100

(mean(decomp_t1_wage.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_wage.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_wage.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_wage.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_wage.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_wage.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100

(mean(decomp_t1_welfare.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(decomp_t2_welfare.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(decomp_t3_welfare.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100

(mean(decomp_t1_welfare.emp_age(101:work))-mean(p1_s1_t1.emp_age(101:work)))*100
(mean(decomp_t2_welfare.emp_age(101:work))-mean(p1_s1_t2.emp_age(101:work)))*100
(mean(decomp_t3_welfare.emp_age(101:work))-mean(p1_s1_t3.emp_age(101:work)))*100



%change in olf
(mean(decomp_t1_risk_shock.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_risk_shock.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_risk_shock.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_risk_jdisp.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_risk_jdisp.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_risk_jdisp.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_risk_shock.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_risk_shock.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_risk_shock.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100

(mean(decomp_t1_risk_job.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_risk_job.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_risk_job.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_risk_job.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_risk_job.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_risk_job.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100

(mean(decomp_t1_risk_ini.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_risk_ini.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_risk_ini.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_risk_ini.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_risk_ini.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_risk_ini.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100

(mean(decomp_t1_risk_health.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_risk_health.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_risk_health.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_risk_health.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_risk_health.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_risk_health.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100

(mean(decomp_t1_wage.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_wage.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_wage.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_wage.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_wage.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_wage.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100

(mean(decomp_t1_welfare.olf_age(1:work))-mean(p1_s1_t1.olf_age(1:work)))*100
(mean(decomp_t2_welfare.olf_age(1:work))-mean(p1_s1_t2.olf_age(1:work)))*100
(mean(decomp_t3_welfare.olf_age(1:work))-mean(p1_s1_t3.olf_age(1:work)))*100

(mean(decomp_t1_welfare.olf_age(121:work))-mean(p1_s1_t1.olf_age(121:work)))*100
(mean(decomp_t2_welfare.olf_age(121:work))-mean(p1_s1_t2.olf_age(121:work)))*100
(mean(decomp_t3_welfare.olf_age(121:work))-mean(p1_s1_t3.olf_age(121:work)))*100


%change in DI
(mean(decomp_t1_risk_shock.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_risk_shock.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_risk_shock.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_risk_jdisp.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_risk_jdisp.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_risk_jdisp.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_risk_shock.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_risk_shock.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_risk_shock.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100

(mean(decomp_t1_risk_job.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_risk_job.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_risk_job.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_risk_job.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_risk_job.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_risk_job.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100

(mean(decomp_t1_risk_ini.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_risk_ini.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_risk_ini.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_risk_ini.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_risk_ini.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_risk_ini.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100

(mean(decomp_t1_risk_health.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_risk_health.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_risk_health.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_risk_health.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_risk_health.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_risk_health.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100

(mean(decomp_t1_wage.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_wage.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_wage.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_wage.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_wage.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_wage.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100

(mean(decomp_t1_welfare.disab_info.DI_rate_age(1:work))-mean(p1_s1_t1.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t2_welfare.disab_info.DI_rate_age(1:work))-mean(p1_s1_t2.disab_info.DI_rate_age(1:work)))*100
(mean(decomp_t3_welfare.disab_info.DI_rate_age(1:work))-mean(p1_s1_t3.disab_info.DI_rate_age(1:work)))*100

(mean(decomp_t1_welfare.disab_info.DI_rate_age(121:work))-mean(p1_s1_t1.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t2_welfare.disab_info.DI_rate_age(121:work))-mean(p1_s1_t2.disab_info.DI_rate_age(121:work)))*100
(mean(decomp_t3_welfare.disab_info.DI_rate_age(121:work))-mean(p1_s1_t3.disab_info.DI_rate_age(121:work)))*100


%change in employment, disability, JTJ rate
(mean(p2_s1_t1.emp_age(1:work))-mean(p1_s1_t1.emp_age(1:work)))*100
(mean(p2_s1_t2.emp_age(1:work))-mean(p1_s1_t2.emp_age(1:work)))*100
(mean(p2_s1_t3.emp_age(1:work))-mean(p1_s1_t3.emp_age(1:work)))*100
(mean(p2_s1_t1.disab_age(work-disable+1:work))-mean(p1_s1_t1.disab_age(work-disable+1:work)))*100
(mean(p2_s1_t2.disab_age(work-disable+1:work))-mean(p1_s1_t2.disab_age(work-disable+1:work)))*100
(mean(p2_s1_t3.disab_age(work-disable+1:work))-mean(p1_s1_t3.disab_age(work-disable+1:work)))*100
(p2_s1_t1.ee-p1_s1_t1.ee)*100
(p2_s1_t2.ee-p1_s1_t2.ee)*100
(p2_s1_t3.ee-p1_s1_t3.ee)*100


%% Graphs
load('emp.mat','emp');
load('lout.mat','lout');

figure(1)
data_emp_age = emp.g1_p1.*educ_share_age.g1.p1(1:4:end)+emp.g2_p1.*educ_share_age.g2.p1(1:4:end)+emp.g3_p1.*educ_share_age.g3.p1(1:4:end);
data_lout_age = lout.g1_p1.*educ_share_age.g1.p1(1:4:end)+lout.g2_p1.*educ_share_age.g2.p1(1:4:end)+lout.g3_p1.*educ_share_age.g3.p1(1:4:end);
plot(25:1:61,pop_emp_age(1:4:end-1),'LineWidth',2.5,'color',[0 0 1])
hold on
plot(25:1:61,pop_olf_age(1:4:end-1),'LineWidth',2.5,'Marker','o','color',[0 0 1])
hold on
plot(25:1:61,data_emp_age,'LineWidth',2.5,'LineStyle','--','color',[1 0 0])
hold on
plot(25:1:61,data_lout_age,'LineWidth',2.5,'LineStyle','--','color',[1 0 0],'Marker','x')
hold off
xlabel('Age','fontsize',13,'FontWeight','bold')
ylabel('Rate','fontsize',13,'FontWeight','bold')
h = legend('Model EMP','Model OLF','Data EMP','Data OLF');
set(h,'Location','SouthEast','fontsize',12)
xlim([25 61])
ylim([0 1])
