function SIPP_orig = meas_error(SIPP_panel,ma,type,spell)
% calculates wages with meassurement error in log wages following a MA
% process. In the data, we look at employment spells. We do the same here

% names = {'LC' 'emp' 'd EE' 'A' 'Gamma' 'wage' 'id'};
names = {'Emp' 'delta J' 'P' 'Gamma' 'asset' 'Acc' 'w' 'c' 'i' 'education' 'age'};

sigma = ma.std(type);
parameter = -ma.coef(:,type); 
parameter = [1; parameter]'; %add contemepraneous effect
coef = flip(parameter);

%% compute spell the worker is in
SIPP_orig = SIPP_panel;

%calculate starting point of new agents (dead becomes new agent)
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,12) = diff(SIPP_panel(:,9));
SIPP_panel(:,12) = SIPP_panel(:,12)~=0; %make it a 1 indicator
SIPP_panel(1,12) = 1;
names{1,12} = 'd indi';

%calculate UE movement 
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,13) = diff(SIPP_panel(:,1));
SIPP_panel(:,13) = SIPP_panel(:,13)<0;
SIPP_panel(SIPP_panel(:,12)==1,13) = 0; %zero where new agent starts
names{1,13} = 'd UE';

%move EE one front
SIPP_panel(2:end,2) = SIPP_panel(1:end-1,2);

%compute spell number
if spell == 1 %treat EE movement as a new spell
    SIPP_panel(:,14) = SIPP_panel(:,2)+SIPP_panel(:,12)+SIPP_panel(:,13);
else
    SIPP_panel(:,14) = SIPP_panel(:,12)+SIPP_panel(:,13);
end
    
SIPP_panel(:,14) = SIPP_panel(:,14)~=0; %make it a 1 indicator
SIPP_panel(:,14) = cumsum(SIPP_panel(:,14));

%set spell to zero when agent is unemployed or dead
SIPP_panel(SIPP_panel(:,1)~=1,14) = 0;

SIPP_panel(SIPP_panel(:,1)==1,7) = log(SIPP_panel(SIPP_panel(:,1)==1,7)); %compute log wages

%compute wages with error 
randn('seed',66735);
index_pos = find(SIPP_panel(:,14)>0); %find index of employment spells
index = order_index(SIPP_panel(index_pos,14));
fcn = @(x){con_error(x,length(x),sigma,coef)};
SIPP_panel(index_pos,7) = accumarray_expand(SIPP_panel(index_pos,7),index,fcn);


SIPP_panel(SIPP_panel(:,1)==1,7) = exp(SIPP_panel(SIPP_panel(:,1)==1,7)); %compute wages
SIPP_orig(:,7) = SIPP_panel(:,7);
end