﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}


__global__ void prod_trans_e(double *E_e_g, double* E_u_g, double *E_f_g, double* E_r_g, double *E_e_b, double* E_u_b, double *E_f_b, double* E_r_b, const double *VUJ_g, const double* VUJ_b, const double *upper2_g, const double* upper2_b, const double *E_ee_f2_g, const double* E_ee_f2_b, const double *E_ee_r2_g, const double* E_ee_r2_b, const double *VU_g, const double* VU_b, const double *upper1_g, const double* upper1_b, const double *E_ee_f1_g, const double* E_ee_f1_b, const double *E_ee_r1_g, const double* E_ee_r1_b, const double *pgrid, const double *trans_emp_stay, const double* trans_emp_gb, const double* trans_emp_bg, double *par, int *index, int* index_life, const int t1)
{
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               
    //Expected value of employment over productivity
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;

    int work = index_life[0];
    int disable = index_life[1];

    //read out parameter vector
    double disab_c = par[0];
    double pi_gb = par[1];
    double pi_bg = par[2];

    //indexes
    int na = index[0];
    int np = index[1];
    int fnodes = index[2];
    int nc = index[3];
    int fnodes_nc = index[4];


    if (ROW < na && COL < np && PAGE < fnodes_nc) {

        double aux = PAGE / fnodes;
        int SHEET = floor(aux); //implied nc

        double pi_gb1 = 1 - pi_gb;
        double pi_bg1 = 1 - pi_bg;


        //today in good health
        double Ee = 0; //value of no job offer
        double Eu = 0; //value of becomming unemployed
        double Ef = 0; //value of forced offer
        double Er = 0; //value of regular offer
        double aux2;
        for (int i2 = 0; i2 < np; i2++) { //productivity state tomorrow
            aux2 = pgrid[i2] - pgrid[COL];
            if (aux2 < disab_c) {// eligible for DI
                Ee += pi_gb1 * trans_emp_stay[COL * np + i2] * upper2_g[PAGE * na * np + i2 * na + ROW];
                Ee += pi_gb * trans_emp_gb[COL * np + i2] * upper2_b[PAGE * na * np + i2 * na + ROW];
                Eu += pi_gb1 * trans_emp_stay[COL * np + i2] * VUJ_g[(t1 - work + disable + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Eu += pi_gb * trans_emp_gb[COL * np + i2] * VUJ_b[(t1 - work + disable + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Ef += pi_gb1 * trans_emp_stay[COL * np + i2] * E_ee_f2_g[PAGE * na * np + i2 * na + ROW];
                Ef += pi_gb * trans_emp_gb[COL * np + i2] * E_ee_f2_b[PAGE * na * np + i2 * na + ROW];
                Er += pi_gb1 * trans_emp_stay[COL * np + i2] * E_ee_r2_g[PAGE * na * np + i2 * na + ROW];
                Er += pi_gb * trans_emp_gb[COL * np + i2] * E_ee_r2_b[PAGE * na * np + i2 * na + ROW];
            }
            else {
                Ee += pi_gb1 * trans_emp_stay[COL * np + i2] * upper1_g[PAGE * na * np + i2 * na + ROW];
                Ee += pi_gb * trans_emp_gb[COL * np + i2] * upper1_b[PAGE * na * np + i2 * na + ROW];
                Eu += pi_gb1 * trans_emp_stay[COL * np + i2] * VU_g[(t1 + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Eu += pi_gb * trans_emp_gb[COL * np + i2] * VU_b[(t1 + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Ef += pi_gb1 * trans_emp_stay[COL * np + i2] * E_ee_f1_g[PAGE * na * np + i2 * na + ROW];
                Ef += pi_gb * trans_emp_gb[COL * np + i2] * E_ee_f1_b[PAGE * na * np + i2 * na + ROW];
                Er += pi_gb1 * trans_emp_stay[COL * np + i2] * E_ee_r1_g[PAGE * na * np + i2 * na + ROW];
                Er += pi_gb * trans_emp_gb[COL * np + i2] * E_ee_r1_b[PAGE * na * np + i2 * na + ROW];
            }
        }
        E_e_g[PAGE * na * np + COL * na + ROW] = Ee;
        E_u_g[PAGE * na * np + COL * na + ROW] = Eu;
        E_f_g[PAGE * na * np + COL * na + ROW] = Ef;
        E_r_g[PAGE * na * np + COL * na + ROW] = Er;



        //today in bad health
        Ee = 0; //value of no job offer
        Eu = 0; //value of becomming unemployed
        Ef = 0; //value of forced offer
        Er = 0; //value of regular offer
        for (int i2 = 0; i2 < np; i2++) { //productivity state tomorrow
            aux2 = pgrid[i2] - pgrid[COL];
            if (aux2 < disab_c) {// eligible for DI
                Ee += pi_bg1 * trans_emp_stay[COL * np + i2] * upper2_b[PAGE * na * np + i2 * na + ROW];
                Ee += pi_bg * trans_emp_bg[COL * np + i2] * upper2_g[PAGE * na * np + i2 * na + ROW];
                Eu += pi_bg1 * trans_emp_stay[COL * np + i2] * VUJ_b[(t1 - work + disable + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Eu += pi_bg * trans_emp_bg[COL * np + i2] * VUJ_g[(t1 - work + disable + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Ef += pi_bg1 * trans_emp_stay[COL * np + i2] * E_ee_f2_b[PAGE * na * np + i2 * na + ROW];
                Ef += pi_bg * trans_emp_bg[COL * np + i2] * E_ee_f2_g[PAGE * na * np + i2 * na + ROW];
                Er += pi_bg1 * trans_emp_stay[COL * np + i2] * E_ee_r2_b[PAGE * na * np + i2 * na + ROW];
                Er += pi_bg * trans_emp_bg[COL * np + i2] * E_ee_r2_g[PAGE * na * np + i2 * na + ROW];
            }
            else {
                Ee += pi_bg1 * trans_emp_stay[COL * np + i2] * upper1_b[PAGE * na * np + i2 * na + ROW];
                Ee += pi_bg * trans_emp_bg[COL * np + i2] * upper1_g[PAGE * na * np + i2 * na + ROW];
                Eu += pi_bg1 * trans_emp_stay[COL * np + i2] * VU_b[(t1 + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Eu += pi_bg * trans_emp_bg[COL * np + i2] * VU_g[(t1 + 1) * na * np * nc + SHEET * na * np + i2 * na + ROW];
                Ef += pi_bg1 * trans_emp_stay[COL * np + i2] * E_ee_f1_b[PAGE * na * np + i2 * na + ROW];
                Ef += pi_bg * trans_emp_bg[COL * np + i2] * E_ee_f1_g[PAGE * na * np + i2 * na + ROW];
                Er += pi_bg1 * trans_emp_stay[COL * np + i2] * E_ee_r1_b[PAGE * na * np + i2 * na + ROW];
                Er += pi_bg * trans_emp_bg[COL * np + i2] * E_ee_r1_g[PAGE * na * np + i2 * na + ROW];
            }
        }
        E_e_b[PAGE * na * np + COL * na + ROW] = Ee;
        E_u_b[PAGE * na * np + COL * na + ROW] = Eu;
        E_f_b[PAGE * na * np + COL * na + ROW] = Ef;
        E_r_b[PAGE * na * np + COL * na + ROW] = Er;
    }
}
