﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}

//integrate over prod transition unemployed
__global__ void prod_trans_u(double* U_n_g, double* U_f_g, double* U_n_b, double* U_f_b, const double* EV_ue_o_g, const double* VU_g, const double* EV_ue_o_b, const double* VU_b, const double* trans_u_stay, const double* trans_u_gb, const double* trans_u_bg, const double* par, int *index, const int t1)
{ 
                                                                                                          
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;


    //read out parameter vector
    double pi_gb = par[0];
    double pi_bg = par[1];

    int na = index[0];
    int np = index[1];
    //int fnodes = index[2];
    int nc = index[3];
    //int fnodes_nc = index[4];


    if (ROW < na && COL < np && PAGE < nc) {
 
        double pi_gb1 = 1.0 - pi_gb;
        double pi_bg1 = 1.0 - pi_bg;


        // integral over productivity transition good health unemployed (given current prod state and good health state)
        double val1 = 0.0;
        double val2 = 0.0;
        for (int i2 = 0; i2 < np; i2++) { //possible states tomorrow
            val1 += pi_gb1 * trans_u_stay[COL * np + i2] * VU_g[(t1 + 1) * na * np * nc + PAGE * na * np + i2 * na + ROW];
            val1 += pi_gb * trans_u_gb[COL * np + i2] * VU_b[(t1 + 1) * na * np * nc + PAGE * na * np + i2 * na + ROW];
            val2 += pi_gb1 * trans_u_stay[COL * np + i2] * EV_ue_o_g[PAGE * na * np + i2 * na + ROW];
            val2 += pi_gb * trans_u_gb[COL * np + i2] * EV_ue_o_b[PAGE * na * np + i2 * na + ROW];
        }
        U_n_g[PAGE * na * np + COL * na + ROW] = val1;
        U_f_g[PAGE * na * np + COL * na + ROW] = val2;

        // integral over productivity transition bad health unemployed (given current prod state and bad health state)
        val1 = 0.0;
        val2 = 0.0;
        for (int i2 = 0; i2 < np; i2++) { //possible states tomorrow
            val1 += pi_bg1 * trans_u_stay[COL * np + i2] * VU_b[(t1 + 1) * na * np * nc + PAGE * na * np + i2 * na + ROW];
            val1 += pi_bg * trans_u_bg[COL * np + i2] * VU_g[(t1 + 1) * na * np * nc + PAGE * na * np + i2 * na + ROW];
            val2 += pi_bg1 * trans_u_stay[COL * np + i2] * EV_ue_o_b[PAGE * na * np + i2 * na + ROW];
            val2 += pi_bg * trans_u_bg[COL * np + i2] * EV_ue_o_g[PAGE * na * np + i2 * na + ROW];
        }
        U_n_b[PAGE * na * np + COL * na + ROW] = val1;
        U_f_b[PAGE * na * np + COL * na + ROW] = val2;

    }
}
