function TW = tw_stats(NLSY)

%compute Topel Ward statistics

%drop the disabled and sum all unemployed
NLSY(NLSY(:,1)==4,:) = [];
NLSY(NLSY(:,1)==5,:) = [];
NLSY(NLSY(:,1)==3,1) = 2;

% start invidual with first job experience
NLSY(:,14) = NLSY(:,1)==1;
fcn = @(x){cumsum(x)}; 
NLSY(:,14) = accumarray_expand(NLSY(:,14),NLSY(:,9),fcn);
NLSY(NLSY(:,14)<1,:) = [];
NLSY(:,13) = [];

%redefine age
fcn = @(x){cumsum(x)};
NLSY(:,13) = 1;
NLSY(:,13) = accumarray_expand(NLSY(:,13),NLSY(:,9),fcn);

%% tenure and experience

%compute experience 
NLSY = [NLSY zeros(length(NLSY),1)];
fcn = @(x){cumsum(x)}; 
NLSY(:,14) = accumarray_expand(NLSY(:,1)==1,NLSY(:,9),fcn);
NLSY(:,14) = NLSY(:,14)./4;

%compute tenure
NLSY = [NLSY zeros(length(NLSY),1)]; %change id
NLSY(2:end,15) = diff(NLSY(:,9)); 
NLSY(1,15) = 1;

NLSY = [NLSY zeros(length(NLSY),1)]; %UE
NLSY(2:end,16) = diff(NLSY(:,1)); 
NLSY(NLSY(:,15)==1,16) = 0;
NLSY(:,16) = NLSY(:,16)==-1;


NLSY(2:end,2) = NLSY(1:end-1,2); %shift job switch one ahead
NLSY(NLSY(:,15)==1,2) = 0;

NLSY(:,17) = NLSY(:,2)+NLSY(:,16);
NLSY(NLSY(:,17)~=0,17) = 1;
fcn = @(x){cumsum(x)};
NLSY(:,18) = accumarray_expand(NLSY(:,17),NLSY(:,9),fcn);
NLSY(NLSY(:,1)==2,18) = 0;

%tenure
NLSY(:,19) = group([NLSY(:,9) NLSY(:,18)]); %group id and job spell
NLSY(NLSY(:,1)==2,19) = 0;
fcn = @(x){cumsum(x)};
NLSY(:,20) = accumarray_expand(ones(length(NLSY),1),NLSY(:,19),fcn); %tenure
NLSY(NLSY(:,1)==2,20) = 0;
NLSY(:,15:17) = [];

%% Indicator of job ending and number of job-to-job transitions

%indicator that job ends next month
NLSY = [NLSY zeros(length(NLSY),1)];
NLSY(2:end,18) = diff(NLSY(:,17));
NLSY(:,18) = NLSY(:,18)<0;
% NLSY(NLSY(:,14)==1,17) = 0;
NLSY(1:end-1,18) = NLSY(2:end,18); %shift one front

fcn = @(x){cumsum(x)};
NLSY(:,19) = accumarray_expand(NLSY(:,2),NLSY(:,9),fcn); %number of job to job transitions

%% statistics
NLSY(NLSY(:,14)>=11,:) = []; %restrict to first 10 years of experience

%months since labor market entry
age_12 = NLSY(NLSY(:,13)==4,:);
age_24 = NLSY(NLSY(:,13)==8,:);
age_36 = NLSY(NLSY(:,13)==12,:);
age_48 = NLSY(NLSY(:,13)==16,:);
age_60 = NLSY(NLSY(:,13)==20,:);
age_72 = NLSY(NLSY(:,13)==24,:);
age_84 = NLSY(NLSY(:,13)==28,:);
age_96 = NLSY(NLSY(:,13)==32,:);
age_108 = NLSY(NLSY(:,13)==36,:);
age_120 = NLSY(NLSY(:,13)==40,:);


TW.jobs12 = mean(age_12(:,16)); %number of jobs
TW.jobs24 = mean(age_24(:,16));
TW.jobs36 = mean(age_36(:,16));
TW.jobs48 = mean(age_48(:,16));
TW.jobs60 = mean(age_60(:,16));
TW.jobs72 = mean(age_72(:,16));
TW.jobs84 = mean(age_84(:,16));
TW.jobs96 = mean(age_96(:,16));
TW.jobs108 = mean(age_108(:,16));
TW.jobs120 = mean(age_120(:,16));

TW.tenure12 = mean(age_12(:,17));
TW.tenure24 = mean(age_24(:,17));
TW.tenure36 = mean(age_36(:,17));
TW.tenure48 = mean(age_48(:,17));
TW.tenure60 = mean(age_60(:,17));
TW.tenure72 = mean(age_72(:,17));
TW.tenure84 = mean(age_84(:,17));
TW.tenure96 = mean(age_96(:,17));
TW.tenure108 = mean(age_108(:,17));
TW.tenure120 = mean(age_120(:,17));

TW.exp12 = mean(age_12(:,14));
TW.exp24 = mean(age_24(:,14));
TW.exp36 = mean(age_36(:,14));
TW.exp48 = mean(age_48(:,14));
TW.exp60 = mean(age_60(:,14));
TW.exp72 = mean(age_72(:,14));
TW.exp84 = mean(age_84(:,14));
TW.exp96 = mean(age_96(:,14));
TW.exp108 = mean(age_108(:,14));
TW.exp120 = mean(age_120(:,14));

TW.jtj12 = mean(age_12(:,19));
TW.jtj24 = mean(age_24(:,19));
TW.jtj36 = mean(age_36(:,19));
TW.jtj48 = mean(age_48(:,19));
TW.jtj60 = mean(age_60(:,19));
TW.jtj72 = mean(age_72(:,19));
TW.jtj84 = mean(age_84(:,19));
TW.jtj96 = mean(age_96(:,19));
TW.jtj108 = mean(age_108(:,19));
TW.jtj120 = mean(age_120(:,19));

TW.exit12 = sum((NLSY(:,13)==12).*NLSY(:,18))./sum(NLSY(:,13)==12);
TW.exit24 = sum((NLSY(:,13)==24).*NLSY(:,18))./sum(NLSY(:,13)==24);
TW.exit36 = sum((NLSY(:,13)==36).*NLSY(:,18))./sum(NLSY(:,13)==36);
TW.exit48 = sum((NLSY(:,13)==48).*NLSY(:,18))./sum(NLSY(:,13)==48);
TW.exit60 = sum((NLSY(:,13)==60).*NLSY(:,18))./sum(NLSY(:,13)==60);
TW.exit72 = sum((NLSY(:,13)==72).*NLSY(:,18))./sum(NLSY(:,13)==72);
TW.exit84 = sum((NLSY(:,13)==84).*NLSY(:,18))./sum(NLSY(:,13)==84);
TW.exit96 = sum((NLSY(:,13)==96).*NLSY(:,18))./sum(NLSY(:,13)==96);
TW.exit108 = sum((NLSY(:,13)==108).*NLSY(:,18))./sum(NLSY(:,13)==108);
TW.exit120 = sum((NLSY(:,13)==120).*NLSY(:,18))./sum(NLSY(:,13)==120);

%% wage growth jtj

%drop unemployed
NLSY(NLSY(:,1)==2,:) = [];


%wage growth
NLSY = [NLSY zeros(length(NLSY),1)];
NLSY(2:end,20) = diff(log(NLSY(:,7))); %not important here to cler for new id and UE transitions as only evaluated at JTJ


jtj = NLSY(NLSY(:,2)==1,:);

TW.wgr_1_10_jtj = sum((jtj(:,14)>=0).*(jtj(:,14)<=2.5).*jtj(:,20))./sum((jtj(:,14)>=0).*(jtj(:,14)<=2.5));
TW.wgr_11_20_jtj = sum((jtj(:,14)>2.5).*(jtj(:,14)<=5).*jtj(:,20))./sum((jtj(:,14)>2.5).*(jtj(:,14)<=5));
TW.wgr_21_30_jtj = sum((jtj(:,14)>5).*(jtj(:,14)<=7.5).*jtj(:,20))./sum((jtj(:,14)>5).*(jtj(:,14)<=7.5));
TW.wgr_31_40_jtj = sum((jtj(:,14)>7.5).*(jtj(:,14)<=11).*jtj(:,20))./sum((jtj(:,14)>7.5).*(jtj(:,14)<=11));
TW.jtj_N = length(jtj);

%% wage growth between year 1 and 10

%cimulative wage growth at job to job transition
% fcn = @(x){create_diff(x)};
% NLSY(:,19) = accumarray_expand(log(NLSY(:,7)),NLSY(:,9),fcn); %wage growth
% NLSY(:,20) = NLSY(:,19).*(NLSY(:,2)==1); %wage growth at jtj
% fcn = @(x){mean(x)};
% aux = sortrows(NLSY,13);
% aux = accumarray_expand_s(aux(:,20),aux(:,13),fcn);
% cum_wage_gr_jtj = cumsum(aux);
% 
% %cumulative wage growth
% fcn = @(x){mean(x)};
% aux = sortrows(NLSY,13);
% aux = accumarray_expand_s(aux(:,19),aux(:,13),fcn);
% cum_wage_gr = cumsum(aux);
% TW.wgr_40_share_jtj = cum_wage_gr_jtj(end)./cum_wage_gr(end);

fcn = @(x){create_diff(x)};
NLSY(:,20) = accumarray_expand(NLSY(:,7),NLSY(:,9),fcn); %wage change
NLSY(:,21) = NLSY(:,20).*(NLSY(:,2)==1); %wage change at jtj
fcn = @(x){cumsum(x)};
NLSY(:,20) = accumarray_expand(NLSY(:,20),NLSY(:,9),fcn);
NLSY(:,21) = accumarray_expand(NLSY(:,21),NLSY(:,9),fcn);
wage_growth_10 = NLSY(NLSY(:,14)==10.75,:);
wage_growth_10(:,22) = wage_growth_10(:,21)./wage_growth_10(:,20); %wage growth at jtj/total wage growth
% TW.wgr_40_share_jtj = mean(wage_growth_10(:,21));
TW.wgr_40_share_jtj = mean(wage_growth_10(:,21))./mean(wage_growth_10(:,20));
end