﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}

//integrate upper1+upper2 over transition probabilities
__global__ void upper2_gamma(double* E_ee_f2, double* E_ee_r2, double* E_ee_f1, double* E_ee_r1, const double* upper1, const double* upper2, const double* gamma_w, const double* prob_move, int *index)
{
    
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;



    int na = index[0];
    int np = index[1];
    int fnodes = index[2];
    //int nc = index[3];
    int fnodes_nc = index[4];


    if (ROW < na && COL < np && PAGE < fnodes_nc) {
 
        double aux = PAGE / fnodes;
        int SHEET = floor(aux); //implied nc
        int PAGE2 = PAGE - (SHEET * fnodes); // the fnodes entry

        
        double val1 = 0.0;
        double val2 = 0.0;
        double val3 = 0.0;
        double val4 = 0.0;
        for (int i2 = 0; i2 < fnodes; i2++) { //possible offers
            // take the integral over reallocation offers
            val1 += gamma_w[i2] * upper1[SHEET * na * np * fnodes + i2 * np * na + COL * na + ROW];
            val2 += gamma_w[i2] * upper2[SHEET * na * np * fnodes + i2 * np * na + COL * na + ROW];
            val3 += prob_move[PAGE2 * fnodes + i2] * upper1[SHEET * na * np * fnodes + i2 * np * na + COL * na + ROW];
            val4 += prob_move[PAGE2 * fnodes + i2] * upper2[SHEET * na * np * fnodes + i2 * np * na + COL * na + ROW];
        }
        E_ee_f1[PAGE * na * np + COL * na + ROW] = val1;
        E_ee_f2[PAGE * na * np + COL * na + ROW] = val2;
        E_ee_r1[PAGE * na * np + COL * na + ROW] = val3;
        E_ee_r2[PAGE * na * np + COL * na + ROW] = val4;




    }
}
