﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}


__global__ void val_fun_u(double* VU, double* policy_a, int* policy_s, const double* U_n_inter, const double* U_f_inter, const double* agrid, const double* aprime, const double* grid_nc, const double* sgrid, const double* search_c, int* index, int* index_life, double* par, const int t1)
{
    //Value function unemployed  
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;


    //read out parameter vector
    double R = par[0];
    double beta = par[1];
    double b = par[2];
    double transfer = par[3];
    double theta = par[4];
    double abar = par[5];

    int na = index[0];
    int np = index[1];
    //int fnodes = index[2];
    int nc = index[3];
    //int fnodes_nc = index[4];
    int ns = index[5];
    int nap = index[6];

    //int work = index_life[0];
    //int disable = index_life[1];
    //int retire = index_life[2];

    //initialization
    double c;
    double util;
    double EV;
    double EV_ue;
    double EV_uu;
    double WW;
    double lt_inc;
    double resources;



    if (ROW < na && COL < np && PAGE < nc) {
        //initialize
        double theta1 = 1 - theta;

        //lt_inc = t1 * grid_nc[PAGE] / (t1+1); //life time income to be interpolated
        //int pos_lt = find_pos(lt_inc, grid_nc, nc); //index
        //if (pos_lt == nc - 1) {
        //    pos_lt = nc - 2;
        //}

        //optimal policy
        policy_s[t1 * nc * na * np + PAGE * na * np + COL * na + ROW] = 0;
        double W = -10000000.0; // value
        policy_a[t1 * nc * na * np + PAGE * na * np + COL * na + ROW] = agrid[0];
        for (int i1 = 0; i1 < ns; i1++) { //loop over search effort
            int a1 = 0;
            while (a1 < nap) { //loop over asset choices
                if (aprime[a1] <= abar) {
                    resources = R * agrid[ROW] + transfer + b;
                    c = resources - aprime[a1];
                }
                else {
                    resources = R * agrid[ROW] + b;
                    c = resources - aprime[a1];
                }
                if (c < 0) { //not a feasible choice
                    a1 = nap;
                }
                else {
                    util = pow(c, theta1) / theta1;
                    //pos_a = find_pos(aprime[a1], agrid, na); //choice index
                    //if (pos_a == na - 1) {
                    //    pos_a = na - 2;
                    //}

                    //weights of 2-D interpolation of lt_inc -- aprime
                    //num = (grid_nc[pos_lt + 1] - grid_nc[pos_lt]) * (agrid[pos_a + 1] - agrid[pos_a]);  // x_g = grid_nc
                    //a00 = ((grid_nc[pos_lt + 1] - lt_inc) * (agrid[pos_a + 1] - aprime[a1])) / num;
                    //a01 = ((grid_nc[pos_lt + 1] - lt_inc) * (aprime[a1] - agrid[pos_a])) / num;
                    //a10 = ((lt_inc - grid_nc[pos_lt]) * (agrid[pos_a + 1] - aprime[a1])) / num;
                    //a11 = ((lt_inc - grid_nc[pos_lt]) * (aprime[a1] - agrid[pos_a])) / num;

                    //EV_ue = a00 * U_f[pos_lt * na * np + COL * na + pos_a] + a01 * U_f[pos_lt * na * np + COL * na + pos_a + 1] + a10 * U_f[(pos_lt+1) * na * np + COL * na + pos_a] + a11 * U_f[(pos_lt + 1) * na * np + COL * na + pos_a + 1];
                    //EV_uu = a00 * U_n[pos_lt * na * np + COL * na + pos_a] + a01 * U_n[pos_lt * na * np + COL * na + pos_a + 1] + a10 * U_n[(pos_lt + 1) * na * np + COL * na + pos_a] + a11 * U_n[(pos_lt + 1) * na * np + COL * na + pos_a + 1];

                    EV_ue = U_f_inter[PAGE * nap * np + COL * nap + a1];
                    EV_uu = U_n_inter[PAGE * nap * np + COL * nap + a1];

                    EV = beta * (sgrid[i1] * EV_ue + (1 - sgrid[i1]) * EV_uu);
                    WW = util - search_c[i1] + EV;
                    if (WW > W) { //new optimum
                        W = WW;
                        policy_a[t1 * nc * na * np + PAGE * na * np + COL * na + ROW] = aprime[a1];
                        policy_s[t1 * nc * na * np + PAGE * na * np + COL * na + ROW] = i1;
                    }
                    a1 = a1 + 1;
                }
            }
        }

        VU[t1 * nc * na * np + PAGE * na * np + COL * na + ROW] = W;
    }

}
