﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}


__global__ void val_fun_UJ(double *Vnew, double *policy_a, int *policy_d, const int *policy_s, const double *VD, const double *U_n_inter, const double *U_f_inter, const double* grid_nc, const double *agrid, const double *sgrid, const double *aprime, const int* abound, const double* search_c, int *index, int *index_life, double *par, const int t1)
{
    //Value function of just unemployed
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;

    //EV_d has dimension na*nc*disable
    //Un and Uf have dimensions na*np*nc

    //read out parameter vector
    double R = par[0];
    double beta = par[1];
    double b = par[2];
    double transfer = par[3];
    double theta = par[4];
    double psi = par[5];
    double abar = par[6];

    int work = index_life[0];
    int disable = index_life[1];
    //int retire = index_life[2];

    int na = index[0];
    int np = index[1];
    int nc = index[2];
    //int ns = index[3];
    int nap = index[4];

    //initialization
    double c;
    double util;
    double EV_ud;
    double EV_uu;
    double EV_ue;
    double EVD;
    double EVU;
    double WW;
    double sc;
    double d_pol;
    double find;
    double lt_inc;
    double num;
    double a00;
    double a01;
    double a10;
    double a11;
    double resources;
    int pos_a;


    if (ROW < na && COL < np && PAGE < nc) {
        //initialize
        double theta1 = 1 - theta;
        int t2 = t1 - work + disable;

        //life-time income
        lt_inc = t1 * grid_nc[PAGE] / (t1 + 1); //life time income to be interpolated
        int pos_lt = find_pos(lt_inc, grid_nc, nc); //index
        if (pos_lt == nc - 1) {
            pos_lt = nc - 2;
        }

        //search costs and job finding rate
        sc = search_c[policy_s[t1 * nc * np * na + PAGE * na * np + COL * na + ROW]];
        find = sgrid[policy_s[t1 * nc * np * na + PAGE * na * np + COL * na + ROW]];

        //optimal policy
        double W = -10000000.0; // value
        policy_a[t2 * nc * np * na + PAGE * na * np + COL * na + ROW] = agrid[0];
        policy_d[t2 * nc * np * na + PAGE * na * np + COL * na + ROW] = 0;
        int a1 = 0;
        while (a1 < nap) { //loop over asset choices
            if (aprime[a1] <= abar) {
                resources = R * agrid[ROW] + transfer + b;
                c = resources - aprime[a1];
            }
            else {
                resources = R * agrid[ROW] + b;
                c = resources - aprime[a1];
            }

            if (c < 0) { //not a feasible choice
                a1 = nap;
            }
            else {
                util = pow(c, theta1) / theta1;
                pos_a = abound[a1];

                //weights of 2-D interpolation of lt_inc -- aprime
                num = (grid_nc[pos_lt + 1] - grid_nc[pos_lt]) * (agrid[pos_a + 1] - agrid[pos_a]);  // x_g = grid_nc
                a00 = ((grid_nc[pos_lt + 1] - lt_inc) * (agrid[pos_a + 1] - aprime[a1])) / num;
                a01 = ((grid_nc[pos_lt + 1] - lt_inc) * (aprime[a1] - agrid[pos_a])) / num;
                a10 = ((lt_inc - grid_nc[pos_lt]) * (agrid[pos_a + 1] - aprime[a1])) / num;
                a11 = ((lt_inc - grid_nc[pos_lt]) * (aprime[a1] - agrid[pos_a])) / num;

                //value of disability
                EV_ud = a00 * VD[(t2 + 1) * nc * na + pos_lt * na + pos_a] + a01 * VD[(t2 + 1) * nc * na + pos_lt * na + pos_a + 1] + a10 * VD[(t2 + 1) * nc * na + (pos_lt + 1) * na + pos_a] + a11 * VD[(t2 + 1) * nc * na + (pos_lt + 1) * na + pos_a + 1];

                //value of staying unemployed
                EV_uu = U_n_inter[PAGE * nap * np + COL * nap + a1];

                //value of becoming employed
                EV_ue = U_f_inter[PAGE * nap * np + COL * nap + a1];

                //value of applying for disability
                EVD = beta * (psi * EV_ud + (1 - psi) * EV_uu);

                //value of searching in U
                EVU = beta * (find * EV_ue + (1 - find) * EV_uu);

                if (EVD > (EVU - sc)) { //prefer disability
                    d_pol = 1;
                    WW = util + EVD;
                }
                else {
                    d_pol = 0;
                    WW = util - sc + EVU;
                }
                if (WW > W) { //new optimum
                    W = WW;
                    policy_a[t2 * nc * np * na + PAGE * na * np + COL * na + ROW] = aprime[a1];
                    policy_d[t2 * nc * np * na + PAGE * na * np + COL * na + ROW] = d_pol;
                }
                a1 = a1 + 1;
                }
            }
        Vnew[t2 * nc * np * na + PAGE * na * np + COL * na + ROW] = W;
    }

}
