﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}

__global__ void val_fun_ret(double* Vnew, double* policy_a, const double* agrid, const double* aprime, const int* abound, const double* ssinc, const double* ssinc_trans, int* index, double* par, const int t)
{
    //Value function of retired
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;


    //read out parameter vector
    double R = par[0];
    double beta = par[1];
    double theta = par[2];
    double abar = par[3];

    int na = index[0];
    int nc = index[1];
    int nap = index[2];

    //initialization
    double c_pol;
    double util;
    double EV;
    double WW;
    int pos_a;




    if (ROW < na && COL < nc) {
        //
        double theta1 = 1 - theta;

        double W = -10000000.0; // value
        double c = 0;
        policy_a[t * na * nc + COL * na + ROW] = aprime[0];

        int a1 = 0;
        while (a1 < nap) {
            if (aprime[a1] <= abar) {
                c = R * agrid[ROW] + ssinc_trans[COL] - aprime[a1];
            }
            else {
                c = R * agrid[ROW] + ssinc[COL] - aprime[a1];
            }
            if (c < 0) { //not a feasible choice
                a1 = nap;
            }
            else {
                util = pow(c, theta1) / theta1;

                pos_a = abound[a1];

                EV = Vnew[(t + 1) * na * nc + COL * na + pos_a] + (Vnew[(t + 1) * na * nc + COL * na + pos_a + 1] - Vnew[(t + 1) * na * nc + COL * na + pos_a]) * (aprime[a1] - agrid[pos_a]) / (agrid[pos_a + 1] - agrid[pos_a]);
                WW = util + beta * EV;
                if (WW > W) { //new optimum
                    W = WW;
                    policy_a[t * na * nc + COL * na + ROW] = aprime[a1];
                }
                a1 = a1 + 1;
            }
        }
        Vnew[t * na * nc + COL * na + ROW] = W;
    }
       

}


