﻿
#include <math.h>

__device__ int find_pos(double sca, const double* grid, const int N) {

    int pos = 0;
    int i1 = 0;
    while (i1 < N) {
        if (sca >= grid[i1]) {
            pos = i1;
            i1 = i1 + 1;
        }
        else {
            i1 = N;
        }
    }
    return pos;
}

__device__ double lininter(double sca, const double* y, const double* grid, const int N) {
    //1D linear interpolation
    int pos = find_pos(sca, grid, N);

    //if (pos == 0) {
    //    pos = 1;
    //}
    if (pos == N - 1) {
        pos = N - 2;
    }

    double y0 = y[pos] + (y[pos + 1] - y[pos]) * (sca - grid[pos]) / (grid[pos + 1] - grid[pos]);

    return y0;

}

__device__ double lininter2(const double x0, const double y0, const double* V, const double* Xgrid, const double* Ygrid, const int Nx, const int Ny, const int Nx2, const int Ny2) {
    //2D linear interpolation. The vector V has length Nx*Ny and entry Nx=1 Ny=3 is at Nx*Ny+Ny

    int pos_x = find_pos(x0, Xgrid, Nx);

    if (pos_x == Nx - 1) {
        pos_x = Nx - 2;
    }

    int pos_y = find_pos(y0, Ygrid, Ny);

    if (pos_y == Ny - 1) {
        pos_y = Ny - 2;
    }


    double num = ((Xgrid[pos_x + 1] - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - Ygrid[pos_y]));
    double a00 = ((Xgrid[pos_x + 1] - x0) * (Ygrid[pos_y + 1] - y0)) / num;
    double a01 = ((Xgrid[pos_x + 1] - x0) * (y0 - Ygrid[pos_y])) / num;
    double a10 = ((x0 - Xgrid[pos_x]) * (Ygrid[pos_y + 1] - y0)) / num;
    double a11 = ((x0 - Xgrid[pos_x]) * (y0 - Ygrid[pos_y])) / num;

    double Vinter = a00 * V[pos_x * Ny + pos_y] + a01 * V[(pos_x + 1) * Ny + pos_y] + a10 * V[pos_x * Ny + pos_y + 1] + a11 * V[(pos_x + 1) * Ny + pos_y + 1];


    return Vinter;

}


__global__ void val_fun_u_copy(double* V_out, double* policy_a_out, int* policy_s_out, const double* V_in, const double* policy_a_in, const int* policy_s_in, int* index, const int t)
{
    //Value function unemployed in last period with bad health (copy good state)
    int COL = blockIdx.x * blockDim.x + threadIdx.x;
    int ROW = blockIdx.y * blockDim.y + threadIdx.y;
    int PAGE = blockIdx.z * blockDim.z + threadIdx.z;


    int na = index[0];
    int np = index[1];
    int nc = index[2];
    //int ns = index[3];
    //int nap = index[4];


    //initialization


    if (ROW < na && COL < np && PAGE < nc) {

        V_out[t * nc * na * np + PAGE * na * np + COL * na + ROW] = V_in[t * nc * na * np + PAGE * na * np + COL * na + ROW];
        policy_a_out[t * nc * na * np + PAGE * na * np + COL * na + ROW] = policy_a_in[t * nc * na * np + PAGE * na * np + COL * na + ROW];
        policy_s_out[t * nc * na * np + PAGE * na * np + COL * na + ROW] = policy_s_in[t * nc * na * np + PAGE * na * np + COL * na + ROW];
        
    }

}
