***************************************************************************
****This do file estimates structurally the residual wage growth process***
***************************************************************************


set more off
clear all


cd "D:\Uni\Ariel\SIPP 7.7.2023"

/*
preserve

**********Export estimated selection components (COUNTERFACTUAL)******************
use counter_est_selection_all, clear
cap drop period
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013

keep if period==3

**P(P=1,P-1=1)**
gen part_counter=PHI101
**P(M=1| P=1,P-1=1)**
gen mob_counter=prob_M1

drop if part_counter==.
drop if mob_counter==.

order period sex grades wpfinwgt part_counter mob_counter 
outsheet period sex grades wpfinwgt part_counter mob_counter using "Selection_period3_counter.txt", replace nonames 
sleep 1000
restore
*/



**********Export estimated selection components******************
use est_selection_all, clear

cap drop period
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013

**P(P=1,P-1=1)**
gen part_true=PHI101
**P(M=1| P=1,P-1=1)**
gen mob_true=prob_M1

order period sex grades wpfinwgt part_true mob_true 
preserve
keep if period==1 & sex==1
drop if part_true==.
drop if mob_true==.
outsheet period sex grades wpfinwgt part_true mob_true using "Selection_period1.txt", replace nonames 
sleep 1000
restore

preserve
keep if period==2 & sex==1
drop if part_true==.
drop if mob_true==.
outsheet period sex grades wpfinwgt part_true mob_true using "Selection_period2.txt", replace nonames 
sleep 1000
restore

preserve
order period sex grades wpfinwgt part_true mob_true 
keep if period==3 & sex==1
drop if part_true==.
drop if mob_true==.
outsheet  period sex grades wpfinwgt part_true mob_true using "Selection_period3.txt", replace nonames 
sleep 1000
restore






**Sort original data, to merge with the g function to see what drives selection
use data_sipp_new_forlater_qt, clear
sort id year quarter
save data_sipp_new_forlater_qt, replace

use est_selection_all, clear
drop if panel_year==89

sort id year quarter
merge id year quarter using data_sipp_new_forlater_qt
drop _merge
drop if M==.
drop if panel_year==89

gen id2=id
destring id2, replace
cap drop time
egen time=group(year quarter)
xtset id2 time
gen change_occ=0
replace change_occ=1 if new_disag_group_occ!=L.new_disag_group_occ & new_disag_group_occ!=. & L.new_disag_group_occ!=. 

gen change_ind=0
replace change_ind=1 if ind_group!=L.ind_group & ind_group!=. & L.ind_group!=. 

**Generate the within and between M***
gen M_w=0
replace M_w=1 if M==1 & change_ind==0 & change_occ==0

gen M_b=0
replace M_b=1 if M==1 & (change_ind==1 | change_occ==1)

ren g dlw

sort id year quarter

cap drop time
egen time=group(year quarter)
sort id year quarter

/* wage regression corrected for participation mills ratio, only participants*/

gen C1=pdf_a1*PHI2A12A13/PHI101
gen C2=pdf_a2*PHIA21A23/PHI101
gen C3=pdf_a1*PHIA12A13/PHI101
gen C4=pdf_a3*PHIA31A32/PHI101

cap drop dummy_time*
set matsize 2000


***************************Hourly WAGE GROWTH EQUATION *********************************
*********************************************************************************


gen dxb=.
cap drop period
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013


bysort period: sum dlw [aweight=wpfinwgt], d

label variable age "Age"
label variable age2 "Age_sq"
label variable disab "Disability"
label variable ddisab "Ch. Disability"
label variable dmarr "Ch. Married"
label variable married "Married"
cap label variable white "White"
label variable unemp_rate "Unemp (\%)"
label variable dunemp_rate "Ch. Unemp (\%)"
label variable exper "Exper"
label variable exper_sq "Exper_sq"
label variable h_metro "Metro"
label variable dh_metro "Ch. Metro"
label variable dregd1 "Change Region 1"
label variable dregd2 "Change Region 2"
label variable dregd3 "Change Region 3"
cap label variable dummy_quarter1 "Dummy Quarter 1"
cap label variable dummy_quarter2 "Dummy Quarter 2"
cap label variable dummy_quarter3 "Dummy Quarter 3"
cap label variable dummy_quarter4 "Dummy Quarter 4"




cap log close
log using wage_growth_trivprobit, replace

foreach y in 1 2 3 {
*foreach y in 2 {

display "***************************"
display "********Period `y'******"
display "********Sex 1******"
display "********Grade 1******"
display "***************************"
reg dlw age age2 married dmarr white unemp_rate dunemp_rate exper exper_sq dh_metro h_metro disab ddisab prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr dpubl dcons dmanuf dserv dfin dagr d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9 yrd* dummy_quarter2 dummy_quarter3 dummy_quarter4 dregd1 dregd2 dregd3 regd1 regd2 regd3 C1 C2 C3 C4 if grades==1 & period==`y' & sex==1  [pweight=wpfinwgt]
testparm yrd*
testparm regd*
testparm dregd*
testparm dummy_quarter*
testparm prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr
testparm d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9
testparm dpubl dcons dmanuf dserv dfin dagr
estimates store dlw_`y'_sex1_low, title(Males: Period `y', Low)
predict xb0_`y' if e(sample)
replace xb0_`y'=xb0_`y'-_b[C1]*C1-_b[C2]*C2-_b[C3]*C3-_b[C4]*C4 if grades==1 & period==`y' & sex==1
replace dxb=xb0_`y' if grades==1 & period==`y'  & sex==1
cap drop xb0_`y'

display "***************************"
display "********Period `y'******"
display "********Sex 1******"
display "********Grade 2******"
display "***************************"

reg dlw age age2 married dmarr white unemp_rate dunemp_rate exper exper_sq  dh_metro h_metro  disab ddisab prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr dpubl dcons dmanuf dserv dfin dagr d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9 yrd* dummy_quarter2 dummy_quarter3 dummy_quarter4 dregd1 dregd2 dregd3 regd1 regd2 regd3   C1 C2 C3 C4 if grades==2 & period==`y' & sex==1 [pweight=wpfinwgt]
*reg dlw age age2 married dmarr white unemp_rate dunemp_rate exper exper_sq  dh_metro h_metro  publ cons manuf serv fin agr  dpubl dcons dmanuf dserv dfin dagr d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9 yrd* dummy_quarter2 dummy_quarter3 dummy_quarter4 dregd1 dregd2 dregd3 regd1 regd2 regd3   C1 C2 C3 C4 if grades==2 & period==`y' & sex==1 [pweight=wpfinwgt]
testparm yrd*
testparm regd*
testparm dregd*
testparm dummy_quarter*
testparm prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr
testparm d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9
testparm dpubl dcons dmanuf dserv dfin dagr
estimates store dlw_`y'_sex1_med, title(Males: Period `y', High)
predict xb1_`y' if e(sample)
replace xb1_`y'=xb1_`y'-_b[C1]*C1-_b[C2]*C2-_b[C3]*C3-_b[C4]*C4 if grades==2 & period==`y' & sex==1
replace dxb=xb1_`y' if grades==2 & period==`y'  & sex==1
cap drop xb1_`y'


display "***************************"
display "********Period `y'******"
display "********Sex 1******"
display "********Grade 3******"
display "***************************"
reg dlw age age2 married dmarr white unemp_rate dunemp_rate exper exper_sq  dh_metro h_metro  disab ddisab prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr dpubl dcons dmanuf dserv dfin dagr d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9 yrd* dummy_quarter2 dummy_quarter3 dummy_quarter4 dregd1 dregd2 dregd3 regd1 regd2 regd3   C1 C2 C3 C4 if grades==3 & period==`y' & sex==1 [pweight=wpfinwgt]
testparm yrd*
testparm regd*
testparm dregd*
testparm dummy_quarter*
testparm prev_publ prev_cons prev_manuf prev_serv prev_fin prev_agr
testparm d_new_disag_occ1 d_new_disag_occ2 d_new_disag_occ3 d_new_disag_occ4 d_new_disag_occ5 d_new_disag_occ6 d_new_disag_occ7 d_new_disag_occ8 d_new_disag_occ9
testparm dpubl dcons dmanuf dserv dfin dagr
estimates store dlw_`y'_sex1_hig, title(Males: Period `y', High)
predict xb2_`y' if e(sample)
replace xb2_`y'=xb2_`y'-_b[C1]*C1-_b[C2]*C2-_b[C3]*C3-_b[C4]*C4 if grades==3 & period==`y' & sex==1
replace dxb=xb2_`y' if grades==3 & period==`y'  & sex==1
cap drop xb2_`y'
}



**Export tables to Latex**
foreach var in low med hig {

*esttab dlw_1_sex1_`var' dlw_2_sex1_`var' dlw_3_sex1_`var' using dlw_sex1_`var'.tex, cells(b(star fmt(3)) se[(fmt(3))]) wide onecell parentheses///
esttab dlw_1_sex1_`var' dlw_2_sex1_`var' dlw_3_sex1_`var' using dlw_sex1_`var'.tex, b(3) se wide onecell parentheses ///
legend label varlabels(_cons Constant)   ///             
stats(r2 N, fmt(3 0 1) label(R-sqr Obs)) replace      

}




gen g    =dlw-dxb	/*unexplained growth*/
gen g2   =g^2	/*unexplained growth squared*/

bysort period: sum g [aweight=wpfinwgt], d


cap log close


cap drop dxb


sort id year quarter

compress
keep  id year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
ren id newid 
save temp_u0_all_g, replace

u temp_u0_all_g,clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter 
gen index=1
save temp1_all_g, replace

u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter
gen index=2
save temp2_all_g, replace


u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter
qui by newid:gen gg1=(g)*(g[_n-1]) if time[_n]==time[_n-1]+1
drop g
keep if gg1!=.
gen index=3
save temp3_all_g, replace


u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter
qui by newid:gen gg2=(g)*(g[_n-2]) if time[_n]==time[_n-2]+2
drop g
keep if gg2!=.
gen index=4
save temp4_all_g, replace

u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter 
qui by newid:gen gg3=(g)*(g[_n-3]) if time[_n]==time[_n-3]+3
drop g
keep if gg3!=.
gen index=5
save temp5_all_g, replace

u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter
qui by newid:gen gg4=(g)*(g[_n-4]) if time[_n]==time[_n-4]+4
drop g
keep if gg4!=.
gen index=6
save temp6_all_g, replace


u temp_u0_all_g, clear
keep  newid year quarter g M grad age g2 wpfin sex  panel_year time wpfinwgt partial_pi_pi1 partial_mu_pi partial_mu_pi1 rho_pimu rho_pipi1 rho_pi1mu a1 a2 a3 pdf_a1 pdf_a2 pdf_a3 A12 A13 A21 A23 A31 A32 A123 A132 A213 A231 A312 A321 PHIA12A13 PHIA21A23 PHIA31A32 PHI2A12A13 pdf_a1_a2 pdf_a1_a3 pdf_a2_a3 F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32 prob_M1 prob_M0 M_w M_b
sort newid year quarter
qui by newid:gen gg5=(g)*(g[_n-5]) if time[_n]==time[_n-5]+5
drop g
keep if gg5!=.
gen index=7
save temp7_all_g, replace



use temp_u0_all_g, clear
tab year if year<=2012 [aweight=wpfinwgt], sum(g)
bysort sex: tab year if year<=2012 [aweight=wpfinwgt], sum(g)
bysort sex M: tab year if year<=2012 [aweight=wpfinwgt], sum(g)

cap drop period
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013


tab period, sum(g)
bysort sex: tab period, sum(g)
bysort sex M: tab period, sum(g)


******************************************************************************************************************************
*************************** ESTIMATION OF WAGE VARIANCES**********************************************************************
******************************************************************************************************************************
u temp1_all_g,clear
append using temp2_all_g
append using temp3_all_g
append using temp4_all_g
append using temp5_all_g
append using temp6_all_g
append using temp7_all_g

sort newid index year 

gen     y=g   if index==1
replace y=g2  if index==2
replace y=gg1 if index==3
replace y=gg2 if index==4
replace y=gg3 if index==5
replace y=gg4 if index==6
replace y=gg5 if index==7

tab index, gen(index_d)

sort newid index year quarter
drop g g2
keep if y!=.
sort newid year quarter index_d1 index_d2 index_d3 index_d4 index_d5 index_d6 index_d7
drop gg2 gg3 gg4 gg5 gg1
drop if pdf_a1==.
drop if pdf_a2==.

order newid y index_d1 index_d2 index_d3 index_d4 index_d5 index_d6 index_d7 M wpfinwgt  rho_pimu rho_pipi1 rho_pi1mu F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32  M_w M_b
foreach x in 1 2 3 {
preserve
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013
keep if sex==1 & grade==1 & period==`x'
count if M!=.
destring newid, replace
egen newid2=group(newid)
cap drop newid
rename newid2 newid
destring newid, replace
outsheet newid y index_d1 index_d2 index_d3 index_d4 index_d5 index_d6 index_d7 M wpfinwgt  rho_pimu rho_pipi1 rho_pi1mu F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32  M_w M_b using "period`x'_grade1.txt", replace nonames 
sleep 2000
restore
}


foreach x in 1 2 3 {
preserve
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013
keep if sex==1 & grade==2 & period==`x'
count if M!=.
destring newid, replace
egen newid2=group(newid)
cap drop newid
rename newid2 newid
destring newid, replace
outsheet newid y index_d1 index_d2 index_d3 index_d4 index_d5 index_d6 index_d7 M wpfinwgt  rho_pimu rho_pipi1 rho_pi1mu F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32  M_w M_b using "period`x'_grade2.txt", replace nonames 
sleep 2000
restore
}


foreach x in 1 2 3 {
preserve
gen period=.
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013
keep if sex==1 & grade==3 & period==`x'
count if M!=.
destring newid, replace
egen newid2=group(newid)
cap drop newid
rename newid2 newid
destring newid, replace
outsheet newid y index_d1 index_d2 index_d3 index_d4 index_d5 index_d6 index_d7 M wpfinwgt  rho_pimu rho_pipi1 rho_pi1mu F1 F2 F12 F13 F21 F23 F31 F32 PHI011 PHI012 PHI111 E_12_13 E_21_23 G_12_13 G_21_23 G_31_32 H1 H2 H3 H12 H13 H21 H23 H31 H32  M_w M_b using "period`x'_grade3.txt", replace nonames 
sleep 2000
restore
}
