

set more off

cd "D:\Uni\Ariel\SIPP 7.7.2023"

cap log close




*************************************************************************
**			
**				CREATE REVISED PANELS WITH RELEVANT POPULATION
**
*************************************************************************



use 84_panel, clear

*West-Virginia (57) becomes Missisipi. NM, SD (58) become AL,ID,MO,WY (63)
replace state = 28 if state==57
replace state = 62 if state==19
replace state = 63 if state==58
replace state = 61 if state==50
replace state = 63 if state==30
replace state = 61 if state==23

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


*************************************************************
***TOP CODED INCOME (top coded at 100,000/12) for earnings***
*************************************************************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}


label var earn1_tc "Earnings topcoded Earnings 1"
label var rate1_tc "Wages topcoded Hourly rate 1"
label var earn2_tc "Earnings topcoded Earnings 2"
label var rate2_tc "Wages topcoded Hourly rate 2"

**Impute Top Coded Earnings**

forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) /* probability that weekly earnings is above the topcode;
                    analagous to 1-F(y2) above */
* b. calculate alternative values for y1
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
**Draw from the distribution above 80% which is Pareto distributed**
**Use only the values which are bove the top-coded**
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) /* probability that weekly earnings is above the topcode;
                    analagous to 1-F(y2) above */
* b. calculate alternative values for y1
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}




******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 


save 84_panel_revised, replace


use 85_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part



***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}


******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 



save 85_panel_revised, replace


use 86_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}


******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 


save 86_panel_revised, replace



use 87_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 


save 87_panel_revised, replace


use 88_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}




save 88_panel_revised, replace


use 89_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}



save 89_panel_revised, replace


use 90_panel, clear

**Identify if there is child in household which is male (below 18 yfears old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 

save 90_panel_revised, replace



use 91_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

cap rename fnlwght_ fnlwgt_
cap rename h_add h_addid
destring h_addid, replace

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}


******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 
save 91_panel_revised, replace


use 92_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

cap rename fnlwgt fnlwgt_
tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 

save 92_panel_revised, replace


use 93_panel, clear

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

cap rename fnlwgt fnlwgt_
cap tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************
rename sc1238 reason_part


***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=8333 if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=8333
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

******************************************
********TOP CODED WEALTH AND DEBT*********
******************************************
**Identify top coded above 400,000 dollars (1988 dollars)**
**Replace year to merge with CPI
gen year=h_year
replace year=year+1900 if year<100
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth = hhtnw/(cpi/100)
/*
gen real_wealth=hhtwlth/(cpi/100)
gen real_debt=hhusdbt/(cpi/100)
gen real_net_worth=real_wealth-real_debt
gen networth_tc=real_net_worth>=400000 if real_net_worth!=.
**Impute Top Coded Net Worth**
gen tc=networth_tc
**Cutoff used for net worth**
local T=400000
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile real_net_worth if tc~=. & real_net_worth!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace real_net_worth=check if tc==1
cap drop check tc
*/
drop month year cpi 

save 93_panel_revised, replace

use 96_panel, clear

replace state = 63 if state==2
replace state = 63 if state==16
replace state = 63 if state==30
replace state = 62 if state==19

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

**DROP PP_MIS DIFFERENT FROM 1 (2001 onwards we drop at Merging Panels1***
drop if pp_mis !=1
drop pp_mis

cap rename higrade grade
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace
**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************



***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=12500  if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=30 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=12500
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=30
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}


gen year=h_year
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth=hhtnw/(cpi/100)
drop month year cpi 

save 96_panel_revised, replace


use 2001_panel, clear

replace state = 63 if state==2
replace state = 63 if state==16
replace state = 63 if state==30
replace state = 62 if state==19


**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

replace h_povd = h_povd*12

drop if pp_mis !=1
drop pp_mis

cap rename higrade grade
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace
**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************

***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=12500  if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=29 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=12500
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=29
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

cap drop _merge
gen year=h_year
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth=hhtnw/(cpi/100)
drop month year cpi 

save 2001_panel_revised, replace


use 2004_panel, clear

cap rename state_ state
replace state = 63 if state==2
replace state = 63 if state==16
replace state = 63 if state==30
replace state = 63 if state==56
replace state = 62 if state==19
replace state = 62 if state==38
replace state = 62 if state==46
replace state = 62 if state==19
replace state = 61 if state==23
replace state = 61 if state==50

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

replace h_povd = h_povd*12

drop if pp_mis !=1
drop pp_mis

cap rename higrade grade
cap rename ws1_amt ws1_am
cap rename ws2_amt ws2_am
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap rename h_metro_  h_metro
cap tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace
**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************

***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=16666.5   if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=28.5 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=16666.5
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=28.5
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

gen year=h_year
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth=hhtnw/(cpi/100)
drop month year cpi 

save 2004_panel_revised, replace



use 2008_panel, clear

cap rename state_ state
replace state = 63 if state==2
replace state = 63 if state==16
replace state = 63 if state==30
replace state = 63 if state==56
replace state = 62 if state==19
replace state = 62 if state==38
replace state = 62 if state==46
replace state = 62 if state==19
replace state = 61 if state==23
replace state = 61 if state==50

**Identify if there is child in household which is male (below 18 years old)***
gen child_aux=.
bysort su_id h_add h_year h_month rrp: replace child_aux=1 if age<=18 & sex==1
bysort su_id h_add h_year h_month: egen child_male=mean(child_aux)
replace child_male=1 if child_male!=.
replace child_male=0 if child_male==.
replace caidcov = caidcov==1

replace h_povd = h_povd*12

drop if pp_mis !=1
drop pp_mis


cap rename higrade grade
cap rename ws1_amt ws1_am
cap rename ws2_amt ws2_am
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap rename h_metro_  h_metro
cap tostring pp_pnum, replace
tostring pp_entry, replace
cap rename h_add h_addid
destring h_addid, replace
**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=22 & age<=61
******************************************************************************

***********************
***TOP CODED INCOME ***
***********************
forval x=1(1)2 {

gen  earn`x'_tc = ws`x'_am>=16666.5   if ws`x'_am~=. 
gen  rate`x'_tc = ws`x'_ra>=35.0 if ws`x'_ra~=. 
}

**Impute Top Coded Earnings**

forval x=1(1)2 {

gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=16666.5
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_am if tc~=. & sex==1 & ws`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
cap drop check tc
}



forval x=1(1)2 {

***Top coded Earnings using Pareto distribution**
gen tc=0 if esr<=4 
replace tc=1 if rate`x'_tc==1
**Cutoff used for earnings**
local T=35.0
qui sum tc [aw=fnlwgt_]
local F2=r(mean) 
_pctile ws`x'_ra if tc~=. & sex==1 & ws`x'_ra!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_ra=check if tc==1
cap drop check tc
}

gen year=h_year
gen month=h_month
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1996:6 (also average of the year)*/
gen real_net_worth=hhtnw/(cpi/100)
drop month year cpi 

save 2008_panel_revised, replace


******************************************************************************
**	1984 - 1990
******************************************************************************

use 84_panel_revised, clear
append using 85_panel_revised
append using 86_panel_revised
append using 87_panel_revised
append using 88_panel_revised
append using 89_panel_revised
append using 90_panel_revised

**NEW CRUCIAL, more inputs in panel 96 onwards on wsimp and wscalc. On top of the input for imputation, there is also option statistical or logical imputation. Make
**it consistent with the previous panels**

foreach var in ws1calc ws1imp05 ws2calc ws2imp05 {
replace `var'=1 if `var'>1 & `var'!=.
}




rename fnlwgt wpfinwgt
drop fnlwgt*
rename h_year year
rename h_month month
rename panel panel_year

*replace esr_=esr if esr_==.
*drop esr

**EDUCATION**


gen new_educ=.
**With high school or less**
replace new_educ=1 if grade<=12 & panel_year<=93 
**With some collegue**
replace new_educ=2 if grade>12 & grade<23 & panel_year<=93
**Collegue or more**
replace new_educ=3 if grade>=23 & panel_year<=93


**With high school or less**
replace new_educ=1 if grade<=39 & panel_year>=96
**With some collegue**
replace new_educ=2 if grade>39 & grade<42 & panel_year>=96
**Collegue or more**
replace new_educ=3 if grade>=42 & panel_year>=96



cap drop id
egen id = group(su_id pp_entry pp_pnum panel_year)
egen grades=max(new_educ),by(id)	
tostring id, replace


*****CREATE CALENDAR MONTH/YEAR*****************************
gen     quarter=1 if month>=1 & month<=3
replace quarter=2 if month>=4 & month<=6
replace quarter=3 if month>=7 & month<=9
replace quarter=4 if month>=10 & month<=12

*****CREATE SOME DEMOG*****
gen     region=1 if state==9|state==61|state==33|state==34|state==36|state==42|state==44|state==25
replace region=2 if state==17|state==18|state==62|state==20|state==26|state==27|state==29|state==31|state==39|state==55
replace region=3 if state==1|state==13|state==22|state==28|state==45|state==5|state==10|state==12|state==21|state==24|state==37|state==40|state==47|state==51|state==11|state==54
replace region=4 if region==. & state>0 & state<64
gen white  =race==1
gen married=ms==1|ms==2
replace h_tenur=2 if h_tenur==3
replace f_oklt18=4 if f_oklt18>4 & f_oklt18!=.

*****DROP THE SELF-EMPLOYED*********************************
egen self=sum(sc1714>1),by(id)
drop if self>0
drop self
************************************************************

drop if state==0
drop if wpfinwgt==0

********************
**Clean imputation**
********************

**ws1imp05: imputation flag for regular hourly rate
**ws1calc: imputation flac for monthly hourly earnings

cap drop time
egen time=group(year month)

sort su_id pp_entry pp_pnum panel_year pp_wave year month
**When amount of hours do not change, and firm does not change, imputation should be constant within wave (take median). This adjustment assumes weeks worked per month did not change within waves
forval x=1(1)2{
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_imputed_income=sd(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen median_imputed_income=median(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_job=sd(jobid`x')
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_hours=sd(ws`x'_hr)
replace ws`x'_am=median_imputed_income if change_job==0 & change_hours==0 & ws`x'calc==1 & change_imputed_income>0 & change_imputed_income!=.
drop change_imputed_income median_imputed_income change_job change_hours
}

**Impute hourly rate (using mean) when was paid before by the hour, is paid by the hour afterwards, hourly rate did not change by more than 5%**
forval x=1(1)2{
gen adj_ws`x'_ra=.
sort su_id pp_entry pp_pnum panel_year jobid`x' year month

by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


**After imputing replace now the indicator ws`x'_2026 that is paid by the hour too**
replace ws`x'_2026=1 if adj_ws`x'_ra>0 & adj_ws`x'_ra!=.
drop adj_ws`x'_ra
}

**Drop if wage growth (hourly and earnings) is above 30% in absolute value because of imputation and conditional on jobid to not change, and hours did not change (for earnings). Assumes weeks employed did not change**
gen outl_imputation=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' year month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ws`x'_hr[_n]==ws`x'_hr[_n-1]  & ((ws`x'imp05[_n]==1 & ws`x'imp05[_n-1]!=1) | (ws`x'imp05[_n]!=1 & ws`x'imp05[_n-1]==1)) & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. 
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_hourlywage_growth`x'=abs(ws`x'_ra[_n]-ws`x'_ra[_n-1])/(ws`x'_ra[_n-1]) if ws`x'_ra!=0 & ws`x'_ra!=. & ws`x'_ra[_n-1]!=0 & ws`x'_ra[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_hourlywage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ((ws`x'calc[_n]==1 & ws`x'calc[_n-1]!=1) | (ws`x'calc[_n]!=1 & ws`x'calc[_n-1]==1))  & abs_hourlywage_growth`x'!=0 & abs_hourlywage_growth`x'!=.
}



**Drop the wave if within the wave there is an outlier**
bysort su_id pp_entry pp_pnum panel_year pp_wave: egen mean_outl_imputation=mean(outl_imputation)
**Drop the wave from the id if there is an outlier at imputation!**
drop if mean_outl_imputation!=.
drop outl_imputation abs_hourlywage_growth* abs_wage_growth*
drop time


*clean hours worked
replace ws1_hr=0 if ws1_hr<5
replace ws2_hr=0 if ws2_hr<5
*NEW
*replace ws1_hr=0 if ws1_hr<20
*replace ws2_hr=0 if ws2_hr<20
*replace ws1_hr=0 if ws1_hr==99
*replace ws2_hr=0 if ws2_hr==99

replace ws1_hr= 0 if tsjdate1==31
replace ws2_hr= 0 if tsjdate2==31

* Calculated earnings if not reported, but hourly rate is not imputed  (ws1imp05==1)
replace ws1_am = ws1_hr*ws1_wk*ws1_ra if ws1_am<=0 & ws1_hr>0 & ws1_ra>0 & ws1_wk>0 & jobid1> 0 & ws1imp05==0
replace ws2_am = ws2_hr*ws2_wk*ws2_ra if ws2_am<=0 & ws2_hr>0 & ws2_ra>0 & ws2_wk>0 & jobid2> 0 & ws2imp05==0


*clean earnings and jobids
replace ws1_am=0 if ws1_am<0
replace ws2_am=0 if ws2_am<0
replace ws1_am=0 if ws1_hr<=0
replace ws2_am=0 if ws2_hr<=0
replace ws1_ra=0 if ws1_ra<=0
replace ws2_ra=0 if ws2_ra<=0
replace jobid1 = 0 if ws1_am <= 0
replace jobid2 = 0 if ws2_am <= 0
replace jobid1 = 0 if ws1_hr <= 0
replace jobid2 = 0 if ws2_hr <= 0
replace jobid1=. if jobid1==0
replace jobid2=. if jobid2==0
replace ws1_hr=. if jobid1==.
replace ws2_hr=. if jobid2==.
replace  ws1_hr=. if  ws1_hr==0 
replace  ws2_hr=. if  ws2_hr==0
replace  ws1_am=. if  ws1_am==0
replace  ws2_am=. if  ws2_am==0
replace  ws1_ra=. if  ws1_ra==0
replace  ws2_ra=. if  ws2_ra==0



*clean esr
*Do not do next step. ESR=8 important to identify out of labor force
*replace esr=8 if jobid1 ==. & jobid2 ==. & esr<=4 
replace esr=5 if esr<=4 & jobid1 ==. & jobid2 ==.

*decide whether to use reported weeks, or smooth 4.3 weeks
replace tejdate1 = 31 if tejdate1>29
replace tejdate2 = 31 if tejdate2>29
gen ws1_wks = -1
replace ws1_wks = 4.3 if jobid1>0
*replace ws1_wks = ws1_wk if jobid1>0 & ws1_2026==1 & ws1imp05==0 
replace ws1_wks = (tejdate1-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1>0
replace ws1_wks = (tejdate1)/7 if jobid1>0 & tejdate1>0 & tsjdate1==0
replace ws1_wks = (31-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1<=0
gen ws2_wks = -1
replace ws2_wks = 4.3 if jobid2>0
*replace ws2_wks = ws2_wk if jobid2>0 & ws2_2026==1 & ws2imp05==0
replace ws2_wks = (tejdate2-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2>0
replace ws2_wks = (tejdate2)/7 if jobid2>0 & tejdate2>0 & tsjdate2==0
replace ws2_wks = (31-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2<=0

gen earn1_h_s = ws1_am/(ws1_wks*ws1_hr)
gen earn2_h_s = ws2_am/(ws2_wks*ws2_hr)
gen earn1_h_ns = ws1_am/(ws1_wk*ws1_hr)
gen earn2_h_ns = ws2_am/(ws2_wk*ws2_hr)


cap drop time
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_s = log(earn1_h_s)-log(earn1_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_s = log(earn2_h_s)-log(earn2_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ns = log(earn1_h_ns)-log(earn1_h_ns[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ns = log(earn2_h_ns)-log(earn2_h_ns[_n-1]) if time==time[_n-1]+1

replace ws1_wks = ws1_wk if abs(g1_ns)<abs(g1_s) 
replace ws2_wks = ws2_wk if abs(g2_ns)<abs(g2_s) 

drop g1_ns g1_s g2_ns g2_s earn1_h_s earn2_h_s earn1_h_ns earn2_h_ns


*****calculate monthly hourly earnings based on reported earnings*******

*gen id_aux = group(su_id pp_entry pp_pnum panel_year)
cap drop time
egen time=group( year month)
sort su_id pp_entry pp_pnum panel_year time
*weeks are constant if earnings and hours do not change
gen z=0
forval x=1(1)3{
if (`x'<=3) {
sort su_id pp_entry pp_pnum panel_year year month
bysort su_id pp_entry pp_pnum panel_year: replace ws1_wks=ws1_wks[_n+1] if ws1_am==ws1_am[_n+1] & ws1_hr==ws1_hr[_n+1]  & jobid1==jobid1[_n+1] & jobid1!=. & time==time[_n+1]-1
bysort su_id pp_entry pp_pnum panel_year: replace ws2_wks=ws2_wks[_n+1] if ws2_am==ws2_am[_n+1] & ws2_hr==ws2_hr[_n+1]  & jobid2==jobid2[_n+1] & jobid2!=. & time==time[_n+1]-1
replace z=`x'
}
}
cap drop z 


gen ws1_hourly_am = ws1_am/(ws1_hr*ws1_wks)
gen ws2_hourly_am = ws2_am/(ws2_hr*ws2_wks)


*****calculate monthly hourly earnings based on hourly rate*******
gen ws1_am_ra = .
gen ws2_am_ra = .
replace ws1_am_ra = ws1_ra if jobid1> 0 & ws1imp05==0
replace ws2_am_ra = ws2_ra if jobid2> 0 & ws2imp05==0

*impute series from each other to assure that we have the full amount of observations
replace ws1_hourly_am=ws1_am_ra if ws1_hourly_am==. & ws1_am_ra!=.
replace ws2_hourly_am=ws2_am_ra if ws2_hourly_am==. & ws2_am_ra!=.
replace ws1_am_ra=ws1_hourly_am if ws1_am_ra==. & ws1_hourly_am!=.
replace ws2_am_ra=ws2_hourly_am if ws2_am_ra==. & ws2_hourly_am!=.

*****we keep the series which gives us the minimum volatility in growth rates******
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_am = log(ws1_hourly_am)-log(ws1_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_am = log(ws2_hourly_am)-log(ws2_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ra = log(ws1_am_ra)-log(ws1_am_ra[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ra = log(ws2_am_ra)-log(ws2_am_ra[_n-1]) if time==time[_n-1]+1

*compute standard deviation
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_am1 = sd(g1_am)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_am2 = sd(g2_am)
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_ra1 = sd(g1_ra)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_ra2 = sd(g2_ra)

gen ws1_hr_best = ws1_hourly_am if std_am1<=std_ra1
gen ws2_hr_best = ws2_hourly_am if std_am2<=std_ra2
replace ws1_hr_best=ws1_am_ra if std_am1>std_ra1
replace ws2_hr_best=ws2_am_ra if std_am2>std_ra2

replace ws1_am = ws1_hr_best*ws1_wks*ws1_hr
replace ws2_am = ws2_hr_best*ws2_wks*ws2_hr

***CLEAN FOR BONUSES!!***
**Drop if wage growth (earnings) is above 30% in absolute value conditional on jobid to not change at L1,L0,F1, hours did not change at L1,L0,F1, and weeks to not change at L1,L0,F1, and value wage at period  [_n-1]==[_n+1]**
**These are commonly bonuses**
sort year month
cap drop time
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year pp_wave year month
gen bonus1_clean=.
gen bonus2_clean=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' year month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace bonus`x'_clean=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & jobid`x'[_n-1]==jobid`x'[_n+1] & ws`x'_hr[_n]==ws`x'_hr[_n-1] & ws`x'_hr[_n-1]==ws`x'_hr[_n+1] & ws`x'_wks[_n]==ws`x'_wks[_n-1] & ws`x'_wks[_n-1]==ws`x'_wks[_n+1]  & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. & ws`x'_am[_n-1]==ws`x'_am[_n+1]
}
sort su_id pp_entry pp_pnum panel_year jobid1 year month
replace ws1_am=ws1_am[_n-1] if bonus1_clean==1  & time[_n]==time[_n-1]+1
sort su_id pp_entry pp_pnum panel_year jobid2 year month
replace ws2_am=ws2_am[_n-1] if bonus2_clean==1  & time[_n]==time[_n-1]+1
 **Drop the wave if within the wave there is an outlier**
drop abs_wage_growth1 abs_wage_growth2 bonus2_clean bonus1_clean
drop time



*****CPI****************

**Replace year to merge with CPI
replace year=year+1900 if year<100

sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1988:6 (also average of the year)*/

compress
save data_sipp_part_all_noimp1,replace




******************************************************************************
**	1991 - 1996
******************************************************************************
set more off
use 91_panel_revised, clear
append using 92_panel_revised
append using 93_panel_revised
append using 96_panel_revised
rename panel panel_year

**NEW CRUCIAL, more inputs in panel 96 onwards on wsimp and wscalc. On top of the input for imputation, there is also option statistical or logical imputation. Make
**it consistent with the previous panels**
**For wscalc value 2 is not inputed input, but calculated
foreach var in ws1calc ws1imp05 ws2calc ws2imp05 {
replace `var'=1 if `var'>1 & `var'!=.
}



**PART TIME HOMOGENOUS ACROSS PANELS**

gen aux=-1
replace aux=1 if reason_part==1 & panel_year>=96
replace aux=2 if reason_part==2 & panel_year>=96
replace aux=3 if reason_part==5 & panel_year>=96
replace aux=4 if reason_part==7 & panel_year>=96
replace aux=5 if reason_part==8 & panel_year>=96
**There are other reasons, but to make it analogous to the previous panels I do not consider them
replace aux=6 if (reason_part==12) & panel_year>=96
replace reason_part=aux if panel_year>=96



********************
**Clean imputation**
********************

**ws1imp05: imputation flag for regular hourly rate
**ws1calc: imputation flac for monthly hourly earnings

cap drop time
egen time=group(h_year h_month)

sort su_id pp_entry pp_pnum panel_year pp_wave h_year h_month
**When amount of hours do not change, and firm does not change, imputation should be constant within wave (take median)
forval x=1(1)2{
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_imputed_income=sd(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen median_imputed_income=median(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_job=sd(jobid`x')
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_hours=sd(ws`x'_hr)
replace ws`x'_am=median_imputed_income if change_job==0 & change_hours==0 & ws`x'calc==1 & change_imputed_income>0 & change_imputed_income!=.
drop change_imputed_income median_imputed_income change_job change_hours
}

**Impute hourly rate (using mean) when was paid before by the hour, is paid by the hour afterwards, hourly rate did not change by more than 5%**
forval x=1(1)2{
gen adj_ws`x'_ra=.
sort su_id pp_entry pp_pnum panel_year jobid`x' h_year h_month
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


**After imputing replace now the indicator ws`x'_2026 that is paid by the hour too**
replace ws`x'_2026=1 if adj_ws`x'_ra>0 & adj_ws`x'_ra!=.
drop adj_ws`x'_ra
}


**Drop if wage growth (hourly and earnings) is above 30% in absolute value because of imputation and conditional on jobid to not change, and hours did not change (for earnings)**

gen outl_imputation=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' h_year h_month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ws`x'_hr[_n]==ws`x'_hr[_n-1]  & ((ws`x'imp05[_n]==1 & ws`x'imp05[_n-1]!=1) | (ws`x'imp05[_n]!=1 & ws`x'imp05[_n-1]==1)) & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. 
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_hourlywage_growth`x'=abs(ws`x'_ra[_n]-ws`x'_ra[_n-1])/(ws`x'_ra[_n-1]) if ws`x'_ra!=0 & ws`x'_ra!=. & ws`x'_ra[_n-1]!=0 & ws`x'_ra[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_hourlywage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ((ws`x'calc[_n]==1 & ws`x'calc[_n-1]!=1) | (ws`x'calc[_n]!=1 & ws`x'calc[_n-1]==1))  & abs_hourlywage_growth`x'!=0 & abs_hourlywage_growth`x'!=.
}

**Drop the wave if within the wave there is an outlier**
bysort su_id pp_entry pp_pnum panel_year pp_wave: egen mean_outl_imputation=mean(outl_imputation)
**Drop the wave from the id if there is an outlier at imputation!**
drop if mean_outl_imputation!=.
drop outl_imputation abs_hourlywage_growth* abs_wage_growth*
drop time



*clean hours worked
replace ws1_hr=0 if ws1_hr<5
replace ws2_hr=0 if ws2_hr<5
*NEW
*replace ws1_hr=0 if ws1_hr<20
*replace ws2_hr=0 if ws2_hr<20
*replace ws1_hr=0 if ws1_hr==99
*replace ws2_hr=0 if ws2_hr==99
replace ws1_hr = 0 if tsjdate1==31
replace ws2_hr = 0 if tsjdate2==31

* Calculated earnings if not reported
replace ws1_am = ws1_hr*ws1_wk*ws1_ra if ws1_am<=0 & ws1_hr>0 & ws1_ra>0 & ws1_wk>0 & jobid1> 0 & ws1imp05==0
replace ws2_am = ws2_hr*ws2_wk*ws2_ra if ws2_am<=0 & ws2_hr>0 & ws2_ra>0 & ws2_wk>0 & jobid2> 0 & ws2imp05==0

*replace earnings if non-imputed paid by the houer
replace ws1_am = ws1_hr*ws1_wk*ws1_ra if jobid1> 0 & ws1_2026==1 & ws1imp05==0
replace ws2_am = ws2_hr*ws2_wk*ws2_ra if jobid2> 0 & ws2_2026==1 & ws2imp05==0
replace ws1calc=0 if jobid1> 0 & ws1_2026==1 & ws1imp05==0
replace ws2calc=0 if jobid2> 0 & ws2_2026==1 & ws2imp05==0

*clean earnings and jobids
replace ws1_am=0 if ws1_am<0
replace ws2_am=0 if ws2_am<0
replace ws1_am=0 if ws1_hr<=0
replace ws2_am=0 if ws2_hr<=0
replace ws1_ra=0 if ws1_ra<=0
replace ws2_ra=0 if ws2_ra<=0
replace jobid1 = 0 if ws1_am <= 0
replace jobid2 = 0 if ws2_am <= 0
replace jobid1 = 0 if ws1_hr <= 0
replace jobid2 = 0 if ws2_hr <= 0
replace jobid1=. if jobid1==0
replace jobid2=. if jobid2==0
replace ws1_hr=. if jobid1==.
replace ws2_hr=. if jobid2==.
replace  ws1_hr=. if  ws1_hr==0 
replace  ws2_hr=. if  ws2_hr==0
replace  ws1_am=. if  ws1_am==0
replace  ws2_am=. if  ws2_am==0
replace  ws1_ra=. if  ws1_ra==0
replace  ws2_ra=. if  ws2_ra==0


*clean esr
*Do not do next step. ESR=8 important to identify out of labor force
*replace esr=8 if jobid1 ==. & jobid2 ==. & esr<=4 
replace esr=5 if esr<=4 & jobid1 ==. & jobid2 ==.



forval x=1(1)2 {
gen aux_tsjdate`x'=tsjdate`x'
tostring aux_tsjdate`x', replace
**Day starting**
gen aux2_tsjdate`x'=substr(aux_tsjdate`x', -2,.)
**Month starting**
gen aux3_tsjdate`x'=substr(aux_tsjdate`x', -4,2)
**Year starting**
gen aux4_tsjdate`x'=substr(aux_tsjdate`x', 1,4)

**Problems when translating the date**
gen aux5_tsjdate`x'=floor(tsjdate`x')
replace aux5_tsjdate`x'=aux5_tsjdate`x'-tsjdate`x'
**Makes sure that the date corresponds to tjsdate/tejdate
destring aux2_tsjdate`x', replace
replace aux2_tsjdate`x'=aux2_tsjdate`x'-aux5_tsjdate`x'

**Given that variable is reported by wave, if month started a job is above the month within the wave, put it as -1**
gen month_tsjdate`x'=aux3_tsjdate`x'
destring month_tsjdate`x', replace
gen year_tsjdate`x'=aux4_tsjdate`x'
destring year_tsjdate`x', replace

**Do the same for ending job
gen aux_tejdate`x'=tejdate`x'
tostring aux_tejdate`x', replace
**Day ending**
gen aux2_tejdate`x'=substr(aux_tejdate`x', -2,.)
**Month ending**
gen aux3_tejdate`x'=substr(aux_tejdate`x', -4,2)
**Year ending**
gen aux4_tejdate`x'=substr(aux_tejdate`x', 1,4)
**Problems when translating the date**
gen aux5_tejdate`x'=floor(tejdate`x')
replace aux5_tejdate`x'=aux5_tejdate`x'-tejdate`x'
**Makes sure that the date corresponds to tjsdate/tejdate
destring aux2_tejdate`x', replace
replace aux2_tejdate`x'=aux2_tejdate`x'-aux5_tejdate`x'

**Given that variable is reported by wave, if month end a job is above the month within the wave, put it as -1**
gen month_tejdate`x'=aux3_tejdate`x'
destring month_tejdate`x', replace
gen year_tejdate`x'=aux4_tejdate`x'
destring year_tejdate`x', replace

**Put as not in universe if the starting day of the job is above the current month of the year
replace aux2_tsjdate`x'=-1 if month_tsjdate`x'>h_month & year_tsjdate`x'==h_year & year_tsjdate`x'!=-1
replace aux2_tsjdate`x'=-1 if year_tsjdate`x'>h_year & year_tsjdate`x'!=-1
replace aux2_tejdate`x'=-1 if month_tejdate`x'<h_month & year_tejdate`x'==h_year & year_tejdate`x'!=-1
replace aux2_tejdate`x'=-1 if year_tejdate`x'<h_year & year_tejdate`x'!=-1

gen aux6_tsjdate`x'=.
gen aux6_tejdate`x'=.

**First month working**
replace aux6_tsjdate`x'=aux2_tsjdate`x' if year_tsjdate`x'==h_year & month_tsjdate`x'==h_month & jobid`x'!=.
**Last month working**
replace aux6_tejdate`x'=aux2_tejdate`x' if year_tejdate`x'==h_year & month_tejdate`x'==h_month & jobid`x'!=.

**For those months within the wave that person did not start a job nor end a job, consider to have started at beginning of the month, and end working within the month at the end of the month**
replace aux6_tsjdate`x'=0 if month_tsjdate`x'<=h_month<=month_tejdate`x' & year_tsjdate`x'<=h_year & year_tejdate`x'<=h_year & year_tsjdate`x'!=-1 & year_tejdate`x'!=-1 & aux6_tsjdate`x'==. & jobid`x'!=.
replace aux6_tejdate`x'=0 if month_tsjdate`x'<=h_month<=month_tejdate`x' & year_tsjdate`x'<=h_year & year_tejdate`x'<=h_year & year_tsjdate`x'!=-1 & year_tejdate`x'!=-1 & aux6_tejdate`x'==. & jobid`x'!=.

*Case where person does not answer beginning and end of job, but reports having a job
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==.
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==.

**Case where reports the year which beginning of started job but not the end. Impute starting day started job in the month to be beginning of the month**
replace aux6_tsjdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tsjdate`x'<h_year
replace aux6_tsjdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tsjdate`x'==h_year & month_tsjdate`x'<=h_month
**Also impute days end job**
replace aux6_tejdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tsjdate`x'<h_year
replace aux6_tejdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tsjdate`x'==h_year & month_tsjdate`x'<=h_month

**Case where reports end of period job but not the beginning. Impute starting day started job in the month**
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tejdate`x'>h_year
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tejdate`x'==h_year & month_tejdate`x'>=h_month
**Also impute days end job**
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tejdate`x'>h_year
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tejdate`x'==h_year & month_tejdate`x'>=h_month


**In case there is no information. Put -1**
replace aux6_tsjdate`x'=-1 if aux6_tsjdate`x'==.
replace aux6_tejdate`x'=-1 if aux6_tejdate`x'==.
}


foreach var in tsjdate1 tsjdate2 tejdate1 tejdate2 {
replace `var'=aux6_`var' if panel_year>=96
drop aux2_`var'
}
cap drop aux*


**EDUCATION**

gen new_educ=.
**With high school or less**
replace new_educ=1 if grade<=12 & panel_year<=93 
**With some collegue**
replace new_educ=2 if grade>12 & grade<23 & panel_year<=93
**Collegue or more**
replace new_educ=3 if grade>=23 & panel_year<=93


**With high school or less**
replace new_educ=1 if grade<=39 & panel_year>=96
**With some collegue**
replace new_educ=2 if grade>39 & grade<42 & panel_year>=96
**Collegue or more**
replace new_educ=3 if grade>=42 & panel_year>=96

*Error! First, define the new id, then define grades! There might be repeated id's
cap drop id
egen id = group(su_id pp_entry pp_pnum panel_year)
egen grades=max(new_educ),by(id)	
tostring id, replace

*****CREATE WEIGHTS*****************************
rename fnlwgt_ wpfinwgt
cap drop fnlwgt*

*****CREATE CALENDAR MONTH/YEAR*****************************
rename h_year year
rename h_month month
gen     quarter=1 if month>=1 & month<=3
replace quarter=2 if month>=4 & month<=6
replace quarter=3 if month>=7 & month<=9
replace quarter=4 if month>=10 & month<=12

*****CREATE SOME DEMOG*****
gen     region=1 if state==9|state==61|state==33|state==34|state==36|state==42|state==44|state==25
replace region=2 if state==17|state==18|state==62|state==20|state==26|state==27|state==29|state==31|state==39|state==55
replace region=3 if state==1|state==13|state==22|state==28|state==45|state==5|state==10|state==12|state==21|state==24|state==37|state==40|state==47|state==51|state==11|state==54
replace region=4 if region==. & state>0 & state<64
gen white  =race==1
gen married=ms==1|ms==2
replace h_tenur=2 if h_tenur==3
replace f_oklt18=4 if f_oklt18>4 & f_oklt18!=.

*****DROP THE SELF-EMPLOYED*********************************
egen self=sum(sc1714>1),by(id)
drop if self>0
drop self
************************************************************

drop if state==0
drop if wpfinwgt==0



*decide whether to use reported weeks, or smooth 4.3 weeks
replace tejdate1 = 31 if tejdate1>29
replace tejdate2 = 31 if tejdate2>29
gen ws1_wks = -1
replace ws1_wks = 4.3 if jobid1>0
*replace ws1_wks = ws1_wk if jobid1>0 & ws1_2026==1 & ws1imp05==0 
replace ws1_wks = (tejdate1-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1>0
replace ws1_wks = (tejdate1)/7 if jobid1>0 & tejdate1>0 & tsjdate1==0
replace ws1_wks = (31-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1<=0
gen ws2_wks = -1
replace ws2_wks = 4.3 if jobid2>0
*replace ws2_wks = ws2_wk if jobid2>0 & ws2_2026==1 & ws2imp05==0
replace ws2_wks = (tejdate2-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2>0
replace ws2_wks = (tejdate2)/7 if jobid2>0 & tejdate2>0 & tsjdate2==0
replace ws2_wks = (31-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2<=0

gen earn1_h_s = ws1_am/(ws1_wks*ws1_hr)
gen earn2_h_s = ws2_am/(ws2_wks*ws2_hr)
gen earn1_h_ns = ws1_am/(ws1_wk*ws1_hr)
gen earn2_h_ns = ws2_am/(ws2_wk*ws2_hr)


cap drop time
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_s = log(earn1_h_s)-log(earn1_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_s = log(earn2_h_s)-log(earn2_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ns = log(earn1_h_ns)-log(earn1_h_ns[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ns = log(earn2_h_ns)-log(earn2_h_ns[_n-1]) if time==time[_n-1]+1

replace ws1_wks = ws1_wk if abs(g1_ns)<abs(g1_s) 
replace ws2_wks = ws2_wk if abs(g2_ns)<abs(g2_s) 

drop g1_ns g1_s g2_ns g2_s earn1_h_s earn2_h_s earn1_h_ns earn2_h_ns


*gen id_aux = group(su_id pp_entry pp_pnum panel_year)
cap drop time
egen time=group( year month)
sort su_id pp_entry pp_pnum panel_year time
*weeks are constant if earnings and hours do not change
gen z=0
forval x=1(1)3{
if (`x'<=3) {
sort su_id pp_entry pp_pnum panel_year year month
bysort su_id pp_entry pp_pnum panel_year: replace ws1_wks=ws1_wks[_n+1] if ws1_am==ws1_am[_n+1] & ws1_hr==ws1_hr[_n+1]  & jobid1==jobid1[_n+1] & jobid1!=. & time==time[_n+1]-1
bysort su_id pp_entry pp_pnum panel_year: replace ws2_wks=ws2_wks[_n+1] if ws2_am==ws2_am[_n+1] & ws2_hr==ws2_hr[_n+1]  & jobid2==jobid2[_n+1] & jobid2!=. & time==time[_n+1]-1
replace z=`x'
}
}
cap drop z 

gen ws1_hourly_am = ws1_am/(ws1_hr*ws1_wks)
gen ws2_hourly_am = ws2_am/(ws2_hr*ws2_wks)


*****calculate monthly hourly earnings based on hourly rate*******
gen ws1_am_ra = .
gen ws2_am_ra = .
replace ws1_am_ra = ws1_ra if jobid1> 0 & ws1imp05==0
replace ws2_am_ra = ws2_ra if jobid2> 0 & ws2imp05==0

*impute series from each other to assure that we have the full amount of observations
replace ws1_hourly_am=ws1_am_ra if ws1_hourly_am==. & ws1_am_ra!=.
replace ws2_hourly_am=ws2_am_ra if ws2_hourly_am==. & ws2_am_ra!=.
replace ws1_am_ra=ws1_hourly_am if ws1_am_ra==. & ws1_hourly_am!=.
replace ws2_am_ra=ws2_hourly_am if ws2_am_ra==. & ws2_hourly_am!=.


cap drop time
egen time=group(year month)
*****we keep the series which gives us the minimum volatility in growth rates******
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_am = log(ws1_hourly_am)-log(ws1_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_am = log(ws2_hourly_am)-log(ws2_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ra = log(ws1_am_ra)-log(ws1_am_ra[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ra = log(ws2_am_ra)-log(ws2_am_ra[_n-1]) if time==time[_n-1]+1

*compute standard deviation
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_am1 = sd(g1_am)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_am2 = sd(g2_am)
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_ra1 = sd(g1_ra)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_ra2 = sd(g2_ra)


gen ws1_hr_best = ws1_hourly_am if std_am1<=std_ra1
gen ws2_hr_best = ws2_hourly_am if std_am2<=std_ra2
replace ws1_hr_best=ws1_am_ra if std_am1>std_ra1
replace ws2_hr_best=ws2_am_ra if std_am2>std_ra2

replace ws1_am = ws1_hr_best*ws1_wks*ws1_hr
replace ws2_am = ws2_hr_best*ws2_wks*ws2_hr




***CLEAN FOR BONUSES!!***
**Drop if wage growth (earnings) is above 30% in absolute value conditional on jobid to not change at L1,L0,F1, hours did not change at L1,L0,F1, and weeks to not change at L1,L0,F1, and value wage at period  [_n-1]==[_n+1]**
**These are commonly bonuses**
cap drop time
sort year month
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year pp_wave year month
gen bonus1_clean=.
gen bonus2_clean=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' year month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace bonus`x'_clean=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & jobid`x'[_n-1]==jobid`x'[_n+1] & ws`x'_hr[_n]==ws`x'_hr[_n-1] & ws`x'_hr[_n-1]==ws`x'_hr[_n+1] & ws`x'_wks[_n]==ws`x'_wks[_n-1] & ws`x'_wks[_n-1]==ws`x'_wks[_n+1]  & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. & ws`x'_am[_n-1]==ws`x'_am[_n+1]
}
sort su_id pp_entry pp_pnum panel_year jobid1 year month
replace ws1_am=ws1_am[_n-1] if bonus1_clean==1  & time[_n]==time[_n-1]+1
sort su_id pp_entry pp_pnum panel_year jobid2 year month
replace ws2_am=ws2_am[_n-1] if bonus2_clean==1  & time[_n]==time[_n-1]+1
 **Drop the wave if within the wave there is an outlier**
drop abs_wage_growth1 abs_wage_growth2 bonus2_clean bonus1_clean
drop time


*****CPI****************

**Replace year to merge with CPI
replace year=year+1900 if year<100

cap drop _merge
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1988:6 (also average of the year)*/

compress
save data_sipp_part_all_noimp2,replace





******************************************************************************
**	2001 - 2008
******************************************************************************
use 2001_panel_revised, clear
append using 2004_panel_revised
append using 2008_panel_revised




**NEW CRUCIAL, more inputs in panel 96 onwards on wsimp and wscalc. On top of the input for imputation, there is also option statistical or logical imputation. Make
**it consistent with the previous panels**
**For wscalc value 2 is not inputed input, but calculated
foreach var in ws1calc ws1imp05 ws2calc ws2imp05 {
replace `var'=1 if `var'>1 & `var'!=.
}


*****CREATE WEIGHTS*****************************
rename fnlwgt_ wpfinwgt
cap drop fnlwgt*


rename panel panel_year

**PART TIME HOMOGENOUS ACROSS PANELS**

gen aux=-1
replace aux=1 if reason_part==1 & panel_year>=96
replace aux=2 if reason_part==2 & panel_year>=96
replace aux=3 if reason_part==5 & panel_year>=96
replace aux=4 if reason_part==7 & panel_year>=96
replace aux=5 if reason_part==8 & panel_year>=96
**There are other reasons, but to make it analogous to the previous panels I do not consider them
replace aux=6 if (reason_part==12) & panel_year>=96
replace reason_part=aux if panel_year>=96


********************
**Clean imputation**
********************

**ws1imp05: imputation flag for regular hourly rate
**ws1calc: imputation flac for monthly hourly earnings

cap drop time
egen time=group( h_year h_month)

sort su_id pp_entry pp_pnum panel_year pp_wave  h_year h_month
**When amount of hours do not change, and firm does not change, imputation should be constant within wave (take median)
forval x=1(1)2{
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_imputed_income=sd(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen median_imputed_income=median(ws`x'_am)
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_job=sd(jobid`x')
bysort su_id pp_entry pp_pnum panel_year jobid`x' pp_wave: egen change_hours=sd(ws`x'_hr)
replace ws`x'_am=median_imputed_income if change_job==0 & change_hours==0 & ws`x'calc==1 & change_imputed_income>0 & change_imputed_income!=.
drop change_imputed_income median_imputed_income change_job change_hours
}

**Impute hourly rate (using mean) when was paid before by the hour, is paid by the hour afterwards, hourly rate did not change by more than 5%**
forval x=1(1)2{
gen adj_ws`x'_ra=.
sort su_id pp_entry pp_pnum panel_year jobid`x' h_year h_month

by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace adj_ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-1]+ws`x'_ra[_n+4]) if ws`x'_2026[_n-1]==1 & ws`x'_2026[_n+4]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-1]==jobid`x'[_n+4] & (sqrt((ws`x'_ra[_n-1]-ws`x'_ra[_n+4])*(ws`x'_ra[_n-1]-ws`x'_ra[_n+4]))/(ws`x'_ra[_n-1])<0.05) & ws`x'_ra==0 & time[_n-1]+5==time[_n+4]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-2]+ws`x'_ra[_n+3]) if ws`x'_2026[_n-2]==1 & ws`x'_2026[_n+3]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-2]==jobid`x'[_n+3] & (sqrt((ws`x'_ra[_n-2]-ws`x'_ra[_n+3])*(ws`x'_ra[_n-2]-ws`x'_ra[_n+3]))/(ws`x'_ra[_n-2])<0.05) & ws`x'_ra==0 & time[_n-2]+5==time[_n+3]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-3]+ws`x'_ra[_n+2]) if ws`x'_2026[_n-3]==1 & ws`x'_2026[_n+2]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-3]==jobid`x'[_n+2] & (sqrt((ws`x'_ra[_n-3]-ws`x'_ra[_n+2])*(ws`x'_ra[_n-3]-ws`x'_ra[_n+2]))/(ws`x'_ra[_n-3])<0.05) & ws`x'_ra==0 & time[_n-3]+5==time[_n+2]
by su_id pp_entry pp_pnum panel_year jobid`x': replace ws`x'_ra=1/2*(ws`x'_ra[_n-4]+ws`x'_ra[_n+1]) if ws`x'_2026[_n-4]==1 & ws`x'_2026[_n+1]==1 & ws`x'_2026[_n]==2 & jobid`x'[_n]==jobid`x'[_n-4]==jobid`x'[_n+1] & (sqrt((ws`x'_ra[_n-4]-ws`x'_ra[_n+1])*(ws`x'_ra[_n-4]-ws`x'_ra[_n+1]))/(ws`x'_ra[_n-4])<0.05) & ws`x'_ra==0 & time[_n-4]+5==time[_n+1]


**After imputing replace now the indicator ws`x'_2026 that is paid by the hour too**
replace ws`x'_2026=1 if adj_ws`x'_ra>0 & adj_ws`x'_ra!=.
drop adj_ws`x'_ra
}


**Drop if wage growth (hourly and earnings) is above 30% in absolute value because of imputation and conditional on jobid to not change, and hours did not change (for earnings)**

gen outl_imputation=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' h_year h_month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ws`x'_hr[_n]==ws`x'_hr[_n-1]  & ((ws`x'imp05[_n]==1 & ws`x'imp05[_n-1]!=1) | (ws`x'imp05[_n]!=1 & ws`x'imp05[_n-1]==1)) & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. 
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_hourlywage_growth`x'=abs(ws`x'_ra[_n]-ws`x'_ra[_n-1])/(ws`x'_ra[_n-1]) if ws`x'_ra!=0 & ws`x'_ra!=. & ws`x'_ra[_n-1]!=0 & ws`x'_ra[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace outl_imputation=1 if abs_hourlywage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & ((ws`x'calc[_n]==1 & ws`x'calc[_n-1]!=1) | (ws`x'calc[_n]!=1 & ws`x'calc[_n-1]==1))  & abs_hourlywage_growth`x'!=0 & abs_hourlywage_growth`x'!=.
}

bysort su_id pp_entry pp_pnum panel_year pp_wave: egen mean_outl_imputation=mean(outl_imputation)
**Drop the wave from the id if there is an outlier at imputation!**
drop if mean_outl_imputation!=.
drop outl_imputation abs_hourlywage_growth* abs_wage_growth*
drop time



*clean hours worked
replace ws1_hr=0 if ws1_hr<5
replace ws2_hr=0 if ws2_hr<5
*NEW
*replace ws1_hr=0 if ws1_hr<20
*replace ws2_hr=0 if ws2_hr<20
*replace ws1_hr=0 if ws1_hr==99
*replace ws2_hr=0 if ws2_hr==99

replace ws1_hr = 0 if tsjdate1==31
replace ws2_hr = 0 if tsjdate2==31

* Calculated earnings if not reported
replace ws1_am = ws1_hr*ws1_wk*ws1_ra if ws1_am<=0 & ws1_hr>0 & ws1_ra>0 & ws1_wk>0 & jobid1> 0 & ws1imp05==0
replace ws2_am = ws2_hr*ws2_wk*ws2_ra if ws2_am<=0 & ws2_hr>0 & ws2_ra>0 & ws2_wk>0 & jobid2> 0 & ws2imp05==0

*replace earnings if non-imputed paid by the houer
replace ws1_am = ws1_hr*ws1_wk*ws1_ra if jobid1> 0 & ws1_2026==1 & ws1imp05==0
replace ws2_am = ws2_hr*ws2_wk*ws2_ra if jobid2> 0 & ws2_2026==1 & ws2imp05==0
replace ws1calc=0 if jobid1> 0 & ws1_2026==1 & ws1imp05==0
replace ws2calc=0 if jobid2> 0 & ws2_2026==1 & ws2imp05==0

*clean earnings and jobids
replace ws1_am=0 if ws1_am<0
replace ws2_am=0 if ws2_am<0
replace ws1_am=0 if ws1_hr<=0
replace ws2_am=0 if ws2_hr<=0
replace ws1_ra=0 if ws1_ra<=0
replace ws2_ra=0 if ws2_ra<=0
replace jobid1 = 0 if ws1_am <= 0
replace jobid2 = 0 if ws2_am <= 0
replace jobid1 = 0 if ws1_hr <= 0
replace jobid2 = 0 if ws2_hr <= 0
replace jobid1=. if jobid1==0
replace jobid2=. if jobid2==0
replace ws1_hr=. if jobid1==.
replace ws2_hr=. if jobid2==.
replace  ws1_hr=. if  ws1_hr==0 
replace  ws2_hr=. if  ws2_hr==0
replace  ws1_am=. if  ws1_am==0
replace  ws2_am=. if  ws2_am==0
replace  ws1_ra=. if  ws1_ra==0
replace  ws2_ra=. if  ws2_ra==0


*clean esr
*Do not do next step. ESR=8 important to identify out of labor force
*replace esr=8 if jobid1 ==. & jobid2 ==. & esr<=4 
replace esr=5 if esr<=4 & jobid1 ==. & jobid2 ==.


**START AND END DATE OF JOBS. FROM 1996 GIVES THE EXACT DATA**
cap drop aux*


forval x=1(1)2 {
gen aux_tsjdate`x'=tsjdate`x'
tostring aux_tsjdate`x', replace
**Day starting**
gen aux2_tsjdate`x'=substr(aux_tsjdate`x', -2,.)
**Month starting**
gen aux3_tsjdate`x'=substr(aux_tsjdate`x', -4,2)
**Year starting**
gen aux4_tsjdate`x'=substr(aux_tsjdate`x', 1,4)

**Problems when translating the date**
gen aux5_tsjdate`x'=floor(tsjdate`x')
replace aux5_tsjdate`x'=aux5_tsjdate`x'-tsjdate`x'
**Makes sure that the date corresponds to tjsdate/tejdate
destring aux2_tsjdate`x', replace
replace aux2_tsjdate`x'=aux2_tsjdate`x'-aux5_tsjdate`x'

**Given that variable is reported by wave, if month started a job is above the month within the wave, put it as -1**
gen month_tsjdate`x'=aux3_tsjdate`x'
destring month_tsjdate`x', replace
gen year_tsjdate`x'=aux4_tsjdate`x'
destring year_tsjdate`x', replace

**Do the same for ending job
gen aux_tejdate`x'=tejdate`x'
tostring aux_tejdate`x', replace
**Day ending**
gen aux2_tejdate`x'=substr(aux_tejdate`x', -2,.)
**Month ending**
gen aux3_tejdate`x'=substr(aux_tejdate`x', -4,2)
**Year ending**
gen aux4_tejdate`x'=substr(aux_tejdate`x', 1,4)
**Problems when translating the date**
gen aux5_tejdate`x'=floor(tejdate`x')
replace aux5_tejdate`x'=aux5_tejdate`x'-tejdate`x'
**Makes sure that the date corresponds to tjsdate/tejdate
destring aux2_tejdate`x', replace
replace aux2_tejdate`x'=aux2_tejdate`x'-aux5_tejdate`x'

**Given that variable is reported by wave, if month end a job is above the month within the wave, put it as -1**
gen month_tejdate`x'=aux3_tejdate`x'
destring month_tejdate`x', replace
gen year_tejdate`x'=aux4_tejdate`x'
destring year_tejdate`x', replace

**Put as not in universe if the starting day of the job is above the current month of the year
replace aux2_tsjdate`x'=-1 if month_tsjdate`x'>h_month & year_tsjdate`x'==h_year & year_tsjdate`x'!=-1
replace aux2_tsjdate`x'=-1 if year_tsjdate`x'>h_year & year_tsjdate`x'!=-1
replace aux2_tejdate`x'=-1 if month_tejdate`x'<h_month & year_tejdate`x'==h_year & year_tejdate`x'!=-1
replace aux2_tejdate`x'=-1 if year_tejdate`x'<h_year & year_tejdate`x'!=-1

*gen aux6_tsjdate`x'=aux2_tsjdate`x'
*gen aux6_tejdate`x'=aux2_tejdate`x'

gen aux6_tsjdate`x'=.
gen aux6_tejdate`x'=.

**First month working**
replace aux6_tsjdate`x'=aux2_tsjdate`x' if year_tsjdate`x'==h_year & month_tsjdate`x'==h_month & jobid`x'!=.
**Last month working**
replace aux6_tejdate`x'=aux2_tejdate`x' if year_tejdate`x'==h_year & month_tejdate`x'==h_month & jobid`x'!=.

**For those months within the wave that person did not start a job nor end a job, consider to have started at beginning of the month, and end working within the month at the end of the month**
replace aux6_tsjdate`x'=0 if month_tsjdate`x'<=h_month<=month_tejdate`x' & year_tsjdate`x'<=h_year & year_tejdate`x'<=h_year & year_tsjdate`x'!=-1 & year_tejdate`x'!=-1 & aux6_tsjdate`x'==. & jobid`x'!=.
replace aux6_tejdate`x'=0 if month_tsjdate`x'<=h_month<=month_tejdate`x' & year_tsjdate`x'<=h_year & year_tejdate`x'<=h_year & year_tsjdate`x'!=-1 & year_tejdate`x'!=-1 & aux6_tejdate`x'==. & jobid`x'!=.

*Do instead this adjustment!  Case where person does not answer beginning and end of job, but reports having a job
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==.
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==.

**Case where reports beginning of started job but not the end. Impute starting day started job in the month to be beginning of the month**
replace aux6_tsjdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tsjdate`x'<h_year
replace aux6_tsjdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tsjdate`x'==h_year & month_tsjdate`x'<=h_month
**Also impute days end job  to be end of the month**
replace aux6_tejdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tsjdate`x'<h_year
replace aux6_tejdate`x'=0 if year_tsjdate`x'!=-1 & year_tejdate`x'==-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tsjdate`x'==h_year & month_tsjdate`x'<=h_month

**Case where reports end of period job but not the beginning. Impute starting day started job in the month to be beginning of the month**
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tejdate`x'>h_year
replace aux6_tsjdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tsjdate`x'==. & year_tejdate`x'==h_year & month_tejdate`x'>=h_month
**Also impute days end job  to be end of the month**
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tejdate`x'>h_year
replace aux6_tejdate`x'=0 if year_tsjdate`x'==-1 & year_tejdate`x'!=-1 & jobid`x'>0 & jobid`x'!=. & aux6_tejdate`x'==. & year_tejdate`x'==h_year & month_tejdate`x'>=h_month


**In case there is no information. Put -1**
replace aux6_tsjdate`x'=-1 if aux6_tsjdate`x'==.
replace aux6_tejdate`x'=-1 if aux6_tejdate`x'==.
}


foreach var in tsjdate1 tsjdate2 tejdate1 tejdate2 {
replace `var'=aux6_`var' if panel_year>=96
drop aux2_`var'
}
cap drop aux*


**EDUCATION**


gen new_educ=.
**With high school or less**
replace new_educ=1 if grade<=12 & panel_year<=93 
**With some collegue**
replace new_educ=2 if grade>12 & grade<23 & panel_year<=93
**Collegue or more**
replace new_educ=3 if grade>=23 & panel_year<=93


**With high school or less**
replace new_educ=1 if grade<=39 & panel_year>=96
**With some collegue**
replace new_educ=2 if grade>39 & grade<42 & panel_year>=96
**Collegue or more**
replace new_educ=3 if grade>=42 & panel_year>=96




*Error! First, define the new id, then define grades! There might be repeated id's
cap drop id
egen id = group(su_id pp_entry pp_pnum panel_year)
egen grades=max(new_educ),by(id)	
tostring id, replace


*****CREATE CALENDAR MONTH/YEAR*****************************
rename h_year year
rename h_month month
gen     quarter=1 if month>=1 & month<=3
replace quarter=2 if month>=4 & month<=6
replace quarter=3 if month>=7 & month<=9
replace quarter=4 if month>=10 & month<=12

*****CREATE SOME DEMOG*****
gen     region=1 if state==9|state==61|state==33|state==34|state==36|state==42|state==44|state==25
replace region=2 if state==17|state==18|state==62|state==20|state==26|state==27|state==29|state==31|state==39|state==55
replace region=3 if state==1|state==13|state==22|state==28|state==45|state==5|state==10|state==12|state==21|state==24|state==37|state==40|state==47|state==51|state==11|state==54
replace region=4 if region==. & state>0 & state<64
gen white  =race==1
gen married=ms==1|ms==2
replace h_tenur=2 if h_tenur==3
replace f_oklt18=4 if f_oklt18>4 & f_oklt18!=.

*****DROP THE SELF-EMPLOYED*********************************
egen self=sum(sc1714>1),by(id)
drop if self>0
drop self
************************************************************

drop if state==0
drop if wpfinwgt==0


*decide whether to use reported weeks, or smooth 4.3 weeks
replace tejdate1 = 31 if tejdate1>29
replace tejdate2 = 31 if tejdate2>29
gen ws1_wks = -1
replace ws1_wks = 4.3 if jobid1>0
*replace ws1_wks = ws1_wk if jobid1>0 & ws1_2026==1 & ws1imp05==0 
replace ws1_wks = (tejdate1-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1>0
replace ws1_wks = (tejdate1)/7 if jobid1>0 & tejdate1>0 & tsjdate1==0
replace ws1_wks = (31-tsjdate1)/7 if jobid1>0 & tsjdate1>1 & tejdate1<=0
gen ws2_wks = -1
replace ws2_wks = 4.3 if jobid2>0
*replace ws2_wks = ws2_wk if jobid2>0 & ws2_2026==1 & ws2imp05==0
replace ws2_wks = (tejdate2-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2>0
replace ws2_wks = (tejdate2)/7 if jobid2>0 & tejdate2>0 & tsjdate2==0
replace ws2_wks = (31-tsjdate2)/7 if jobid2>0 & tsjdate2>1 & tejdate2<=0

gen earn1_h_s = ws1_am/(ws1_wks*ws1_hr)
gen earn2_h_s = ws2_am/(ws2_wks*ws2_hr)
gen earn1_h_ns = ws1_am/(ws1_wk*ws1_hr)
gen earn2_h_ns = ws2_am/(ws2_wk*ws2_hr)


cap drop time
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_s = log(earn1_h_s)-log(earn1_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_s = log(earn2_h_s)-log(earn2_h_s[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ns = log(earn1_h_ns)-log(earn1_h_ns[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ns = log(earn2_h_ns)-log(earn2_h_ns[_n-1]) if time==time[_n-1]+1

replace ws1_wks = ws1_wk if abs(g1_ns)<abs(g1_s) 
replace ws2_wks = ws2_wk if abs(g2_ns)<abs(g2_s) 

drop g1_ns g1_s g2_ns g2_s earn1_h_s earn2_h_s earn1_h_ns earn2_h_ns


*gen id_aux = group(su_id pp_entry pp_pnum panel_year)
cap drop time
egen time=group( year month)
sort su_id pp_entry pp_pnum panel_year time
*weeks are constant if earnings and hours do not change
gen z=0
forval x=1(1)3{
if (`x'<=3) {
sort su_id pp_entry pp_pnum panel_year year month
bysort su_id pp_entry pp_pnum panel_year: replace ws1_wks=ws1_wks[_n+1] if ws1_am==ws1_am[_n+1] & ws1_hr==ws1_hr[_n+1]  & jobid1==jobid1[_n+1] & jobid1!=. & time==time[_n+1]-1
bysort su_id pp_entry pp_pnum panel_year: replace ws2_wks=ws2_wks[_n+1] if ws2_am==ws2_am[_n+1] & ws2_hr==ws2_hr[_n+1]  & jobid2==jobid2[_n+1] & jobid2!=. & time==time[_n+1]-1
replace z=`x'
}
}
cap drop z 




*****calculate monthly hourly earnings based on reported earnings*******
gen ws1_hourly_am = ws1_am/(ws1_hr*ws1_wks)
gen ws2_hourly_am = ws2_am/(ws2_hr*ws2_wks)


*****calculate monthly hourly earnings based on hourly rate*******
gen ws1_am_ra = .
gen ws2_am_ra = .
replace ws1_am_ra = ws1_ra if jobid1> 0 & ws1imp05==0
replace ws2_am_ra = ws2_ra if jobid2> 0 & ws2imp05==0

*impute series from each other to assure that we have the full amount of observations
replace ws1_hourly_am=ws1_am_ra if ws1_hourly_am==. & ws1_am_ra!=.
replace ws2_hourly_am=ws2_am_ra if ws2_hourly_am==. & ws2_am_ra!=.
replace ws1_am_ra=ws1_hourly_am if ws1_am_ra==. & ws1_hourly_am!=.
replace ws2_am_ra=ws2_hourly_am if ws2_am_ra==. & ws2_hourly_am!=.

*****we keep the series which gives us the minimum volatility in growth rates******
sort su_id pp_entry pp_pnum panel_year year month
by su_id pp_entry pp_pnum panel_year: gen g1_am = log(ws1_hourly_am)-log(ws1_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_am = log(ws2_hourly_am)-log(ws2_hourly_am[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g1_ra = log(ws1_am_ra)-log(ws1_am_ra[_n-1]) if time==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year: gen g2_ra = log(ws2_am_ra)-log(ws2_am_ra[_n-1]) if time==time[_n-1]+1
*compute standard deviation
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_am1 = sd(g1_am)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_am2 = sd(g2_am)
bysort su_id pp_entry pp_pnum panel_year jobid1: egen std_ra1 = sd(g1_ra)
bysort su_id pp_entry pp_pnum panel_year jobid2: egen std_ra2 = sd(g2_ra)

gen ws1_hr_best = ws1_hourly_am if std_am1<=std_ra1
gen ws2_hr_best = ws2_hourly_am if std_am2<=std_ra2
replace ws1_hr_best=ws1_am_ra if std_am1>std_ra1
replace ws2_hr_best=ws2_am_ra if std_am2>std_ra2

replace ws1_am = ws1_hr_best*ws1_wks*ws1_hr
replace ws2_am = ws2_hr_best*ws2_wks*ws2_hr


***CLEAN FOR BONUSES!!***
**Drop if wage growth (earnings) is above 30% in absolute value conditional on jobid to not change at L1,L0,F1, hours did not change at L1,L0,F1, and weeks to not change at L1,L0,F1, and value wage at period  [_n-1]==[_n+1]**
**These are commonly bonuses**
cap drop time
sort year month
egen time=group(year month)
sort su_id pp_entry pp_pnum panel_year pp_wave year month
gen bonus1_clean=.
gen bonus2_clean=.
forval x=1(1)2{
sort su_id pp_entry pp_pnum panel_year jobid`x' year month
by su_id pp_entry pp_pnum panel_year jobid`x': gen abs_wage_growth`x'=abs(ws`x'_am[_n]-ws`x'_am[_n-1])/(ws`x'_am[_n-1]) if ws`x'_am!=0 & ws`x'_am!=. & ws`x'_am[_n-1]!=0 & ws`x'_am[_n-1]!=. & time[_n]==time[_n-1]+1
by su_id pp_entry pp_pnum panel_year jobid`x': replace bonus`x'_clean=1 if abs_wage_growth`x'>0.3 & jobid`x'[_n]==jobid`x'[_n-1] & jobid`x'[_n-1]==jobid`x'[_n+1] & ws`x'_hr[_n]==ws`x'_hr[_n-1] & ws`x'_hr[_n-1]==ws`x'_hr[_n+1] & ws`x'_wks[_n]==ws`x'_wks[_n-1] & ws`x'_wks[_n-1]==ws`x'_wks[_n+1]  & abs_wage_growth`x'!=0 & abs_wage_growth`x'!=. & ws`x'_am[_n-1]==ws`x'_am[_n+1]
}
sort su_id pp_entry pp_pnum panel_year jobid1 year month
replace ws1_am=ws1_am[_n-1] if bonus1_clean==1  & time[_n]==time[_n-1]+1
sort su_id pp_entry pp_pnum panel_year jobid2 year month
replace ws2_am=ws2_am[_n-1] if bonus2_clean==1  & time[_n]==time[_n-1]+1
 **Drop the wave if within the wave there is an outlier**
drop abs_wage_growth1 abs_wage_growth2 bonus2_clean bonus1_clean
drop time

*****CPI****************

**Replace year to merge with CPI
replace year=year+1900 if year<100

cap drop _merge
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				/*CPI Base 1988:6 (also average of the year)*/

compress
save data_sipp_part_all_noimp3,replace


**Create occupational groups***
use occ1980_occ1990dd, clear
sort occ
save occ1980_occ1990dd, replace

use occ1990_occ1990dd, clear
sort occ 
save occ1990_occ1990dd, replace

use occ2000_occ1990dd, clear
cap drop occ2
gen occ2=occ
sort occ2
save occ2000_occ1990dd, replace







forval x=1(1)3{


u data_sipp_part_all_noimp`x',clear

**Identify main job as the one where the worker earns most during the month**
**Later on, we look at the changes in income from this main jobs identified within the month, over the quarter**
sort id year month
gen aux=.
gen aux2=.
replace aux=1 if (ws1_am>=ws2_am) & ws1_am>0 & ws2_am>0 & ws1_am!=. & ws2_am!=.
replace aux=2 if ws2_am>ws1_am & ws2_am>0 & ws1_am>0 & ws1_am!=. & ws2_am!=.
replace aux2=1 if ws1_am!=. & ws1_am>0 & ws2_am==.
replace aux2=2 if ws2_am!=. & ws2_am>0 & ws1_am==.

gen jobidmain=.
replace jobidmain=jobid1 if aux==1
replace jobidmain=jobid2 if aux==2
replace jobidmain=jobid1 if aux2==1 & aux==.
replace jobidmain=jobid2 if aux2==2 & aux==.

drop aux aux2


cap drop index*

*Identify those workers who change main job id but go back to previous job id next month (can happen several times for same person--max observable 8)
*Notice that we do not use lag of 8!
gen z=0
forval z=1(1)8{
if (z<=8) {
gen false_move=0
sort id year month
by id:replace false_move=1 if jobidmain[_n+1]==jobidmain[_n-1] & jobidmain!=jobidmain[_n-1] & jobidmain[_n-1]!=. & jobidmain[_n+1]!=. & jobidmain!=. 
cap drop aux
gen aux = 1 if jobidmain==jobid1
replace aux = 2 if jobidmain==jobid2
replace jobidmain=jobid1 if aux == 2 & false_move==1 & jobid1!=.
replace jobidmain=jobid2 if aux == 1 & false_move==1 & jobid2!=.
drop aux false_move
replace z=`z'
}
}
cap drop z



gen aux = 1 if jobidmain==jobid1
replace aux = 2 if jobidmain==jobid2
gen earn_main=.
replace earn_main=ws1_am if aux==1
replace earn_main=ws2_am if aux==2
gen hours_main=.
replace hours_main=ws1_hr if aux==1
replace hours_main=ws2_hr if aux==2
gen weeks_main=.
replace weeks_main=ws1_wk if aux==1
replace weeks_main=ws2_wk if aux==2
gen weekss_main=.
replace weekss_main=ws1_wks if aux==1
replace weekss_main=ws2_wks if aux==2
gen industry_main=.
replace industry_main=ws1_in if aux==1
replace industry_main=ws2_in if aux==2
gen occupation_main=.
replace occupation_main=ws1_oc if aux==1
replace occupation_main=ws2_oc if aux==2
gen class_worker_main=.
replace class_worker_main=ws1_cl if aux==1
replace class_worker_main=ws2_cl if aux==2
gen imp_main=.
replace imp_main=ws1calc if aux==1
replace imp_main=ws2calc if aux==2
gen tenure_main=.
replace tenure_main=tenure1 if aux==1
replace tenure_main=tenure2 if aux==2



***NEW: drop observation when worker switches from full (part) to part (full) because he wants***
gen part = 1 if jobidmain>0 & hours_main<35 & jobidmain!=.
replace part=2 if jobidmain>0 & hours_main>=35 & jobidmain!=.
cap drop time
egen time = group(year month)
sort id time
by id: gen diff_part = part[_n]-part[_n-1]
*moving from full to part
replace diff_part =0 if diff_part ==-1 & reason_part!=2
*moving from part to full
replace diff_part =0 if diff_part ==1 & reason_part[_n-1]!=2
replace diff_part=0 if diff_part==.
*drop observation of voluntary switch
drop if diff_part!=0
drop diff_part


drop if in_af == 1
drop in_af
drop if class_worker_main == 6
drop if school ==1
drop school

*****CREATES A NO-GAP SEQUENCE OF FIRM IDS: 123... OR 213...; THIS VARIABLE (NF) REPLACES FIRM ID JOBIDMAIN****************
egen nf=group(id jobidmain)
egen min=min(nf),by(id)
replace nf=nf-min+1
drop min
replace jobidmain = nf

*****CREATES A VARIABLE # OF JOBS***************************************************************************************************
egen minnf=min(nf),by(id)
egen maxnf=max(nf),by(id)
gen num_jobs=maxnf-minnf+1


*****THE NEW FIRM ID IS "FIRM"***********************************
*****************************************************************
gen firm=nf


**************************************************************************************
*****NOW ELIMINATES RECALLS and RETURNS*****
cap drop nf
egen nf=group(id firm)
cap drop time
egen time = group(year month)
sort nf time
by nf: gen index2 = time[_n]-time[_n-1]
replace index2=1 if index2==.
replace index2=1 if nf==0
replace index2=1 if nf==.
sort id time
by id: egen index3 = max(index2)
replace index3=0 if index3>1
di "Number of observations recalls drop"
drop if index3==0
drop index2 index3 nf time
cap drop index


**************************************************************************************
**************************************************************************************

/*************************************************************************************
************HOURLY WAGES**************************************************************
Info available is:
(a) total monthly earnings with this firm 						(earn_main)
(b) total weekly hours worked									(hours_main)
(c) total weeks of work with this firm in this month			(weeks_main)
**************************************************************************************
*************************************************************************************/
gen ernam1=earn_main
gen wshrs1=hours_main
gen wksem1=weekss_main


foreach var in wshrs1 ernam1 wksem1 {
replace `var'=0 if `var'==.
}
gen hours_m = wshrs1*wksem1

gen nomearn=ernam1
gen realearn=ernam1/(cpi/100)
replace u_comp = u_comp/(cpi/100)
replace soc_sec_inc = soc_sec_inc/(cpi/100)

*****EMPLOYMENT STATUS: EMPL, UNEMPL, OLF***********************
*****ASSUME EMPLOYED IF never unemployed in THE MONTH****
gen     status=1 if esr>=1 & esr<=4
replace status=2 if esr>=5 & esr<=7
replace status=3 if esr==8

***HOUSEHOLD DEPENDENCE AND EMPLOYMENT STATUS**
cap drop count
bysort su_id h_add year month: gen count=_N

*Identify people who are the only ones who may potentially work in the household**
gen single_work=0
replace single_work=1 if count==1


*Identify those people whose partner or another individual in the household works**
cap drop aux
gen aux=0
replace aux=1 if status==1
bysort su_id h_add year month: egen total_work_hh=total(aux)
replace total_work_hh=total_work_hh-aux

gen partner_work=0
replace partner_work=1 if count>1 & total_work_hh!=0  & total_work_hh!=. & count!=.  

sort id

**RENAME SOME VARIABLES**

**********************RENAME AND ADJUST SOME VARIABLES TO MAKE IT HOMOGENOUS ACROSS PANELS***********************************

*1980 CENSUS
gen ind_group2=.
replace ind_group2=1 if industry_main>=10 & industry_main<=31 & panel_year<=1992 /* agriculture */
replace ind_group2=2 if industry_main>=40 & industry_main<=50 & panel_year<=1992 /*mining*/
replace ind_group2=3 if industry_main==60 & panel_year<=1992 /*construction*/
replace ind_group2=4 if industry_main>=100 & industry_main<=222 & panel_year<=1992 /*non-durables*/
replace ind_group2=5 if industry_main>=230 & industry_main<=392 & panel_year<=1992 /*durables*/
replace ind_group2=6 if industry_main>=400 & industry_main<=472 & panel_year<=1992 /*transport,communication,utilities*/
replace ind_group2=7 if industry_main>=500 & industry_main<=571 & panel_year<=1992 /*wholesale trade*/
replace ind_group2=8 if industry_main>=580 & industry_main<=691 & panel_year<=1992 /*retail trade*/
replace ind_group2=9 if industry_main>=700 & industry_main<=712 & panel_year<=1992 /*Finance, insurance, r.estate*/
replace ind_group2=10 if industry_main>=721 & industry_main<=760 & panel_year<=1992 /*Business and professional services*/
replace ind_group2=10 if industry_main>=812 & industry_main<=892 & panel_year<=1992 /*Business and professional services*/
replace ind_group2=11 if industry_main>=761 & industry_main<=802 & panel_year<=1992 /*Personal services+entertainment*/
replace ind_group2=12 if industry_main>=900 & industry_main<=932 & panel_year<=1992 /*Public*/
replace ind_group2=13 if industry_main>=933 & industry_main<=999 & panel_year<=1992 /*not reported+armed forces*/

*1990 CENSUS
replace ind_group2=1 if industry_main>=10 & industry_main<=32 & panel_year>=1993 & panel_year<=2001 /* agriculture */
replace ind_group2=2 if industry_main>=40 & industry_main<=50 & panel_year>=1993 & panel_year<=2001 /*mining*/
replace ind_group2=3 if industry_main==60 & panel_year>=1993 & panel_year<=2001 /*construction*/
replace ind_group2=4 if industry_main>=100 & industry_main<=222 & panel_year>=1993 & panel_year<=2001 /*non-durables*/
replace ind_group2=5 if industry_main>=230 & industry_main<=392 & panel_year>=1993 & panel_year<=2001 /*durables*/
replace ind_group2=6 if industry_main>=400 & industry_main<=472 & panel_year>=1993 & panel_year<=2001 /*transport,communication,utilities*/
replace ind_group2=7 if industry_main>=500 & industry_main<=571 & panel_year>=1993 & panel_year<=2001 /*wholesale trade*/
replace ind_group2=8 if industry_main>=580 & industry_main<=691 & panel_year>=1993 & panel_year<=2001 /*retail trade*/
replace ind_group2=9 if industry_main>=700 & industry_main<=712 & panel_year>=1993 & panel_year<=2001 /*Finance, insurance, r.estate*/
replace ind_group2=10 if industry_main>=721 & industry_main<=760 & panel_year>=1993 & panel_year<=2001 /*Business and professional services*/
replace ind_group2=10 if industry_main>=812 & industry_main<=893 & panel_year>=1993 & panel_year<=2001 /*Business and professional services*/
replace ind_group2=11 if industry_main>=761 & industry_main<=810 & panel_year>=1993 & panel_year<=2001 /*Personal services+entertainment*/
replace ind_group2=12 if industry_main>=900 & industry_main<=932 & panel_year>=1993 & panel_year<=2001 /*Public*/
replace ind_group2=13 if industry_main>=933 & industry_main<=999 & panel_year>=1993 & panel_year<=2001 /*not reported+armed forces*/


*2000 CENSUS
replace ind_group2=1 if industry_main>=170 & industry_main<=290 & panel_year>=2004 /* agriculture */
replace ind_group2=2 if industry_main>=370 & industry_main<=490 & panel_year>=2004 /*mining*/
replace ind_group2=3 if industry_main==770 & panel_year>=2004 /*construction*/
replace ind_group2=4 if industry_main>=1070 & industry_main<=2390 & panel_year>=2004 /*non-durables*/
replace ind_group2=4 if industry_main==6470 | industry_main==6480 | industry_main==6490 & panel_year>=2004 /*non-durables*/
replace ind_group2=5 if industry_main>=2470 & industry_main<=3990 & panel_year>=2004 /*durables*/
replace ind_group2=6 if industry_main>=6070 & industry_main<=6390 & panel_year>=2004 /*transport,communication,utilities*/
replace ind_group2=6 if industry_main>=570 & industry_main<=690 & panel_year>=2004 /*transport,communication,utilities*/
replace ind_group2=6 if industry_main>=6570 & industry_main<=6780 & panel_year>=2004 /*transport,communication,utilities*/
replace ind_group2=7 if industry_main>=4070 & industry_main<=4590 & panel_year>=2004 /*wholesale trade*/
replace ind_group2=8 if industry_main>=4670 & industry_main<=5790 & panel_year>=2004 /*retail trade*/
replace ind_group2=9 if industry_main>=6870 & industry_main<=7190 & panel_year>=2004 /*Finance, insurance, r.estate*/
replace ind_group2=10 if industry_main>=7270 & industry_main<=7790 & panel_year>=2004 /*Business and professional services*/
replace ind_group2=10 if industry_main>=7860 & industry_main<=8470 & panel_year>=2004 /*Business and professional services*/
replace ind_group2=11 if industry_main>=8560 & industry_main<=9290 & panel_year>=2004 /*Personal services+entertainment*/
replace ind_group2=12 if industry_main>=9370 & industry_main<=9590 & panel_year>=2004 /*Public*/
replace ind_group2=13 if industry_main>=9670 & industry_main<=9999 & panel_year>=2004 /*not reported+armed forces*/

***INDUSTRY***

*********************************************
*  Edited and imputed 2 digit industry code
*         01 .Agriculture, forestry, 
*             .fisheries and mining
*         02 .Construction
*         03 .Manufacturing
*         04 .Transportation, communication, trade
*         05 .Finance, insurance, r.estate
*         06 .Non financial services
*         07 .Public administration
*         08 .Industry not reported

**Rename industry code**
gen ind_group=.
replace ind_group=1 if ind_group2==1 | ind_group2==2 
replace ind_group=2 if ind_group2==3 
replace ind_group=3 if ind_group2==4 | ind_group2==5 
replace ind_group=4 if ind_group2==6 | ind_group2==7 | ind_group2==8
replace ind_group=5 if ind_group2==9
replace ind_group=6 if ind_group2==10 | ind_group2==11 
replace ind_group=7 if ind_group2==12
replace ind_group=8 if ind_group2==13

*DROP those who worked at armed forces or did not report**
drop if ind_group==8

rename h_totinc hh_inc
rename h_earn hh_ear
rename h_tran hh_tra 
rename pp_earn pp_ear
drop grade industry_main

*******************************************************************************************
sort id year month
save data2_sipp_new_part_all_noimp`x',replace


***OCCUPATIONAL CODES*******
gen occ=occupation_main
sort occ
merge occ using occ1980_occ1990dd
rename occ1990dd aux1
drop _merge
sort occ
merge occ using occ1990_occ1990dd
rename occ1990dd aux2
drop _merge

**Take out last zero for occupation 2004-2008**
cap drop occ2
gen occ2=occ
tostring occ2, replace
gen occ3=substr(occ2,1,1)
destring occ3, replace force
gen occ4=substr(occ2,1,2)
destring occ4, replace
gen occ5=substr(occ2,1,3)
destring occ5, replace
destring occ2, replace
gen occ6=.
replace occ6=occ3 if occ2<100 & occ2>=10
replace occ6=occ4 if occ2<1000 & occ2>=100
replace occ6=occ5 if occ2<10000 & occ2>=1000
drop occ2 occ3 occ4 occ5
rename occ6 occ2
sort occ2
merge occ2 using occ2000_occ1990dd
rename occ1990dd aux3
drop _merge

**Drop non-existing id's**
gen aux7=id
destring aux7, replace
drop if aux7==.
cap drop aux7
*1980 census up to 1992, 1993 starts with 1990, 2004 starts with 2000*
gen occ1990dd=.
replace occ1990dd=aux1 if panel_year<=92
replace occ1990dd=aux2 if panel_year>92 & panel_year<=2001
replace occ1990dd=aux3 if panel_year>2001 & panel_year<=2008

drop aux1 aux2 aux3
cap drop occ 
cap drop occ2
*******************************************************************
* Occ1990dd Occupation Groups
*******************************************************************
* Copied from David Dorn, version October 12, 2012
********************************************************************
* Occupation Dummies Level 3: Subgroups of Low-Skill Service Occupations
********************************************************************
gen occ3_clean=0            /* housekeeping, cleaning, laundry */
replace occ3_clean=1 if     (occ1990dd>=405 & occ1990dd<=408 & occ1990dd!=.)
gen occ3_protect=0        /* all protective service */
replace occ3_protect=1 if (occ1990dd>=415 & occ1990dd<=427  & occ1990dd!=.)
gen occ3_guard=0          /* supervisors of guards; guards */
replace occ3_guard=1 if (occ1990dd==415  & occ1990dd!=. | (occ1990dd>=425 & occ1990dd<=427  & occ1990dd!=.))
gen occ3_food=0           /* food preparation and service occs */
replace occ3_food=1 if (occ1990dd>=433 & occ1990dd<=444  & occ1990dd!=.)
gen occ3_shealth=0        /* health service occs (dental ass., health/nursing aides) */
replace occ3_shealth=1 if (occ1990dd>=445 & occ1990dd<=447  & occ1990dd!=.)
gen occ3_janitor=0          /* building and grounds cleaning and maintenance occs */
replace occ3_janitor=1 if (occ1990dd>=448 & occ1990dd<=455  & occ1990dd!=.)
gen occ3_beauty=0           /* personal appearance occs */
replace occ3_beauty=1 if (occ1990dd>=457 & occ1990dd<=458  & occ1990dd!=.)
gen occ3_recreation=0      /* recreation and hospitality occs */
replace occ3_recreation=1 if (occ1990dd>=459 & occ1990dd<=467  & occ1990dd!=.)
gen occ3_child=0           /* child care workers */
replace occ3_child=1 if (occ1990dd==468  & occ1990dd!=.)
gen occ3_othpers=0        /* misc. personal care and service occs */
replace occ3_othpers=1 if (occ1990dd>=469 & occ1990dd<=472)
********************************************************************
* Occupation Dummies Level 2: 16 Non-Service Occupation Groups
********************************************************************
gen occ2_exec=0          /* executive, administrative and managerial occs */
replace occ2_exec=1 if (occ1990dd>=3 & occ1990dd<=22  & occ1990dd!=.)
gen occ2_mgmtrel=0       /* management related occs */
replace occ2_mgmtrel=1 if (occ1990dd>=23 & occ1990dd<=37  & occ1990dd!=.)
gen occ2_prof=0          /* professional specialty occs */
replace occ2_prof=1 if (occ1990dd>=43 & occ1990dd<=200  & occ1990dd!=.)
gen occ2_tech=0          /* technicians and related support occs */
replace occ2_tech=1 if (occ1990dd>=203 & occ1990dd<=235  & occ1990dd!=.)
gen occ2_finsales=0      /* financial sales and related occs */
replace occ2_finsales=1 if (occ1990dd>=243 & occ1990dd<=258  & occ1990dd!=.)
gen occ2_retsales=0      /* retail sales occs */
replace occ2_retsales=1 if (occ1990dd>=274 & occ1990dd<=283  & occ1990dd!=.)
gen occ2_cleric=0        /* administrative support occs */
replace occ2_cleric=1 if (occ1990dd>=303 & occ1990dd<=389  & occ1990dd!=.)
gen occ2_firepol=0       /* fire fighting, police, and correctional insitutions */
replace occ2_firepol=1 if (occ1990dd>=417 & occ1990dd<=423  & occ1990dd!=.)
gen occ2_farmer=0        /* farm operators and managers */
replace occ2_farmer=1 if (occ1990dd>=473 & occ1990dd<=475  & occ1990dd!=.)
gen occ2_otheragr=0      /* other agricultural and related occs */
replace occ2_otheragr=1 if (occ1990dd>=479 & occ1990dd<=498  & occ1990dd!=.)
gen occ2_mechanic=0      /* mechanics and repairers */
replace occ2_mechanic=1 if (occ1990dd>=503 & occ1990dd<=549  & occ1990dd!=.)
gen occ2_constr=0        /* construction trades */
replace occ2_constr=1 if (occ1990dd>=558 & occ1990dd<=599  & occ1990dd!=.)
gen occ2_mining=0        /* extractive occs */
replace occ2_mining=1 if (occ1990dd>=614 & occ1990dd<=617  & occ1990dd!=.)
gen occ2_product=0       /* precision production occs */
replace occ2_product=1 if (occ1990dd>=628 & occ1990dd<=699  & occ1990dd!=.)
gen occ2_operator=0      /* machine operators, assemblers, and inspectors */
replace occ2_operator=1 if (occ1990dd>=703 & occ1990dd<=799  & occ1990dd!=.)
gen occ2_transp=0        /* transportation and material moving occs */
replace occ2_transp=1 if (occ1990dd>=803 & occ1990dd<=889  & occ1990dd!=.)
********************************************************************
* Occupation Dummies Level 1: 6 Aggregate Occupation Groups
* as used in Autor and Dorn, "The Growth of Low-Skill Service Jobs
* and the Polarization of the U.S. Labor Market"
********************************************************************
* (1) management/professional/technical/financial sales/public security occs
gen occ1_managproftech=occ2_exec+occ2_mgmtrel+occ2_prof+occ2_tech+occ2_finsales+occ2_firepol
* (2) administrative support and retail sales occs
gen occ1_clericretail=occ2_cleric+occ2_retsales
* (3) low-skill services
gen occ1_service=occ3_clean+occ3_guard+occ3_food+occ3_shealth+occ3_janitor+occ3_beauty+occ3_recreation+occ3_child+occ3_othpers
* (4) precision production and craft occs
gen occ1_product=occ2_product
* (5) machine operators, assemblers and inspectors
gen occ1_operator=occ2_operator
* (6) transportation/construction/mechanics/mining/agricultural occs
gen occ1_transmechcraft=occ2_transp+occ2_constr+occ2_mechanic+occ2_mining+occ2_farmer+occ2_otheragr
gen mayor_group_occ1=.
replace mayor_group_occ1=1 if occ1_managproftech==1
replace mayor_group_occ1=2 if occ1_clericretail==1
replace mayor_group_occ1=3 if occ1_service==1
replace mayor_group_occ1=4 if occ1_product==1
replace mayor_group_occ1=5 if occ1_operator==1
replace mayor_group_occ1=6 if occ1_transmechcraft==1



**Look at changes comming from firm and industryn
save data2_sipp_new_part_all_noimp`x', replace

}






*******************************************************************************************************************************************************
***************************************************Construct quarterly dataset*************************************************************************
*******************************************************************************************************************************************************

forval x=1(1)3{

use data2_sipp_new_part_all_noimp`x',clear

**If using income net of taxes drop sex=2 inmediately!

if (`x'==1) {
keep su_id h_add pp_entry pp_pnum pp_wave id year quarter firm hours_m weekss_main real_net_worth realearn nomearn month rrp cpi sex age grades white married region state f_oklt18 h_tenur h_metro panel_year status class_worker_main hh_inc hh_ear hh_tra pp_ear ind_group occupation_main tenure_main exper wpfinwgt disab esr partner_work single_work  child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw disab_ss imp_main h_povd caidcov h_np u_comp gov_pension retird soc_sec_inc
}

if (`x'==2) {
keep su_id h_add pp_entry pp_pnum pp_wave id year quarter firm hours_m weekss_main real_net_worth realearn nomearn month rrp cpi sex age grades white married region state f_oklt18 h_tenur h_metro panel_year status class_worker_main hh_inc hh_ear hh_tra pp_ear ind_group occupation_main tenure_main exper wpfinwgt disab esr partner_work single_work  child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw disab_ss imp_main h_povd caidcov h_np u_comp gov_pension retird soc_sec_inc
}

if (`x'==3) {
keep su_id h_add pp_entry pp_pnum pp_wave id year quarter firm hours_m weekss_main real_net_worth realearn nomearn month rrp cpi sex age grades white married region state f_oklt18 h_tenur h_metro panel_year status class_worker_main hh_inc hh_ear hh_tra pp_ear ind_group occupation_main tenure_main exper wpfinwgt disab esr partner_work single_work  child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw disab_ss imp_main h_povd caidcov h_np u_comp gov_pension retird soc_sec_inc
}

**Identify the wage income from spouse (tax purposes)**
gen reference=.
replace reference=1 if rrp==1 | rrp==2
replace reference=2 if rrp==3
replace reference=3 if rrp>3 & rrp!=.

*Consider nominal earnings (by firm) of main reference in the household**
bysort su_id h_add panel_year year month firm: gen nomearn_main_hh=nomearn if reference==1
bysort su_id h_add panel_year year month: egen mnomearn_main_hh=max(nomearn_main_hh) 
drop nomearn_main_hh 
rename mnomearn_main_hh nomearn_main_hh

*Consider nominal earnings (by firm) of spouse in the household**
bysort su_id h_add panel_year year month firm: gen nomearn_spouse_hh=nomearn if reference==2
bysort su_id h_add panel_year year month: egen mnomearn_spouse_hh=max(nomearn_spouse_hh) 
drop nomearn_spouse_hh 
rename mnomearn_spouse_hh nomearn_spouse_hh

**do we observe all months of a quarter (year)?
egen obs_quar = sum(id!="."), by(id year quarter)
replace obs_quar = obs_quar==3
drop if obs_quar!=1
drop obs_quar

**Keep old id for merging the yearly data with the quarterly data when doing the probits**
format %16.0g su_id
gen old_id=.
format %16.0g old_id
recast double old_id
replace old_id=su_id

cap drop id
egen id = group(old_id pp_entry pp_pnum panel_year)
tostring id, replace


egen obs_quar = sum(id!="."), by(old_id pp_entry pp_pnum panel_year year quarter)
egen emp = sum(firm!=.), by(old_id pp_entry pp_pnum panel_year year quarter)
*1 is always employed
replace emp = emp/obs_quar
*2 counted as employed but no jtj
replace emp = 2 if emp>=0.5 & emp<1
*3 unemployed
replace emp = 3 if emp<0.5 

cap drop index
*in case a job to job transition took place, check whether worker was unemployed between
sort id year month
by id: gen jtj = firm-firm[_n-1]
replace jtj = jtj!=0
gen index=0
replace index=1 if jtj==1 & esr>=1 & esr<=4
sort id year month
by id: replace index=1 if jtj[_n-1]==1 & esr>=1 & esr<=4
sort id year quarter
by id year quarter: egen index2 = max(index)
replace emp=1 if emp==2 & index2==1
drop index index2
/*
**IDENTIFY JOB TO JOB TRANSITIONS WITHOUT UNEMPLOYMENT SPELLS WHICH ARE ACROSS QUARTERS*
cap drop time
sort year month
egen time=group(year month)
sort id year month
gen id2=id
destring id2, replace
xtset id2 time
gen jtj_noeue=.
**To get jtj without unemployment it necessarily needs to work in the last month of quarter n and first month of quarter n+1**
**Otherwise it is EUE**
replace jtj_noeue=1 if esr>=1 & esr<=4 & L.esr>=1 & L.esr<=4 & firm!=L.firm & quarter!=L.quarter
*/
egen lout = sum(esr==8), by(old_id pp_entry pp_pnum panel_year year quarter)
*1 is always out of labor force
replace lout = lout/obs_quar
replace lout = 0 if lout<1
drop obs_quar status

gen obs_firm=1

di "Number of observations before collapsing"
count if year!=.
if (`x'==1) {
collapse (sum) hours_m realearn nomearn hh_inc hh_ear hh_tra pp_ear obs_firm weekss_main u_comp gov_pension soc_sec_inc (mean) avg_nomearn=nomearn nomearn_main_hh nomearn_spouse_hh (median)  imp_main pp_wave child_male sex emp  partner_work single_work lout grades age white married f_oklt18 h_tenur h_metro tenure_main exper disab_ss wpfinwgt cpi disab real_net_worth hhtwlth hhscdbt hhusdbt hhdebt hhtnw caidcov h_np (first) id su_id reference h_add region ind_group class_worker_main occupation_main h_povd state retird, by(old_id pp_entry pp_pnum panel_year year quarter firm)
}
if (`x'==2) {
collapse (sum) hours_m realearn nomearn hh_inc hh_ear hh_tra pp_ear obs_firm weekss_main u_comp gov_pension soc_sec_inc (mean) avg_nomearn=nomearn nomearn_main_hh nomearn_spouse_hh (median)  imp_main pp_wave child_male sex emp  partner_work single_work lout grades age white married f_oklt18 h_tenur h_metro tenure_main exper disab_ss wpfinwgt cpi disab real_net_worth hhtwlth hhscdbt hhusdbt hhdebt hhtnw caidcov h_np (first) id su_id reference h_add region ind_group class_worker_main occupation_main h_povd state retird, by(old_id pp_entry pp_pnum panel_year year quarter firm)
}
if (`x'==3) {
collapse (sum) hours_m realearn nomearn hh_inc hh_ear hh_tra pp_ear obs_firm weekss_main u_comp gov_pension soc_sec_inc (mean) avg_nomearn=nomearn nomearn_main_hh nomearn_spouse_hh (median)  imp_main pp_wave child_male sex emp  partner_work single_work lout grades age white married f_oklt18 h_tenur h_metro tenure_main exper disab_ss wpfinwgt cpi disab real_net_worth hhtwlth hhscdbt hhusdbt hhdebt hhtnw caidcov h_np (first) id su_id reference h_add region ind_group class_worker_main occupation_main h_povd state retird, by(old_id pp_entry pp_pnum panel_year year quarter firm)
}

di "Number of observations after collapsing"
count if year!=.

**I get some cases of waves 1.5, 2.5, 3.5...Assign randomly 50% to wave 1 and 50% to wave 2 for the case of 1.5 for example
gen pp_wave2=.
replace pp_wave2=pp_wave if pp_wave==1 | pp_wave==2 | pp_wave==3 |  pp_wave==4 |  pp_wave==5 |  pp_wave==6 |  pp_wave==7 |  pp_wave==8 |  pp_wave==9 |  pp_wave==10 |  pp_wave==11 |  pp_wave==12 |  pp_wave==13 |  pp_wave==14 |  pp_wave==15 |  pp_wave==16 
set seed 1234
bysort su_id pp_entry pp_pnum panel_year year quarter firm: gen random_number_wave=runiform()
replace pp_wave2=ceil(pp_wave) if random_number_wave>0.5 & (pp_wave==1.5 | pp_wave==2.5 | pp_wave==3.5 |  pp_wave==4.5 |  pp_wave==5.5 |  pp_wave==6.5 |  pp_wave==7.5 |  pp_wave==8.5 |  pp_wave==9.5 |  pp_wave==10.5 |  pp_wave==11.5 |  pp_wave==12.5 |  pp_wave==13.5 |  pp_wave==14.5 |  pp_wave==15.5 |  pp_wave==16.5) 
replace pp_wave2=floor(pp_wave) if random_number_wave<=0.5 & (pp_wave==1.5 | pp_wave==2.5 | pp_wave==3.5 |  pp_wave==4.5 |  pp_wave==5.5 |  pp_wave==6.5 |  pp_wave==7.5 |  pp_wave==8.5 |  pp_wave==9.5 |  pp_wave==10.5 |  pp_wave==11.5 |  pp_wave==12.5 |  pp_wave==13.5 |  pp_wave==14.5 |  pp_wave==15.5 |  pp_wave==16.5) 
replace pp_wave2=round(pp_wave) if pp_wave2==.
drop pp_wave 
rename pp_wave2 pp_wave
replace grades=round(grades)
replace quarter=round(quarter)
replace age=round(age)
replace sex=ceil(sex)
replace imp_main=ceil(imp_main)

gen emp2=.
replace emp2=emp if emp==1 | emp==2 | emp==3
replace emp2=floor(emp) if (1<emp<1.5) | (2<emp<2.5) 
replace emp2=ceil(emp) if (1.5<emp<2) | (2.5<emp<3) 
replace emp2=floor(emp) if random_number_wave<=0.5 & (emp==1.5 | emp==2.5)
replace emp2=ceil(emp) if random_number_wave>0.5 & (emp==1.5 | emp==2.5)
drop emp
rename emp2 emp

foreach var in partner_work single_work disab disab_ss caidcov{
gen `var'2=.
replace `var'2=`var' if `var'==0 | `var'==1
replace `var'2=floor(`var') if 0<`var'<0.5 
replace `var'2=ceil(`var') if 0.5<`var'<1 
replace `var'2=floor(`var') if random_number_wave<=0.5 & `var'==0.5
replace `var'2=ceil(`var') if random_number_wave>0.5 & `var'==0.5
drop `var'
rename `var'2 `var'
}

replace white=ceil(white)
replace married=ceil(married)
replace f_oklt18=ceil(f_oklt18)
replace region=ceil(region)
replace h_tenur=ceil(h_tenur)
replace ind_group=ceil(ind_group)
replace occupation_main=ceil(occupation_main)
replace class_worker_main=ceil(class_worker_main)
replace state=ceil(state)
replace child_male=ceil(child_male)
replace h_np=ceil(h_np)

gen  q_hwage=realearn/hours_m
gen  nom_q_hwage=nomearn/hours_m
gen q_earn=realearn 
gen q_hours=hours_m 





**Get average hours at the week**
gen weekly_hours=hours_m/weekss_main

egen y_hours   =sum(hours_m), by(id firm year)
egen y_earnings=sum(realearn), by(id firm year)
gen  y_hwage   =y_earnings/y_hours


sort year
merge year using federal_tax_panel_married
tab _merge
cap drop _merge
sort year 
merge year using federal_tax_panel_single
tab _merge
cap drop _merge


di "Number of observations before keeping main job"
count if year!=.

***********If the person has 2+ jobs/or was Employed and Unemployed in a given quarter, select the "main" one	************
*Take the case with the maximum number of months within the quarter
bysort old_id pp_entry pp_pnum panel_year year quarter: gen count=_N
egen my=max(obs_firm),by(su_id pp_entry pp_pnum panel_year year quarter)
drop if my>obs_firm & count>1
cap drop count my
*Conditional on employment. Consider the person to be employed if the amount of months is the same between employed and unemployed
bysort old_id pp_entry pp_pnum panel_year year quarter: gen count=_N
drop if count>1 & emp<=2 & firm==. 
drop count 
*For those cases of employed in two or more jobs and if the months employed coincide, take the job with higher earnings
bysort old_id pp_entry pp_pnum panel_year year quarter: gen count=_N
bysort old_id pp_entry pp_pnum panel_year year quarter: egen max_q=max(q_earn)
drop if max_q>q_earn & count>1 & q_earn!=. & max_q!=.
*drop if max_qhwage>q_hwage & count>1 & no_work==0 & q_hwage!=. & max_qhwage!=.
cap drop count max_q
*Finally, if earnings are the same, take the first job
bysort old_id pp_entry pp_pnum panel_year year quarter: gen count=_N
bysort old_id pp_entry pp_pnum panel_year year quarter: gen count2=_n
drop if count>1 & count2>1
drop count count2

di "Number of observations after keeping main job"
count if year!=.



***GET DATA FROM TAXSIM. THINK HOW TO RESTRUCTURE IT**
**Get measure of monthly average earnings and translate it into yearly earnings**
gen year_earn=avg_nomearn*12
gen year_earn_main_hh=nomearn_main_hh*12
gen year_earn_spouse=nomearn_spouse_hh*12

**Create variables to be used in taxsim. Taxes are at Household Level**

gen depchild=f_oklt18
gen depx=depchild
gen mstat=2 if married==1
replace mstat=1 if married==0
**If the person is not the main in the household nor the secondary tax payer, assume same treatment as primary tax payer**
**wage income of taxpayer**
gen pwages=year_earn 
**Income of Wife if person is the main in household**
gen swages=year_earn_spouse if reference==1
**Income of Husband if person is the Wife**
replace swages=year_earn_main_hh if reference==2
replace pwages=0 if pwages==.
replace swages=0 if swages==.

**Create state data from taxsim**
gen state_tax=.
replace state_tax=1 if state==1 & panel_year==84
replace state_tax=3 if state==4 & panel_year==84
replace state_tax=4 if state==5 & panel_year==84
replace state_tax=5 if state==6 & panel_year==84
replace state_tax=6 if state==8 & panel_year==84
replace state_tax=7 if state==9 & panel_year==84
replace state_tax=8 if state==10 & panel_year==84
replace state_tax=9 if state==12 & panel_year==84
replace state_tax=10 if state==13 & panel_year==84
replace state_tax=11 if state==15 & panel_year==84
replace state_tax=12 if state==58 & panel_year==84
replace state_tax=13 if state==17 & panel_year==84
replace state_tax=14 if state==18 & panel_year==84
replace state_tax=15 if state==19 & panel_year==84
replace state_tax=16 if state==20 & panel_year==84
replace state_tax=17 if state==21 & panel_year==84
replace state_tax=18 if state==22 & panel_year==84
replace state_tax=19 if state==23 & panel_year==84
replace state_tax=20 if state==24 & panel_year==84
replace state_tax=21 if state==25 & panel_year==84
replace state_tax=22 if state==26 & panel_year==84
replace state_tax=23 if state==27 & panel_year==84
replace state_tax=24 if state==57 & panel_year==84
replace state_tax=25 if state==29 & panel_year==84
replace state_tax=26 if state==30 & panel_year==84
replace state_tax=27 if state==31 & panel_year==84
replace state_tax=28 if state==32 & panel_year==84
replace state_tax=29 if state==33 & panel_year==84
replace state_tax=30 if state==34 & panel_year==84
replace state_tax=31 if state==58 & panel_year==84
replace state_tax=32 if state==36 & panel_year==84
replace state_tax=33 if state==37 & panel_year==84
replace state_tax=34 if state==38 & panel_year==84
replace state_tax=35 if state==39 & panel_year==84
replace state_tax=36 if state==40 & panel_year==84
replace state_tax=37 if state==41 & panel_year==84
replace state_tax=38 if state==42 & panel_year==84
replace state_tax=39 if state==44 & panel_year==84
replace state_tax=40 if state==45 & panel_year==84
replace state_tax=41 if state==58 & panel_year==84
replace state_tax=42 if state==47 & panel_year==84
replace state_tax=43 if state==48 & panel_year==84
replace state_tax=44 if state==49 & panel_year==84
replace state_tax=45 if state==50 & panel_year==84
replace state_tax=46 if state==51 & panel_year==84
replace state_tax=47 if state==53 & panel_year==84
replace state_tax=48 if state==11 & panel_year==84
replace state_tax=49 if state==57 & panel_year==84
replace state_tax=50 if state==55 & panel_year==84
replace state_tax=51 if state==58 & panel_year==84
replace state_tax=41 if state==62 & panel_year==84
replace state_tax=45 if state==61 & panel_year==84
replace state_tax=2 if state==2 & panel_year==84
replace state_tax=24 if state==28 & panel_year==84
replace state_tax=31 if state==35 & panel_year==84

replace state_tax=1 if state==1 & panel_year>=85 & panel_year<=93
replace state_tax=2 if state==63 & panel_year>=85 & panel_year<=93
replace state_tax=3 if state==4 & panel_year>=85 & panel_year<=93
replace state_tax=4 if state==5 & panel_year>=85 & panel_year<=93
replace state_tax=5 if state==6 & panel_year>=85 & panel_year<=93
replace state_tax=6 if state==8 & panel_year>=85 & panel_year<=93
replace state_tax=7 if state==9 & panel_year>=85 & panel_year<=93
replace state_tax=8 if state==10 & panel_year>=85 & panel_year<=93
replace state_tax=9 if state==12 & panel_year>=85 & panel_year<=93
replace state_tax=10 if state==13 & panel_year>=85 & panel_year<=93
replace state_tax=11 if state==15 & panel_year>=85 & panel_year<=93
replace state_tax=12 if state==63 & panel_year>=85 & panel_year<=93
replace state_tax=13 if state==17 & panel_year>=85 & panel_year<=93
replace state_tax=14 if state==18 & panel_year>=85 & panel_year<=93
replace state_tax=15 if state==62 & panel_year>=85 & panel_year<=93
replace state_tax=16 if state==20 & panel_year>=85 & panel_year<=93
replace state_tax=17 if state==21 & panel_year>=85 & panel_year<=93
replace state_tax=18 if state==22 & panel_year>=85 & panel_year<=93
replace state_tax=19 if state==61 & panel_year>=85 & panel_year<=93
replace state_tax=20 if state==24 & panel_year>=85 & panel_year<=93
replace state_tax=21 if state==25 & panel_year>=85 & panel_year<=93
replace state_tax=22 if state==26 & panel_year>=85 & panel_year<=93
replace state_tax=23 if state==27 & panel_year>=85 & panel_year<=93
replace state_tax=24 if state==28 & panel_year>=85 & panel_year<=93
replace state_tax=25 if state==29 & panel_year>=85 & panel_year<=93
replace state_tax=26 if state==63 & panel_year>=85 & panel_year<=93
replace state_tax=27 if state==31 & panel_year>=85 & panel_year<=93
replace state_tax=28 if state==32 & panel_year>=85 & panel_year<=93
replace state_tax=29 if state==33 & panel_year>=85 & panel_year<=93
replace state_tax=30 if state==34 & panel_year>=85 & panel_year<=93
replace state_tax=31 if state==35 & panel_year>=85 & panel_year<=93
replace state_tax=32 if state==36 & panel_year>=85 & panel_year<=93
replace state_tax=33 if state==37 & panel_year>=85 & panel_year<=93
replace state_tax=34 if state==62 & panel_year>=85 & panel_year<=93
replace state_tax=35 if state==39 & panel_year>=85 & panel_year<=93
replace state_tax=36 if state==40 & panel_year>=85 & panel_year<=93
replace state_tax=37 if state==41 & panel_year>=85 & panel_year<=93
replace state_tax=38 if state==42 & panel_year>=85 & panel_year<=93
replace state_tax=39 if state==44 & panel_year>=85 & panel_year<=93
replace state_tax=40 if state==45 & panel_year>=85 & panel_year<=93
replace state_tax=41 if state==62 & panel_year>=85 & panel_year<=93
replace state_tax=42 if state==47 & panel_year>=85 & panel_year<=93
replace state_tax=43 if state==48 & panel_year>=85 & panel_year<=93
replace state_tax=44 if state==49 & panel_year>=85 & panel_year<=93
replace state_tax=45 if state==61 & panel_year>=85 & panel_year<=93
replace state_tax=46 if state==51 & panel_year>=85 & panel_year<=93
replace state_tax=47 if state==53 & panel_year>=85 & panel_year<=93
replace state_tax=48 if state==11 & panel_year>=85 & panel_year<=93
replace state_tax=49 if state==54 & panel_year>=85 & panel_year<=93
replace state_tax=50 if state==55 & panel_year>=85 & panel_year<=93
replace state_tax=51 if state==63 & panel_year>=85 & panel_year<=93



replace state_tax=1 if state==1 & panel_year>=96 & panel_year<=2001
replace state_tax=2 if state==2 & panel_year>=96 & panel_year<=2001
replace state_tax=3 if state==4 & panel_year>=96 & panel_year<=2001
replace state_tax=4 if state==5 & panel_year>=96 & panel_year<=2001
replace state_tax=5 if state==6 & panel_year>=96 & panel_year<=2001
replace state_tax=6 if state==8 & panel_year>=96 & panel_year<=2001
replace state_tax=7 if state==9 & panel_year>=96 & panel_year<=2001
replace state_tax=8 if state==10 & panel_year>=96 & panel_year<=2001
replace state_tax=9 if state==12 & panel_year>=96 & panel_year<=2001
replace state_tax=10 if state==13 & panel_year>=96 & panel_year<=2001
replace state_tax=11 if state==15 & panel_year>=96 & panel_year<=2001
replace state_tax=12 if state==16 & panel_year>=96 & panel_year<=2001
replace state_tax=13 if state==17 & panel_year>=96 & panel_year<=2001
replace state_tax=14 if state==18 & panel_year>=96 & panel_year<=2001
replace state_tax=15 if state==19 & panel_year>=96 & panel_year<=2001
replace state_tax=16 if state==20 & panel_year>=96 & panel_year<=2001
replace state_tax=17 if state==21 & panel_year>=96 & panel_year<=2001
replace state_tax=18 if state==22 & panel_year>=96 & panel_year<=2001
replace state_tax=19 if state==61 & panel_year>=96 & panel_year<=2001
replace state_tax=20 if state==24 & panel_year>=96 & panel_year<=2001
replace state_tax=21 if state==25 & panel_year>=96 & panel_year<=2001
replace state_tax=22 if state==26 & panel_year>=96 & panel_year<=2001
replace state_tax=23 if state==27 & panel_year>=96 & panel_year<=2001
replace state_tax=24 if state==28 & panel_year>=96 & panel_year<=2001
replace state_tax=25 if state==29 & panel_year>=96 & panel_year<=2001
replace state_tax=26 if state==30 & panel_year>=96 & panel_year<=2001
replace state_tax=27 if state==31 & panel_year>=96 & panel_year<=2001
replace state_tax=28 if state==32 & panel_year>=96 & panel_year<=2001
replace state_tax=29 if state==33 & panel_year>=96 & panel_year<=2001
replace state_tax=30 if state==34 & panel_year>=96 & panel_year<=2001
replace state_tax=31 if state==35 & panel_year>=96 & panel_year<=2001
replace state_tax=32 if state==36 & panel_year>=96 & panel_year<=2001
replace state_tax=33 if state==37 & panel_year>=96 & panel_year<=2001
replace state_tax=34 if state==62 & panel_year>=96 & panel_year<=2001
replace state_tax=35 if state==39 & panel_year>=96 & panel_year<=2001
replace state_tax=36 if state==40 & panel_year>=96 & panel_year<=2001
replace state_tax=37 if state==41 & panel_year>=96 & panel_year<=2001
replace state_tax=38 if state==42 & panel_year>=96 & panel_year<=2001
replace state_tax=39 if state==44 & panel_year>=96 & panel_year<=2001
replace state_tax=40 if state==45 & panel_year>=96 & panel_year<=2001
replace state_tax=41 if state==62 & panel_year>=96 & panel_year<=2001
replace state_tax=42 if state==47 & panel_year>=96 & panel_year<=2001
replace state_tax=43 if state==48 & panel_year>=96 & panel_year<=2001
replace state_tax=44 if state==49 & panel_year>=96 & panel_year<=2001
replace state_tax=45 if state==61 & panel_year>=96 & panel_year<=2001
replace state_tax=46 if state==51 & panel_year>=96 & panel_year<=2001
replace state_tax=47 if state==53 & panel_year>=96 & panel_year<=2001
replace state_tax=48 if state==11 & panel_year>=96 & panel_year<=2001
replace state_tax=49 if state==54 & panel_year>=96 & panel_year<=2001
replace state_tax=50 if state==55 & panel_year>=96 & panel_year<=2001
replace state_tax=51 if state==62 & panel_year>=96 & panel_year<=2001


replace state_tax=1 if state==1 & panel_year>=2004
replace state_tax=2 if state==2 & panel_year>=2004
replace state_tax=3 if state==4 & panel_year>=2004
replace state_tax=4 if state==5 & panel_year>=2004
replace state_tax=5 if state==6 & panel_year>=2004
replace state_tax=6 if state==8 & panel_year>=2004
replace state_tax=7 if state==9 & panel_year>=2004
replace state_tax=8 if state==10 & panel_year>=2004
replace state_tax=9 if state==12 & panel_year>=2004
replace state_tax=10 if state==13 & panel_year>=2004
replace state_tax=11 if state==15 & panel_year>=2004
replace state_tax=12 if state==16 & panel_year>=2004
replace state_tax=13 if state==17 & panel_year>=2004
replace state_tax=14 if state==18 & panel_year>=2004
replace state_tax=15 if state==19 & panel_year>=2004
replace state_tax=16 if state==20 & panel_year>=2004
replace state_tax=17 if state==21 & panel_year>=2004
replace state_tax=18 if state==22 & panel_year>=2004
replace state_tax=19 if state==23 & panel_year>=2004
replace state_tax=20 if state==24 & panel_year>=2004
replace state_tax=21 if state==25 & panel_year>=2004
replace state_tax=22 if state==26 & panel_year>=2004
replace state_tax=23 if state==27 & panel_year>=2004
replace state_tax=24 if state==28 & panel_year>=2004
replace state_tax=25 if state==29 & panel_year>=2004
replace state_tax=26 if state==30 & panel_year>=2004
replace state_tax=27 if state==31 & panel_year>=2004
replace state_tax=28 if state==32 & panel_year>=2004
replace state_tax=29 if state==33 & panel_year>=2004
replace state_tax=30 if state==34 & panel_year>=2004
replace state_tax=31 if state==35 & panel_year>=2004
replace state_tax=32 if state==36 & panel_year>=2004
replace state_tax=33 if state==37 & panel_year>=2004
replace state_tax=34 if state==38 & panel_year>=2004
replace state_tax=35 if state==39 & panel_year>=2004
replace state_tax=36 if state==40 & panel_year>=2004
replace state_tax=37 if state==41 & panel_year>=2004
replace state_tax=38 if state==42 & panel_year>=2004
replace state_tax=39 if state==44 & panel_year>=2004
replace state_tax=40 if state==45 & panel_year>=2004
replace state_tax=41 if state==46 & panel_year>=2004
replace state_tax=42 if state==47 & panel_year>=2004
replace state_tax=43 if state==48 & panel_year>=2004
replace state_tax=44 if state==49 & panel_year>=2004
replace state_tax=45 if state==50 & panel_year>=2004
replace state_tax=46 if state==51 & panel_year>=2004
replace state_tax=47 if state==53 & panel_year>=2004
replace state_tax=48 if state==11 & panel_year>=2004
replace state_tax=49 if state==54 & panel_year>=2004
replace state_tax=50 if state==55 & panel_year>=2004
replace state_tax=51 if state==56 & panel_year>=2004

**Rename state data to import at taxsim**
rename state state_sipp
rename state_tax state

drop if mstat==. 
taxsim9,replace

**Assign taxes to be paid based on the share of household income that corresponds to each person in household**
bysort old_id h_add panel_year year quarter: egen total_earn_hh=sum(year_earn) 
gen share_inc_hh=year_earn/total_earn_hh

**Get quarterly tax by person** 
gen total_tax_qt=share_inc_hh*(fiitax+siitax+fica)/4
gen after_tax_earn=nomearn-total_tax_qt
gen real_after_tax_q_hw= (after_tax_earn/(cpi/100))/q_hours

***If using after tax earnings, use also for qhwage!***
gen  q_hwage_tax=real_after_tax_q_hw
gen  nom_q_hwage_tax=real_after_tax_q_hw*(cpi/100)
gen q_earn_tax=after_tax_earn 

drop state
rename state_sipp state


sort old_id pp_entry pp_pnum panel_year year quarter
qby old_id pp_entry pp_pnum panel_year:gen g=ln(q_hwage)-ln(q_hwage[_n-1]) if quarter-quarter[_n-1]==1 & quarter!=1 & year==year[_n-1]	
qby old_id pp_entry pp_pnum panel_year:replace g=ln(q_hwage)-ln(q_hwage[_n-1]) if quarter-quarter[_n-1]==-3 & quarter==1	& year==year[_n-1]+1 

qby old_id pp_entry pp_pnum panel_year: gen gE=ln(q_earn)-ln(q_earn[_n-1]) if quarter-quarter[_n-1]==1 & quarter!=1 & year==year[_n-1]	
qby old_id pp_entry pp_pnum panel_year: replace gE=ln(q_earn)-ln(q_earn[_n-1]) if quarter-quarter[_n-1]==-3 & quarter==1	& year==year[_n-1]+1 

cap drop time
egen time = group(year quarter)

qby old_id pp_entry pp_pnum panel_year: gen     M=1 if g!=. & firm!=firm[_n-1] & time-time[_n-1]==1 				
qby old_id pp_entry pp_pnum panel_year: replace M=0 if g!=. & firm==firm[_n-1] & time-time[_n-1]==1		

qby old_id pp_entry pp_pnum panel_year: gen     M_2=1 if g!=. & firm!=firm[_n-1] & time-time[_n-1]==1		
qby old_id pp_entry pp_pnum panel_year: replace M_2=2 if g!=. & firm!=firm[_n-1] & emp!=1  & time-time[_n-1]==1	 
qby old_id pp_entry pp_pnum panel_year: replace M_2=2 if g!=. & firm!=firm[_n-1] & emp[_n-1]!=1  & time-time[_n-1]==1	 
qby old_id pp_entry pp_pnum panel_year: replace M_2=0 if g!=. & firm==firm[_n-1] & time-time[_n-1]==1


cap drop time
gen e_over_h=log(q_hwage)

gen poverty = (hh_ear-pp_ear)<(h_povd/4)

gen oth_inc=(hh_inc-hh_ear-hh_tra)/(cpi/100)	
replace oth_inc=0 if oth_inc<0
gen oth_ear=(hh_ear-pp_ear)/(cpi/100)
replace oth_ear=0 if oth_ear<0

gen publ=ind_group==7
replace f_oklt18=4 if f_oklt18>4 & f_oklt18!=.

**Identify job movers at other members in the household
cap drop aux
gen aux=1 if M==1
replace aux=0 if M==0
bysort su_id h_add year quarter: egen total_movers_hh=total(aux)
gen total_movers_hh2=total_movers_hh-aux

gen partner_move_job=0
*Case person working
replace partner_move_job=1 if total_movers_hh2!=0  & total_movers_hh2!=. 
*Case person not working
replace partner_move_job=1 if total_movers_hh!=0  & total_movers_hh!=. & M==.


drop if sex==2
save data2_sipp_new_part_all_noimp`x'_qt,replace


clear
}


***************************************************************
*   APPEND BIG DATASETS
*
***************************************************************


use data2_sipp_new_part_all_noimp1_qt, clear
keep id old_id su_id pp_entry pp_pnum pp_wave year quarter firm q_hwage q_hours q_earn g gE M M_2 oth_inc oth_ear hh_inc hh_ear hh_tra pp_ear obs_firm panel_year sex emp lout grades age white married f_oklt18 publ region state h_tenur h_metro ind_group occupation_main class_worker_main tenure_main exper wpfinwgt cpi disab lout nom_q_hwage partner_work single_work partner_move_job child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw nomearn_main_hh nomearn_spouse_hh weekly_hours disab_ss imp_main poverty h_povd caidcov retird h_np u_comp gov_pension real_after_tax_q_hw q_earn_tax real_net_worth soc_sec_inc
save data3_sipp_new_part_all_noimp1_qt, replace

use data2_sipp_new_part_all_noimp2_qt, clear
keep id old_id su_id pp_entry pp_pnum pp_wave year quarter firm q_hwage q_hours q_earn g gE M M_2 oth_inc oth_ear hh_inc hh_ear hh_tra pp_ear obs_firm panel_year sex emp lout grades age white married f_oklt18 publ region state h_tenur h_metro ind_group occupation_main class_worker_main tenure_main exper wpfinwgt cpi disab lout nom_q_hwage partner_work single_work partner_move_job child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw nomearn_main_hh nomearn_spouse_hh weekly_hours disab_ss imp_main poverty h_povd caidcov retird h_np u_comp gov_pension real_after_tax_q_hw q_earn_tax real_net_worth soc_sec_inc
save data3_sipp_new_part_all_noimp2_qt, replace

use data2_sipp_new_part_all_noimp3_qt, clear
keep id old_id su_id pp_entry pp_pnum pp_wave year quarter firm q_hwage q_hours q_earn g gE M M_2 oth_inc oth_ear hh_inc hh_ear hh_tra pp_ear obs_firm panel_year sex emp lout grades age white married f_oklt18 publ region state h_tenur h_metro ind_group occupation_main class_worker_main tenure_main exper wpfinwgt cpi disab lout nom_q_hwage partner_work single_work partner_move_job child_male hhtwlth hhscdbt hhusdbt hhdebt hhtnw nomearn_main_hh nomearn_spouse_hh weekly_hours disab_ss imp_main poverty h_povd caidcov retird h_np u_comp gov_pension real_after_tax_q_hw q_earn_tax real_net_worth soc_sec_inc
save data3_sipp_new_part_all_noimp3_qt, replace

use data3_sipp_new_part_all_noimp1_qt, clear
append using data3_sipp_new_part_all_noimp2_qt, force
append using data3_sipp_new_part_all_noimp3_qt, force


***Create new id now, because it was being created before by panel and group**
egen id2=group(old_id pp_entry pp_pnum panel_year)
drop id
rename id2 id
format %16.0g id
recast double id
tostring id, replace

******************************************************************************************************************************
******************************************MERGE WITH UNEMP HOUSING UI, create variables in differences************************
******************************************************************************************************************************

**DROP INCONSISTENT STATE NUMBERS**
drop if state==2 & panel_year<=93
drop if state==19 & panel_year<=93
drop if state==23 & panel_year<=93
drop if state==30 & panel_year<=93
drop if state==38 & panel_year<=93
drop if state==46 & panel_year<=93
drop if state==50 & panel_year<=93
drop if state==52 & panel_year<=93

drop if state==7 & panel_year>93 & panel_year<=2001
drop if state==23 & panel_year>93 & panel_year<=2001
drop if state==50 & panel_year>93 & panel_year<=2001
drop if state==43 & panel_year>2001 & panel_year!=.


sort year quarter state 
merge year quarter state using ui_altsipp2_setone 

foreach var in ui uirank uirank2 {
replace `var'=. if panel_year>93 & panel_year!=.
}
rename ui ui_1
rename uirank uirank_1
rename uirank2 uirank2_1

tab _merge if panel_year<=93
drop if _merge!=3 & panel_year<=93
drop _merge

sort year quarter state 
merge year quarter state using ui_altsipp2_settwo 

foreach var in ui uirank uirank2 {
replace `var'=. if (panel_year<=93 | panel_year>2001) & panel_year!=.
}

rename ui ui_2
rename uirank uirank_2
rename uirank2 uirank2_2

tab _merge if panel_year>93 & panel_year<=2001
drop if _merge!=3 & panel_year>93 & panel_year<=2001
drop _merge

sort year quarter state 
merge year quarter state using ui_altsipp2_setthree 

foreach var in ui uirank uirank2 {
replace `var'=. if panel_year<2004
}
rename ui ui_3
rename uirank uirank_3
rename uirank2 uirank2_3

tab _merge if panel_year>2001 & panel_year!=.

drop if _merge!=3 & panel_year>2001 & panel_year!=.
drop _merge

gen ui=.
gen uirank=.
gen uirank2=.

foreach var in ui uirank uirank2 {
replace `var'=`var'_1 if panel_year<=93
replace `var'=`var'_2 if panel_year>93 & panel_year<=2001
replace `var'=`var'_3 if panel_year>2001
}

cap drop ui_1 ui_2 ui_3
cap drop uirank_1 uirank_2 uirank_3 
cap drop uirank2_1 uirank2_2 uirank2_3 
cap drop unemp_rate_1 unemp_rate_2 unemp_rate_3 

**Merge by sets of panels (state change)

sort year quarter state 
merge year quarter state using unemp_rate_setone 

foreach var in unemp_rate {
replace `var'=. if panel_year>93 & panel_year!=.
}
rename unemp_rate unemp_rate_1

tab _merge if panel_year<=93
drop if _merge!=3 & panel_year<=93
drop _merge

sort year quarter state 
merge year quarter state using unemp_rate_settwo 

foreach var in unemp_rate {
replace `var'=. if panel_year<=93 | panel_year>2001
}

rename unemp_rate unemp_rate_2

tab _merge if panel_year>93 & panel_year<=2001
drop if _merge!=3 & panel_year>93 & panel_year<=2001
drop _merge

sort year quarter state 
merge year quarter state using unemp_rate_setthree 

foreach var in unemp_rate {
replace `var'=. if panel_year<2004
}
rename unemp_rate unemp_rate_3

tab _merge if panel_year>2001 & panel_year!=.
drop if _merge!=3 & panel_year>2001 & panel_year!=.
drop _merge

gen unemp_rate=.

foreach var in unemp_rate {
replace `var'=`var'_1 if panel_year<=93 & panel_year!=.
replace `var'=`var'_2 if panel_year>93 & panel_year<=2001 & panel_year!=.
replace `var'=`var'_3 if panel_year>2001 & panel_year!=.
}


 
sort year state 
merge year state using minimum_wage_setone 

replace min_wage=. if panel_year>93 & panel_year!=.
rename min_wage min_wage_1

tab _merge if panel_year<=93
drop if _merge!=3 & panel_year<=93
drop _merge

sort year state 
merge year state using minimum_wage_settwo

replace min_wage=. if panel_year<=93 | panel_year>2001

rename min_wage min_wage_2

tab _merge if panel_year>93 & panel_year<=2001
drop if _merge!=3 & panel_year>93 & panel_year<=2001
drop _merge

sort year state 
merge year state using minimum_wage_setthree 

replace min_wage=. if panel_year<2004
rename min_wage min_wage_3

tab _merge if panel_year>2001 & panel_year!=.
drop if _merge!=3 & panel_year>2001 & panel_year!=.
drop _merge

gen min_wage=.

foreach var in min_wage {
replace `var'=`var'_1 if panel_year<=93 & panel_year!=.
replace `var'=`var'_2 if panel_year>93 & panel_year<=2001 & panel_year!=.
replace `var'=`var'_3 if panel_year>2001 & panel_year!=.
}


**Merge by sets of panels (state change)
foreach y in min max {

sort year state 
merge year state using `y'_state_tax_setone 

foreach var in `y'_state_tax {
replace `var'=. if panel_year>93 & panel_year!=.
}
rename `y'_state_tax `y'_state_tax_1

tab _merge if panel_year<=93
drop if _merge!=3 & panel_year<=93
drop _merge

sort year state 
merge year state using `y'_state_tax_settwo 

foreach var in `y'_state_tax {
replace `var'=. if panel_year<=93 | panel_year>2001
}

rename `y'_state_tax `y'_state_tax_2

tab _merge if panel_year>93 & panel_year<=2001
drop if _merge!=3 & panel_year>93 & panel_year<=2001
drop _merge

sort year state 
merge year state using `y'_state_tax_setthree 

foreach var in `y'_state_tax {
replace `var'=. if panel_year<2004
}
rename `y'_state_tax `y'_state_tax_3

tab _merge if panel_year>2001 & panel_year!=.
drop if _merge!=3 & panel_year>2001 & panel_year!=.
drop _merge

gen `y'_state_tax=.

foreach var in `y'_state_tax {
replace `var'=`var'_1 if panel_year<=93 & panel_year!=.
replace `var'=`var'_2 if panel_year>93 & panel_year<=2001 & panel_year!=.
replace `var'=`var'_3 if panel_year>2001 & panel_year!=.
}
}


**Merge by sets of panels (state change)
sort year quarter state 
merge year quarter state using house_prices_setone 

foreach var in home_value {
replace `var'=. if panel_year>93 & panel_year!=.
}
rename home_value home_value_1

tab _merge if panel_year<=93
drop if _merge!=3 & panel_year<=93
drop _merge


sort year quarter state 
merge year quarter state using house_prices_settwo 


foreach var in home_value {
replace `var'=. if panel_year<=93 | panel_year>2001
}

rename home_value home_value_2

tab _merge if panel_year>93 & panel_year<=2001
drop if _merge!=3 & panel_year>93 & panel_year<=2001
drop _merge

sort year quarter state 
merge year quarter state using house_prices_setthree 

foreach var in home_value {
replace `var'=. if panel_year<2004
}
rename home_value home_value_3

tab _merge if panel_year>2001 & panel_year!=.
drop if _merge!=3 & panel_year>2001 & panel_year!=.
drop _merge

gen home_value=.

foreach var in home_value {
replace `var'=`var'_1 if panel_year<=93 & panel_year!=.
replace `var'=`var'_2 if panel_year>93 & panel_year<=2001 & panel_year!=.
replace `var'=`var'_3 if panel_year>2001 & panel_year!=.
}




**Drop non-existing id's**
gen aux7=id
destring aux7, replace
drop if aux7==.
cap drop aux7



replace h_metro = h_metro==1
replace f_oklt18 = f_oklt18>2
replace sex=ceil(sex)

***Consider oth_inc in log form to avoid extreme values**
replace oth_inc=log(oth_inc+1)
replace oth_ear=log(oth_ear+1)
replace exper=log(exper+1)
replace tenure_main=log(tenure_main+1)

gen     typefirm=1 if class_worker_main==1
replace typefirm=2 if class_worker_main==2
replace typefirm=3 if typefirm==. & class_worker_main!=0

gen industry=ind_group
egen ind =mode(industry),by(id year quarter firm) min		 	
egen type=mode(typefirm),by(id year quarter firm) min


gen agr =ind==1
gen cons =ind==2
gen manuf=ind==3
gen trade=ind==4
gen fin =ind==5
gen serv =ind==6
cap drop publ
gen publ =ind==7

cap drop notforprof
gen notforprof=type==2


replace home_value=log(home_value)



*************compute by state/year average welfare income****************
gen h_in_pov = (hh_inc-hh_tra)<(h_povd/4)
preserve
keep if sex==1 & h_np>=2 & h_np<=4 & married==1
keep if  year<=1993
keep if h_in_pov==1
gen hh_tra_ave=hh_tra/(cpi/100)
rename caidcov caidcov_ave
collapse (mean) caidcov_ave hh_tra_ave , by(state)
gen perio = 1
sort state perio
save transfer_1, replace
restore
preserve
keep if sex==1 & h_np>=2 & h_np<=4 & married==1
keep if year>=1994 & year<=2003
keep if h_in_pov==1
gen hh_tra_ave=hh_tra/(cpi/100)
rename caidcov caidcov_ave
collapse (mean) caidcov_ave hh_tra_ave , by(state)
set obs 45
replace state = 15 in 45
replace caidcov_ave = 0 in 45
replace hh_tra_ave = 0 in 45
gen perio = 2
sort state perio
save transfer_2, replace
restore
preserve
keep if sex==1 & h_np>=2 & h_np<=4 & married==1
keep if year>=2004 
keep if h_in_pov==1
gen hh_tra_ave=hh_tra/(cpi/100)
rename caidcov caidcov_ave
collapse (mean) caidcov_ave hh_tra_ave , by(state)
set obs 45
replace state = 11 in 45
replace caidcov_ave = 0.088 in 45
replace hh_tra_ave = 21 in 45
gen perio = 3
sort state perio
save transfer_3, replace
restore
preserve
use "transfer_1.dta", clear
merge state perio using "transfer_2.dta"
drop _merge
sort state perio
merge state perio using "transfer_3.dta"
drop _merge
sort perio state
save transfer_all, replace
restore

gen perio = .
replace perio = 1 if  year<=1993
replace perio = 2 if  year>=1994 & year<=2003
replace perio = 3 if  year>=2004 
sort perio state
merge perio state using "transfer_all.dta"
drop _merge perio





cap drop time
egen time=group(year quarter)

tab region,gen(regd)
sort id year quarter firm

 

qby id:gen ind_change_wave=1 if pp_wave!=pp_wave[_n-1] & time[_n]==time[_n-1]+1
replace ind_change_wave=0 if ind_change_wave==.
qby id:gen dsingle_work=single_work-single_work[_n-1] if time[_n]==time[_n-1]+1
qby id:gen dpartner_move_job=partner_move_job-partner_move_job[_n-1] if time[_n]==time[_n-1]+1

qby id:gen dregd1=regd1-regd1[_n-1] if time[_n]==time[_n-1]+1
qby id:gen dregd2=regd2-regd2[_n-1] if time[_n]==time[_n-1]+1
qby id:gen dregd3=regd3-regd3[_n-1] if time[_n]==time[_n-1]+1
qby id:gen dmarr=married-married[_n-1] if time[_n]==time[_n-1]+1
qby id:gen dh_metro=h_metro-h_metro[_n-1] if time[_n]==time[_n-1]+1
qby id:gen lag_ind=ind[_n-1] if time[_n]==time[_n-1]+1
qby id:gen lag_type=type[_n-1] if time[_n]==time[_n-1]+1


gen agr0 =lag_ind==1
gen cons0 =lag_ind==2
gen manuf0=lag_ind==3
gen fin0 =lag_ind==5
gen serv0 =lag_ind==6
gen publ0 =lag_ind==7
gen dagr=agr-agr0
gen dcons=cons-cons0
gen dmanuf=manuf-manuf0
gen dfin=fin-fin0
gen dserv=serv-serv0
gen dpubl=publ-publ0
gen notforprof0=lag_type==2

gen dnotfor=notforprof-notforprof0
qby id: gen dunemp_rate=unemp_rate-unemp_rate[_n-1] if time[_n]==time[_n-1]+1
qby id: gen df_oklt18=f_oklt18-f_oklt18[_n-1] if time[_n]==time[_n-1]+1
qby id: gen dtenure_main=tenure_main-tenure_main[_n-1] if time[_n]==time[_n-1]+1
qby id: gen dh_tenur=h_tenur-h_tenur[_n-1] if time[_n]==time[_n-1]+1
qby id: gen dexper=exper-exper[_n-1] if time[_n]==time[_n-1]+1
qby id: gen doth_ear=oth_ear-oth_ear[_n-1] if time[_n]==time[_n-1]+1
qby id: gen ddisab=disab-disab[_n-1] if time[_n]==time[_n-1]+1
qby id: gen dpartner_work=partner_work-partner_work[_n-1] if time[_n]==time[_n-1]+1
gen dexper2=exper^2-exper[_n-1]^2 if time[_n]==time[_n-1]+1
gen dtenure_main2=tenure_main^2- tenure_main[_n-1]^2 if time[_n]==time[_n-1]+1
gen inter_married_kids=f_oklt18*married


***OCCUPATIONAL CODES*******
gen occ=occupation_main
sort occ
merge occ using occ1980_occ1990dd
rename occ1990dd aux1
drop _merge

sort occ
merge occ using occ1990_occ1990dd
rename occ1990dd aux2
drop _merge

**Take out last zero for occupation 2004-2008**
gen occ2=occ
tostring occ2, replace
gen occ3=substr(occ2,1,1)
destring occ3, replace force
gen occ4=substr(occ2,1,2)
destring occ4, replace
gen occ5=substr(occ2,1,3)
destring occ5, replace
destring occ2, replace
gen occ6=.
replace occ6=occ3 if occ2<100 & occ2>=10
replace occ6=occ4 if occ2<1000 & occ2>=100
replace occ6=occ5 if occ2<10000 & occ2>=1000
drop occ2 occ3 occ4 occ5
rename occ6 occ2
sort occ2
merge occ2 using occ2000_occ1990dd
rename occ1990dd aux3
drop _merge

**Drop non-existing id's**
gen aux7=id
destring aux7, replace
drop if aux7==.
cap drop aux7

*1980 census up to 1992, 1993 starts with 1990, 2004 starts with 2000*

gen occ1990dd=.
replace occ1990dd=aux1 if panel_year<=92
replace occ1990dd=aux2 if panel_year>92 & panel_year<=2001
replace occ1990dd=aux3 if panel_year>2001 & panel_year<=2008
**There are 0.7% observations without occupational id**

drop aux1 aux2 aux3
drop occ occ2
*******************************************************************
* Occ1990dd Occupation Groups
*******************************************************************
* Copied from David Dorn, version October 12, 2012
********************************************************************
* Occupation Dummies Level 3: Subgroups of Low-Skill Service Occupations
********************************************************************
gen occ3_clean=0            /* housekeeping, cleaning, laundry */
replace occ3_clean=1 if     (occ1990dd>=405 & occ1990dd<=408 & occ1990dd!=.)
gen occ3_protect=0        /* all protective service */
replace occ3_protect=1 if (occ1990dd>=415 & occ1990dd<=427  & occ1990dd!=.)
gen occ3_guard=0          /* supervisors of guards; guards */
replace occ3_guard=1 if (occ1990dd==415  & occ1990dd!=. | (occ1990dd>=425 & occ1990dd<=427  & occ1990dd!=.))
gen occ3_food=0           /* food preparation and service occs */
replace occ3_food=1 if (occ1990dd>=433 & occ1990dd<=444  & occ1990dd!=.)
gen occ3_shealth=0        /* health service occs (dental ass., health/nursing aides) */
replace occ3_shealth=1 if (occ1990dd>=445 & occ1990dd<=447  & occ1990dd!=.)
gen occ3_janitor=0          /* building and grounds cleaning and maintenance occs */
replace occ3_janitor=1 if (occ1990dd>=448 & occ1990dd<=455  & occ1990dd!=.)
gen occ3_beauty=0           /* personal appearance occs */
replace occ3_beauty=1 if (occ1990dd>=457 & occ1990dd<=458  & occ1990dd!=.)
gen occ3_recreation=0      /* recreation and hospitality occs */
replace occ3_recreation=1 if (occ1990dd>=459 & occ1990dd<=467  & occ1990dd!=.)
gen occ3_child=0           /* child care workers */
replace occ3_child=1 if (occ1990dd==468  & occ1990dd!=.)
gen occ3_othpers=0        /* misc. personal care and service occs */
replace occ3_othpers=1 if (occ1990dd>=469 & occ1990dd<=472)


********************************************************************
* Occupation Dummies Level 2: 16 Non-Service Occupation Groups
********************************************************************

gen occ2_exec=0          /* executive, administrative and managerial occs */
replace occ2_exec=1 if (occ1990dd>=3 & occ1990dd<=22  & occ1990dd!=.)
gen occ2_mgmtrel=0       /* management related occs */
replace occ2_mgmtrel=1 if (occ1990dd>=23 & occ1990dd<=37  & occ1990dd!=.)
gen occ2_prof=0          /* professional specialty occs */
replace occ2_prof=1 if (occ1990dd>=43 & occ1990dd<=200  & occ1990dd!=.)
gen occ2_tech=0          /* technicians and related support occs */
replace occ2_tech=1 if (occ1990dd>=203 & occ1990dd<=235  & occ1990dd!=.)
gen occ2_finsales=0      /* financial sales and related occs */
replace occ2_finsales=1 if (occ1990dd>=243 & occ1990dd<=258  & occ1990dd!=.)
gen occ2_retsales=0      /* retail sales occs */
replace occ2_retsales=1 if (occ1990dd>=274 & occ1990dd<=283  & occ1990dd!=.)
gen occ2_cleric=0        /* administrative support occs */
replace occ2_cleric=1 if (occ1990dd>=303 & occ1990dd<=389  & occ1990dd!=.)
gen occ2_firepol=0       /* fire fighting, police, and correctional insitutions */
replace occ2_firepol=1 if (occ1990dd>=417 & occ1990dd<=423  & occ1990dd!=.)
gen occ2_farmer=0        /* farm operators and managers */
replace occ2_farmer=1 if (occ1990dd>=473 & occ1990dd<=475  & occ1990dd!=.)
gen occ2_otheragr=0      /* other agricultural and related occs */
replace occ2_otheragr=1 if (occ1990dd>=479 & occ1990dd<=498  & occ1990dd!=.)
gen occ2_mechanic=0      /* mechanics and repairers */
replace occ2_mechanic=1 if (occ1990dd>=503 & occ1990dd<=549  & occ1990dd!=.)
gen occ2_constr=0        /* construction trades */
replace occ2_constr=1 if (occ1990dd>=558 & occ1990dd<=599  & occ1990dd!=.)
gen occ2_mining=0        /* extractive occs */
replace occ2_mining=1 if (occ1990dd>=614 & occ1990dd<=617  & occ1990dd!=.)
gen occ2_product=0       /* precision production occs */
replace occ2_product=1 if (occ1990dd>=628 & occ1990dd<=699  & occ1990dd!=.)
gen occ2_operator=0      /* machine operators, assemblers, and inspectors */
replace occ2_operator=1 if (occ1990dd>=703 & occ1990dd<=799  & occ1990dd!=.)
gen occ2_transp=0        /* transportation and material moving occs */
replace occ2_transp=1 if (occ1990dd>=803 & occ1990dd<=889  & occ1990dd!=.)


********************************************************************
* Occupation Dummies Level 1: 6 Aggregate Occupation Groups
* as used in Autor and Dorn, "The Growth of Low-Skill Service Jobs
* and the Polarization of the U.S. Labor Market"
********************************************************************

* (1) management/professional/technical/financial sales/public security occs
gen occ1_managproftech=occ2_exec+occ2_mgmtrel+occ2_prof+occ2_tech+occ2_finsales+occ2_firepol
*gen occ1_managproftech=occ2_exec+occ2_mgmtrel+occ2_prof+occ2_tech+occ2_finsales+occ2_firepol+occ2_cleric
* (2) administrative support and retail sales occs
gen occ1_clericretail=occ2_cleric+occ2_retsales
* (3) low-skill services
gen occ1_service=occ3_clean+occ3_guard+occ3_food+occ3_shealth+occ3_janitor+occ3_beauty+occ3_recreation+occ3_child+occ3_othpers
*gen occ1_service=occ3_clean+occ3_guard+occ3_food+occ3_shealth+occ3_janitor+occ3_beauty+occ3_recreation+occ3_child+occ3_othpers+occ2_retsales
* (4) precision production and craft occs
gen occ1_product=occ2_product
* (5) machine operators, assemblers and inspectors
gen occ1_operator=occ2_operator
* (6) transportation/construction/mechanics/mining/agricultural occs
gen occ1_transmechcraft=occ2_transp+occ2_constr+occ2_mechanic+occ2_mining+occ2_farmer+occ2_otheragr

gen mayor_group_occ1=.
replace mayor_group_occ1=1 if occ1_managproftech==1
replace mayor_group_occ1=1 if occ1_clericretail==1
replace mayor_group_occ1=3 if occ1_product==1
replace mayor_group_occ1=3 if occ1_operator==1
replace mayor_group_occ1=2 if occ1_transmechcraft==1
replace mayor_group_occ1=2 if occ1_service==1


gen disag_group_occ2=.
replace disag_group_occ2=1 if occ1_managproftech==1
replace disag_group_occ2=2 if occ1_clericretail==1
replace disag_group_occ2=3 if occ1_product==1
replace disag_group_occ2=4 if occ1_operator==1
replace disag_group_occ2=5 if occ1_transmechcraft==1
replace disag_group_occ2=6 if occ1_service==1

gen new_disag_group_occ=.
replace new_disag_group_occ=1 if occ2_exec==1
replace new_disag_group_occ=1 if occ2_mgmtrel==1
replace new_disag_group_occ=2 if occ2_prof==1
replace new_disag_group_occ=2 if occ2_tech==1
replace new_disag_group_occ=3 if occ2_finsales==1
replace new_disag_group_occ=3 if occ2_retsales==1
replace new_disag_group_occ=4 if occ2_firepol==1
replace new_disag_group_occ=4 if occ2_cleric==1
replace new_disag_group_occ=5 if occ3_clean==1
replace new_disag_group_occ=6 if occ3_guard==1
replace new_disag_group_occ=6 if occ3_protect==1
replace new_disag_group_occ=5 if occ3_food==1
replace new_disag_group_occ=6 if occ3_shealth==1
replace new_disag_group_occ=5 if occ3_janitor==1
replace new_disag_group_occ=5 if occ3_beauty==1
replace new_disag_group_occ=5 if occ3_recreation==1
replace new_disag_group_occ=5 if occ3_child==1
replace new_disag_group_occ=5 if occ3_othpers==1
replace new_disag_group_occ=7 if occ2_product==1
replace new_disag_group_occ=8 if occ2_operator==1
replace new_disag_group_occ=9 if occ2_transp==1
replace new_disag_group_occ=9 if occ2_constr==1
replace new_disag_group_occ=8 if occ2_mechanic==1
replace new_disag_group_occ=10 if occ2_mining==1
replace new_disag_group_occ=10 if occ2_farmer==1
replace new_disag_group_occ=10 if occ2_otheragr==1

tab mayor_group_occ1, gen(dummy_occ)
sort id time
qby id: gen docc1=dummy_occ1-dummy_occ1[_n-1] if time[_n]==time[_n-1]+1
qby id: gen docc2=dummy_occ2-dummy_occ2[_n-1] if time[_n]==time[_n-1]+1
qby id: gen docc3=dummy_occ3-dummy_occ3[_n-1] if time[_n]==time[_n-1]+1


tab disag_group_occ2, gen(dummy_disag_occ)
sort id time
qby id: gen d_disag_occ1=dummy_disag_occ1-dummy_disag_occ1[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_disag_occ2=dummy_disag_occ2-dummy_disag_occ2[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_disag_occ3=dummy_disag_occ3-dummy_disag_occ3[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_disag_occ4=dummy_disag_occ4-dummy_disag_occ4[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_disag_occ5=dummy_disag_occ5-dummy_disag_occ5[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_disag_occ6=dummy_disag_occ6-dummy_disag_occ6[_n-1] if time[_n]==time[_n-1]+1


tab new_disag_group_occ, gen(new_dummy_disag_occ)
sort id time
qby id: gen d_new_disag_occ1=new_dummy_disag_occ1-new_dummy_disag_occ1[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ2=new_dummy_disag_occ2-new_dummy_disag_occ2[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ3=new_dummy_disag_occ3-new_dummy_disag_occ3[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ4=new_dummy_disag_occ4-new_dummy_disag_occ4[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ5=new_dummy_disag_occ5-new_dummy_disag_occ5[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ6=new_dummy_disag_occ6-new_dummy_disag_occ6[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ7=new_dummy_disag_occ7-new_dummy_disag_occ7[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ8=new_dummy_disag_occ8-new_dummy_disag_occ8[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ9=new_dummy_disag_occ9-new_dummy_disag_occ9[_n-1] if time[_n]==time[_n-1]+1
qby id: gen d_new_disag_occ10=new_dummy_disag_occ10-new_dummy_disag_occ10[_n-1] if time[_n]==time[_n-1]+1



gen age_old=age
**Generate new age variable, based on quarterly information**
egen aux=group(age quarter)
drop age
rename aux age
gen age2=age^2
**New: Divide age (expressed in quarter) by 10 and age2 by 1000**
replace age=age/10
replace age2=age2/1000
gen exper_sq=exper*exper
sort id year quarter
tab quarter, gen(dummy_quarter)
tab h_tenur, gen(dummy_h_tenur)
tab f_oklt18, gen(dummy_f_oklt18)

**Re-define M due to missing values period t-1 due to dropping for outliers**
cap drop time
egen time = group(year quarter)
sort id year quarter
by id: egen min_time=min(time)
by id: replace M=. if time[_n]!=time[_n-1]+1 & time[_n]!=min_time
by id: replace M=. if M!=. & time==min_time

gen part=emp<=2
replace part=1 if M==1 & part!=1 & part!=.
replace part=1 if M==0 & part!=1 & part!=.
sort id year quarter
by id: replace part=1 if M[_n+1]==1 & part[_n]!=1 & part[_n]!=. & quarter[_n]==quarter[_n+1]-1 & year[_n]==year[_n+1]
by id: replace part=1 if M[_n+1]==1 & part[_n]!=1 & part[_n]!=. & quarter[_n]==quarter[_n+1]+3 & year[_n]==year[_n+1]-1
by id: replace part=1 if M[_n+1]==0 & part[_n]!=1 & part[_n]!=. & quarter[_n]==quarter[_n+1]-1 & year[_n]==year[_n+1]
by id: replace part=1 if M[_n+1]==0 & part[_n]!=1 & part[_n]!=. & quarter[_n]==quarter[_n+1]+3 & year[_n]==year[_n+1]-1


forval x=1983 (1) 2013 {
gen yrd`x'=0
replace yrd`x'=1 if year==`x'
}

gen id2=id
destring id2, replace
xtset id2 time

foreach var in part age age2 uirank oth_inc oth_ear dummy_h_tenur1 dummy_h_tenur2 exper exper_sq single_work h_metro married unemp_rate disab white regd1 regd2 regd3 regd4 caidcov_ave hh_tra_ave poverty min_state_tax max_state_tax min_wage home_value dummy_quarter1 dummy_quarter2 dummy_quarter3 dummy_quarter4 yrd1983 yrd1984 yrd1985 yrd1986 yrd1987 yrd1988 yrd1989 yrd1990 yrd1991 yrd1992 yrd1993 yrd1994 yrd1995 yrd1996 yrd1997 yrd1998 yrd1999 yrd2000 yrd2001 yrd2002 yrd2003 yrd2004 yrd2005 yrd2006 yrd2007 yrd2008 yrd2009 yrd2010 yrd2011 yrd2012 yrd2013 caidcov_ave hh_tra_ave  cons manuf serv fin agr new_dummy_disag_occ1 new_dummy_disag_occ2 new_dummy_disag_occ3 new_dummy_disag_occ4 new_dummy_disag_occ5 new_dummy_disag_occ6 new_dummy_disag_occ7 new_dummy_disag_occ8 new_dummy_disag_occ9 {
cap gen prev_`var'=.
cap replace prev_`var'=L.`var'
}



keep if age_old>=25

*if (`constrain_option'!=-1) {
*keep if age_old>=25
*}


**Drop panel 85 & 89 if using experience! Information not available**
drop if panel_year==85 | panel_year==89

**Drop panel 89 not that many quarters with observations**
*drop if panel_year==89


*Drop missing values occupations and industry conditional on participation**
foreach var in dummy_disag_occ1 dummy_disag_occ2 dummy_disag_occ3 dummy_disag_occ4 dummy_disag_occ5 notforprof publ cons manuf serv fin agr {
*drop if `var'==. & part==1
drop if `var'==. & M!=.
}

di "Number of observations before dropping wage levels"
count if year!=.

cap drop outl
cap drop aux
gen outl=.
gen aux=.







set more off
gen period=. 
replace period=1 if year>=1983 & year<=1993
replace period=2 if year>=1994 & year<=2003
replace period=3 if year>=2004 & year<=2013
foreach z in 1 2 3 {
foreach t in 1 2 3 {
foreach y in 1 2 {
cap noi qui sum g if M==0 & g!=. & grades==`t' & sex==`y' & period==`z', d
cap noi replace outl=1 if g!=. & M==0 & g<`r(p1)'  & grades==`t' & sex==`y' & period==`z'
cap noi qui sum g if M==0 & g!=. & grades==`t' & sex==`y' & period==`z', d
cap noi replace outl=1 if g!=. & M==0 & g>`r(p99)'  & grades==`t' & sex==`y' & period==`z'

cap noi qui sum g if M==1 & g!=.  & grades==`t' & sex==`y' & period==`z', d
cap noi replace outl=1 if g!=. & M==1 & g<`r(p1)'  & grades==`t' & sex==`y' & period==`z'
cap noi qui sum g if M==1 & g!=.  & grades==`t' & sex==`y' & period==`z', d
cap noi replace outl=1 if g!=. & M==1 & g>`r(p99)'  & grades==`t' & sex==`y' & period==`z'
}
}
}



drop period


bysort id: egen mean_outl=mean(outl)
drop if mean_outl==1


di "Number of observations after dropping wage levels and growth"
count if year!=.

cap drop id
egen id = group(old_id pp_entry pp_pnum panel_year)
tostring id, replace
cap drop outl aux aux2
sort id year quarter

save data3_sipp_qt_calib_topcoded, replace
